@@ -62,7 +62,7 @@ static char *argv0;
 
 int archdep_startup(int *argc, char **argv)
 {
-   	argv0 = stralloc(argv[0]);
+    argv0 = stralloc(argv[0]);
     orig_workdir = getcwd(NULL, GET_PATH_MAX);
 
     return 0;
@@ -94,12 +94,12 @@ const char *archdep_program_name(void)
     return program_name;
 }
 
-static char *boot_path=NULL;
+static char *boot_path = NULL;
 
 const char *archdep_boot_path(void)
 {
     if (boot_path == NULL) {
-        fname_split(argv0, &boot_path, NULL);
+        util_fname_split(argv0, &boot_path, NULL);
 
         /* This should not happen, but you never know...  */
         if (boot_path == NULL)
@@ -115,9 +115,12 @@ const char *archdep_default_sysfile_pathlist(const char *emu_id)
 
     if (default_path == NULL) {
         const char *boot_path = archdep_boot_path();
-        default_path = concat(boot_path,"/",emu_id,
+        default_path = concat(boot_path, "/", emu_id,
                               FINDPATH_SEPARATOR_STRING,
-                              boot_path,"/","DRIVES", NULL);
+                              boot_path, "/", "DRIVES",
+                              FINDPATH_SEPARATOR_STRING,
+                              boot_path, "/", "PRINTER",
+                              NULL);
     }
 
     return default_path;
@@ -128,8 +131,8 @@ char *archdep_make_backup_filename(const char *fname)
 {
 char    *tmp;
 
-    tmp=concat(fname,NULL);
-    tmp[strlen(tmp)-1]='~';
+    tmp = concat(fname, NULL);
+    tmp[strlen(tmp) - 1] = '~';
     return tmp;
 }
 
@@ -170,9 +173,12 @@ int archdep_num_text_columns(void)
     return 80;
 }
 
-int archdep_default_logger(const char *level_string, const char *format,
-                                                                va_list ap)
+int archdep_default_logger(const char *level_string, const char *txt)
 {
+    if (fputs(level_string, stdout) == EOF
+        || fprintf(stdout, txt) < 0
+        || fputc ('\n', stdout) == EOF)
+        return -1;
     return 0;
 }
 
@@ -190,8 +196,6 @@ static RETSIGTYPE break64(int sig)
 
 void archdep_setup_signals(int do_core_dumps)
 {
-
-/* Activate this later...
     signal(SIGINT, break64);
     signal(SIGTERM, break64);
 
@@ -199,7 +203,6 @@ void archdep_setup_signals(int do_core_dumps)
         signal(SIGSEGV,  break64);
         signal(SIGILL,   break64);
     }
-*/
 }
 
 int archdep_path_is_relative(const char *path)
@@ -221,33 +224,34 @@ int archdep_spawn(const char *name, char **argv,
 
     child_pid = vfork();
     if (child_pid < 0) {
-    log_error(LOG_DEFAULT, "vfork() failed: %s.", strerror(errno));
-    return -1;
-    } else if (child_pid == 0) {
-    if (stdout_redir && freopen(stdout_redir, "w", stdout) == NULL) {
-        log_error(LOG_DEFAULT, "freopen(\"%s\") failed: %s.",
-                      stdout_redir, strerror(errno));
-        _exit(-1);
-    }
-    if (stderr_redir && freopen(stderr_redir, "w", stderr) == NULL) {
-        log_error(LOG_DEFAULT, "freopen(\"%s\") failed: %s.",
-                      stderr_redir, strerror(errno));
-        _exit(-1);
-    }
-    execvp(name, argv);
-    _exit(-1);
+        log_error(LOG_DEFAULT, "vfork() failed: %s.", strerror(errno));
+        return -1;
+    } else {
+        if (child_pid == 0) {
+            if (stdout_redir && freopen(stdout_redir, "w", stdout) == NULL) {
+                log_error(LOG_DEFAULT, "freopen(\"%s\") failed: %s.",
+                          stdout_redir, strerror(errno));
+                _exit(-1);
+            }
+            if (stderr_redir && freopen(stderr_redir, "w", stderr) == NULL) {
+                log_error(LOG_DEFAULT, "freopen(\"%s\") failed: %s.",
+                          stderr_redir, strerror(errno));
+                _exit(-1);
+            }
+            execvp(name, argv);
+            _exit(-1);
+        }
     }
 
     if (waitpid(child_pid, &child_status, 0) != child_pid) {
         log_error(LOG_DEFAULT, "waitpid() failed: %s", strerror(errno));
-    return -1;
+        return -1;
     }
 
     if (WIFEXITED(child_status))
-    return WEXITSTATUS(child_status);
+        return WEXITSTATUS(child_status);
     else
-    return -1;
-
+        return -1;
 }
 
 
@@ -261,12 +265,15 @@ int archdep_expand_path(char **return_path, const char *orig_name)
 
 void archdep_startup_log_error(const char *format, ...)
 {
-        char tmp[1024];
-        va_list args;
+    char *tmp;
+    va_list args;
 
-        va_start(args, format);
-        vsprintf(tmp, format, args);
-        va_end(args);
+    va_start(args, format);
+    tmp = xmvsprintf(format, args);
+    va_end(args);
+	printf(tmp);
+	
+    free(tmp);
 }
 
 char *archdep_quote_parameter(const char *name)
@@ -278,6 +285,7 @@ char *archdep_filename_parameter(const char *name)
 {
     char *exp;
     char *a;
+
     archdep_expand_path(&exp, name);
     a = archdep_quote_parameter(exp);
     free(exp);
@@ -288,3 +296,20 @@ char *archdep_tmpnam(void)
 {
     return stralloc(tmpnam(NULL));
 }
+
+int archdep_file_is_gzip(const char *name)
+{
+    size_t l = strlen(name);
+
+    if ((l < 4 || strcasecmp(name + l - 3, ".gz"))
+        && (l < 3 || strcasecmp(name + l - 2, ".z"))
+        && (l < 4 || toupper(name[l - 1]) != 'Z' || name[l - 4] != '.'))
+        return 0;
+    return 1;
+}
+
+int archdep_file_set_gzip(const char *name)
+{
+    return 0;
+}
+
