@@ -44,24 +44,28 @@ ui_menu_toggle  c128_ui_menu_toggles[]={
     { "REU", MENU_TOGGLE_REU },
     { "IEEE488", MENU_TOGGLE_IEEE488 },
     { "Mouse", MENU_TOGGLE_MOUSE },
-    { "SidFilters", MENU_TOGGLE_SIDFILTERS },
-#ifdef HAVE_RESID
-    { "SidUseResid", MENU_TOGGLE_SOUND_RESID },
-#endif
     { "VDC_DoubleSize", MENU_TOGGLE_VDC_DOUBLESIZE },
     { "VDC_DoubleScan", MENU_TOGGLE_VDC_DOUBLESCAN },
     { "VDC_64KB", MENU_TOGGLE_VDC_64KB },
+    { "DelayLoopEmulation", MENU_TOGGLE_FASTPAL },
     { NULL, 0 }
 };
 
-static ui_res_possible_values SidType[] = {
-    {0, MENU_SIDTYPE_6581},
-    {1, MENU_SIDTYPE_8580},
-    {-1,0}
+ui_res_possible_values ReuSize[] = {
+        {128, MENU_REU_SIZE_128},
+        {256, MENU_REU_SIZE_256},
+        {512, MENU_REU_SIZE_512},
+        {1024, MENU_REU_SIZE_1024},
+        {2048, MENU_REU_SIZE_2048},
+        {4096, MENU_REU_SIZE_4096},
+        {8192, MENU_REU_SIZE_8192},
+        {16384, MENU_REU_SIZE_16384},
+        {-1, 0}
 };
 
+
 ui_res_value_list c128_ui_res_values[] = {
-    {"SidModel", SidType},
+    {"REUsize", ReuSize},
     {NULL,NULL}
 };
 
@@ -69,15 +73,9 @@ ui_res_value_list c128_ui_res_values[] = {
 void c128_ui_specific(void *msg, void *window)
 {
     switch (((BMessage*)msg)->what) {
-		case MENU_SIDTYPE_6581:
-    		resources_set_value("SidModel", (resource_value_t) 0);
-        	break;
-		case MENU_SIDTYPE_8580:
-        	resources_set_value("SidModel", (resource_value_t) 1);
-        	break;
 		case MENU_VICII_SETTINGS:
         	ui_vicii();
-        break;
+        	break;
 
     	default: ;
     }
