@@ -2,7 +2,7 @@
  * c64kbd.c -- C64 keyboard for MS-DOS.
  *
  * Written by
- *  Ettore Perazzoli (ettore@comm2000.it)
+ *  Ettore Perazzoli <ettore@comm2000.it>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -24,10 +24,6 @@
  *
  */
 
-#include "vice.h"
-
-#include <stdio.h>
-
 #include "cartridge.h"
 #include "kbd.h"
 
@@ -148,3 +144,4 @@ int c64_kbd_init(void)
     return kbd_init(1,
                     1, 7, c64_keyboard, sizeof(c64_keyboard));
 }
+
