@@ -61,7 +61,7 @@ static resource_t resources[] = {
     { NULL }
 };
 
-int mouse_init_resources(void)
+int mouse_resources_init(void)
 {
     return resources_register(resources);
 }
@@ -76,7 +76,7 @@ static cmdline_option_t cmdline_options[] = {
     { NULL }
 };
 
-int mouse_init_cmdline_options(void)
+int mouse_cmdline_options_init(void)
 {
     return cmdline_register_options(cmdline_options);
 }
@@ -116,3 +116,4 @@ int mouse_init(void)
 
     return 0;
 }
+
