@@ -2,7 +2,7 @@
  * tuimenu.c - A (very) simple text-based menu.
  *
  * Written by
- *  Ettore Perazzoli (ettore@comm2000.it)
+ *  Ettore Perazzoli <ettore@comm2000.it>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -26,14 +26,18 @@
 
 #include "vice.h"
 
-#include <stdlib.h>
-#include <strings.h>
-#include <ctype.h>
 #include <conio.h>
-#include <pc.h>
+#include <ctype.h>
 #include <keys.h>
+#include <pc.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
+#include "log.h"
+#include "resources.h"
 #include "tui.h"
+#include "tui_backend.h"
 #include "tuimenu.h"
 #include "utils.h"
 
@@ -274,9 +278,16 @@ void tui_menu_add_item(tui_menu_t menu, const char *label,
 		       void *callback_param, int par_string_max_len,
 		       tui_menu_item_behavior_t behavior)
 {
-    tui_menu_item_t *new = tui_menu_add_generic(menu);
+    tui_menu_item_t *new;
     int width, dummy;
 
+    if (menu == NULL) {
+        log_message(LOG_DEFAULT, "Invalid menu!");
+        return;
+    }
+
+    new = tui_menu_add_generic(menu);
+
     width = set_label(new, label);
 
     if (par_string_max_len != 0)
