@@ -2,7 +2,7 @@
  * vic20kbd.c -- VIC20 keyboard handling for MS-DOS.
  *
  * Written by
- *  Ettore Perazzoli (ettore@comm2000.it)
+ *  Ettore Perazzoli <ettore@comm2000.it>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -24,10 +24,6 @@
  *
  */
 
-#include "vice.h"
-
-#include <stdio.h>
-
 #include "kbd.h"
 
 static keyconv vic20_keyboard[256] = {
