@@ -28,7 +28,10 @@
 
 #define INCL_WINSYS        // SYSCLR_*
 #define INCL_WININPUT      // VK_*
+#define INCL_WINDIALOGS    // WinSendDlgItemMsg
+#define INCL_WINBUTTONS    // BS_DEFAULT
 #define INCL_WINFRAMEMGR
+#define INCL_WINPOINTERS   // WinLoadPointer
 #define INCL_DOSDATETIME   // Date and time values
 #define INCL_DOSSEMAPHORES
 #include <os2.h>
@@ -44,14 +47,19 @@
 #include "ui.h"
 #include "ui_status.h"
 
+#include "dialogs.h"
+#include "dlg-drive.h"
+#include "dlg-monitor.h"
+#include "dlg-datasette.h"
+#include "snippets\\pmwin2.h"
 //#ifdef __EMX__
 //#include "dos.h"
 //#endif
 #include "log.h"
 #include "utils.h"
 #include "archdep.h"
-#include "dialogs.h"
 #include "cmdline.h"
+#include "machine.h"   // vsid_mode
 #include "resources.h"
 
 /* ------------------------ ui resources ------------------------ */
@@ -72,12 +80,12 @@ static int set_use_leds(resource_value_t v, void *param)
 static resource_t resources[] = {
     { "UseLeds", RES_INTEGER, (resource_value_t) 1,
       (resource_value_t *) &use_leds, set_use_leds, NULL },
-{ NULL }
+    NULL
 };
 
 int ui_init_resources(void)
 {
-    return resources_register(resources);
+    return vsid_mode?0:resources_register(resources);
 }
 
 static cmdline_option_t cmdline_options[] = {
@@ -85,12 +93,17 @@ static cmdline_option_t cmdline_options[] = {
       NULL, "Enable usage of PC keyboard LEDs" },
     { "+leds", SET_RESOURCE, 0, NULL, NULL, "UseLeds", (resource_value_t) 0,
       NULL, "Disable usage of PC keyboard LEDs" },
-    { NULL },
+    NULL,
 };
 
 int ui_init_cmdline_options(void)
 {
-    return cmdline_register_options(cmdline_options);
+    return vsid_mode?0:cmdline_register_options(cmdline_options);
+}
+
+int machine_ui_init(void)
+{
+    return 0;
 }
 
 int ui_init(int *argc, char **argv)
@@ -170,7 +183,8 @@ void ui_display_drive_led(int drive_number, int status)
     }
     DosReleaseMutexSem(hmtxKey);
 
-    WinSendMsg(hwndDrive, WM_DRIVELEDS, (void*)drive_number, (void*)status);
+    WinSendMsg(hwndDrive, WM_DRIVELEDS,
+               (void*)drive_number, (void*)status);
 }
 
 void ui_display_drive_track(int drive_number, int drive_base,
@@ -178,13 +192,13 @@ void ui_display_drive_track(int drive_number, int drive_base,
 {
     ui_status.lastTrack[drive_number]=track_number;
     WinSendMsg(hwndDrive, WM_TRACK,
-               (void*)drive_number, (void*)(int)(track_number*2));
+                      (void*)drive_number, (void*)(int)(track_number*2));
 }
 
 void ui_enable_drive_status(ui_drive_enable_t state, int *drive_led_color)
 {
     ui_status.lastDriveState=state;
-    WinSendMsg(hwndDrive, WM_DRIVESTATE, (void*)state, NULL);
+    WinSendMsg(hwndDrive, WM_DRIVESTATE,(void*)state, NULL);
     if (state&1) ui_display_drive_led(0, 0);
     if (state&2) ui_display_drive_led(1, 0);
 }
@@ -205,7 +219,8 @@ void ui_display_drive_current_image(unsigned int drive_number,
         strcpy(ui_status.imageHist[0], image);
     }
 
-    WinSendMsg(hwndDrive, WM_DRIVEIMAGE, (void*)image, (void*)drive_number);
+    WinSendMsg(hwndDrive, WM_DRIVEIMAGE,
+               (void*)image, (void*)drive_number);
 
     if (image)
         strcpy(ui_status.lastImage[drive_number], image);
@@ -215,31 +230,69 @@ void ui_display_drive_current_image(unsigned int drive_number,
 
 void ui_error(const char *format,...)
 {
-    char *txt;
+    char *txt, *tmp;
+
     va_list ap;
     va_start(ap, format);
-    txt = xmvsprintf(format, ap);
-    WinMessageBox(HWND_DESKTOP, HWND_DESKTOP,
-                  txt, "VICE/2 Error", 0, MB_OK);
+    tmp = xmvsprintf(format, ap);
+    txt = concat(" Error in emulation thread:\n ", tmp, NULL);
+    free(tmp);
+
+    log_message(LOG_DEFAULT, txt);
+    ViceErrorDlg(HWND_DESKTOP, PTR_SKULL, txt);
+
     free(txt);
 }
 
 ui_jam_action_t ui_jam_dialog(const char *format,...)
 {
-    char *txt;
+    ULONG rc;
+
+    char *txt, *tmp;
+
     va_list ap;
+
+    const int sz   = sizeof(MB2INFO)+2*sizeof(MB2D);
+
+    MB2INFO *mb    = malloc(sz);
+    mb->cb         = sz;
+    mb->hIcon      = WinLoadPointer(HWND_DESKTOP, NULLHANDLE, PTR_SKULL);
+    mb->cButtons   = 3;
+    mb->flStyle    = MB_CUSTOMICON|WS_VISIBLE;
+    mb->hwndNotify = NULLHANDLE;
+    strcpy(mb->mb2d[0].achText, "  ~Hard Reset  ");
+    strcpy(mb->mb2d[1].achText, "  ~Soft Reset  ");
+    strcpy(mb->mb2d[2].achText, "   ~Monitor   ");
+    mb->mb2d[0].idButton = UI_JAM_HARD_RESET;
+    mb->mb2d[1].idButton = UI_JAM_RESET;
+    mb->mb2d[2].idButton = UI_JAM_MONITOR;
+    mb->mb2d[0].flStyle  = BS_DEFAULT;
+    mb->mb2d[1].flStyle  = 0;
+    mb->mb2d[2].flStyle  = 0;
+
     va_start(ap, format);
-    txt = xmvsprintf(format, ap);
-    WinMessageBox(HWND_DESKTOP, HWND_DESKTOP,
-                  txt, "VICE/2 CPU JAM happend", 0, MB_OK);
+    tmp = xmvsprintf(format, ap);
+    txt = concat("    Chipset reported:\n ", tmp, NULL);
+    free(tmp);
+
+    rc = WinMessageBox2(HWND_DESKTOP, HWND_DESKTOP,
+                        txt, "VICE/2 Error", 0, mb);
     free(txt);
-    return UI_JAM_HARD_RESET;  // Always hard reset.
+    free(mb);
+
+    //
+    // open monitor dialog
+    //
+    if (rc==UI_JAM_MONITOR)
+        WinShowWindow(hwndMonitor, 1);
+
+    return rc;
 }
 
 int ui_extend_image_dialog(void)
 {
     return WinMessageBox(HWND_DESKTOP, HWND_DESKTOP,
-                         "Extend disk image in drive 8 to 40 tracks?",
+                         "Extend disk image in drive to 40 tracks?",
                          "VICE/2 Extend Disk Image",
                          0, MB_YESNO)==MBID_YES;
 }
@@ -249,7 +302,3 @@ int ui_extend_image_dialog(void)
 void ui_update_menus(void)
 {
 }
-
-void ui_proc_write_msg(char* msg)
-{
-}
