@@ -27,6 +27,6 @@
 #ifndef _C64C128UI_H
 #define _C64C128UI_H
 
-extern void c64c128_ui_init_keyboard(void);
+extern void c64c128_ui_init_keyboard(const char *filename);
 
 #endif
