@@ -24,7 +24,8 @@
  *
  */
 
-#include "ROlib.h"
+#include "vice.h"
+
 #include "ui.h"
 #include "c64ui.h"
 #include "kbd.h"
@@ -35,9 +36,18 @@
 
 char *WimpTaskName = "Vice C64";
 
+static const char C64keyfile[] = "Vice:C64.ROdflt/vkm";
+
 
 int c64_ui_init(void)
 {
-  c64c128_ui_init_keyboard();
   return ui_init_named_app("Vice64", "!vice64");
 }
+
+int c64_kbd_init(void)
+{
+  c64c128_ui_init_keyboard(C64keyfile);
+  kbd_load_keymap(NULL, 0);
+  return kbd_init();
+}
+
