@@ -43,13 +43,13 @@ static BYTE old_joy[2];
 
 
 
-static int set_joystick_port1(resource_value_t val)
+static int set_joystick_port1(resource_value_t val, void *param)
 {
   joystick_port_map[0] = (int)val;
   return 0;
 }
 
-static int set_joystick_port2(resource_value_t val)
+static int set_joystick_port2(resource_value_t val, void *param)
 {
   joystick_port_map[1] = (int)val;
   return 0;
@@ -58,9 +58,9 @@ static int set_joystick_port2(resource_value_t val)
 
 static resource_t resources[] = {
   {"JoyDevice1", RES_INTEGER, (resource_value_t)JOYDEV_NONE,
-    (resource_value_t)&joystick_port_map[0], set_joystick_port1},
+    (resource_value_t)&joystick_port_map[0], set_joystick_port1, NULL },
   {"JoyDevice2", RES_INTEGER, (resource_value_t)JOYDEV_KBD1,
-    (resource_value_t)&joystick_port_map[1], set_joystick_port2},
+    (resource_value_t)&joystick_port_map[1], set_joystick_port2, NULL },
   {NULL}
 };
 
