@@ -29,7 +29,8 @@
 
 struct cmdline_option_s;
 
-extern void ui_cmdline_show_help  (int num_options,
-                                   struct cmdline_option_s *options);
+extern void ui_cmdline_show_help(int num_options,
+                                 struct cmdline_option_s *options,
+                                 void *userparam);
 
 #endif
