@@ -33,11 +33,13 @@
 #include "palette.h"
 #include "types.h"
 #include "ui.h"
+#include "video.h"
 
 
 struct video_frame_buffer_s {
-  int width, height;
+  int width, height, depth;
   PIXEL *tmpframebuffer;
+  void *spritebase;
   unsigned int tmpframebufferlinesize;
 };
 
@@ -46,7 +48,7 @@ typedef struct video_frame_buffer_s video_frame_buffer_t;
 typedef PIXEL *frame_buffer_ptr_t;
 typedef ui_exposure_handler_t canvas_redraw_t;
 
-struct canvas_s {
+struct video_canvas_s {
   unsigned int width, height;
   unsigned int scale;
   int shiftx, shifty;
@@ -55,12 +57,13 @@ struct canvas_s {
   PIXEL *pixel_translation;
   unsigned int num_colours;
   unsigned int colour_table[256];
+  video_render_config_t videoconfig;
 };
 
-typedef struct canvas_s canvas_t;
+typedef struct video_canvas_s video_canvas_t;
 
 typedef struct canvas_list_t {
-  canvas_t *canvas;
+  video_canvas_t *canvas;
   struct canvas_list_t *next;
 } canvas_list_t;
 
@@ -74,7 +77,7 @@ typedef struct canvas_list_t {
 
 
 extern void canvas_mode_change(void);
-extern canvas_t *canvas_for_handle(int handle);
+extern video_canvas_t *canvas_for_handle(int handle);
 extern unsigned int canvas_number_for_handle(int handle);
 extern void canvas_next_active(int moveCaret);
 extern int canvas_get_number(void);
@@ -89,7 +92,7 @@ extern void video_full_screen_plot_status(void);
 extern void video_full_screen_display_image(unsigned int num, const char *img);
 
 extern canvas_list_t *CanvasList;
-extern canvas_t *ActiveCanvas;
+extern video_canvas_t *ActiveCanvas;
 
 extern int FullScreenMode;
 extern int FullScreenStatLine;
