@@ -1,10 +1,11 @@
 /*
- * kbd.h - X11 keyboard driver.
+ * kbd.h - Keyboard driver.
  *
  * Written by
- *  Jouko Valta        (jopi@stekt.oulu.fi)
- *  Andre Fachat       (fachat@physik.tu-chemnitz.de)
- *  Ettore Perazzoli   (ettore@comm2000.it)
+ *  Jouko Valta <jopi@stekt.oulu.fi>
+ *  Andre Fachat <fachat@physik.tu-chemnitz.de>
+ *  Ettore Perazzoli <ettore@comm2000.it>
+ *  Andreas Boose <boose@linux.rz.fh-hannover.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README file for copyright notice.
@@ -26,26 +27,11 @@
  *
  */
 
-/* X11 keyboard driver. */
+#ifndef _KBD_H
+#define _KBD_H
 
-#ifndef _KBD_X_H
-#define _KBD_X_H
+#include "types.h"
 
-#include <X11/Intrinsic.h>
-
-/* Maximum of keyboard array (CBM-II values
- * (8 for C64/VIC20, 10 for PET, 11 for C128; we need max).  */
-#define	KBD_ROWS	16
-
-/* (This is actually the same for all the machines.) */
-/* (All have 8, except CBM-II that has 6) */
-#define KBD_COLS	8
-
-extern int keyarr[KBD_ROWS], rev_keyarr[KBD_COLS];
-extern BYTE joystick_value[3];
-
-extern void kbd_event_handler(Widget w, XtPointer client_data, XEvent *report,
-			      Boolean *ctd);
 extern int kbd_load_keymap(const char *filename);
 extern int kbd_dump_keymap(const char *filename);
 
@@ -53,18 +39,7 @@ extern int kbd_init(void);
 extern int do_kbd_init_cmdline_options(void);
 extern int do_kbd_init_resources(void);
 
-extern int kbd_init_cmdline_options(void);
-extern int kbd_init_resources(void);
-
-extern int pet_kbd_init_cmdline_options(void);
-extern int pet_kbd_init_resources(void);
-
 extern const char **keymap_res_name_list;
 
-extern int c64_kbd_init(void);
-extern int c128_kbd_init(void);
-extern int vic20_kbd_init(void);
-extern int pet_kbd_init(void);
-extern int c610_kbd_init(void);
-
 #endif
+
