@@ -29,8 +29,8 @@
 
 #include "types.h"
 
-extern int mouse_init_resources(void);
-extern int mouse_init_cmdline_options(void);
+extern int mouse_resources_init(void);
+extern int mouse_cmdline_options_init(void);
 extern int mouse_init(void);
 extern void mouse_button(int bnumber, int state);
 
