@@ -75,6 +75,10 @@ KeySym key_ctrl_restore2 = NoSymbol;
 KeySym key_ctrl_column4080 = NoSymbol;
 key_ctrl_column4080_func_t key_ctrl_column4080_func = NULL;
 
+/* CAPS (ASCII/DIN) key.  */
+KeySym key_ctrl_caps = NoSymbol;
+key_ctrl_caps_func_t key_ctrl_caps_func = NULL;
+
 /* Joystick status */
 BYTE joystick_value[3] = { 0, 0, 0 };
 static keyconv_t joykeys[2][10];
@@ -121,8 +125,8 @@ static int set_keymap_index(resource_value_t v, void *param)
 }
 
 static resource_t resources[] = {
-    { "KeymapIndex", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &keymap_index, set_keymap_index, NULL },
+    { "KeymapIndex", RES_INTEGER, (resource_value_t)0,
+      (resource_value_t *)&keymap_index, set_keymap_index, NULL },
     { NULL }
 };
 
@@ -277,6 +281,11 @@ int pet_kbd_init(void)
     return kbd_init();
 }
 
+int plus4_kbd_init(void)
+{
+    return kbd_init();
+}
+
 int c610_kbd_init(void)
 {
     return kbd_init();
@@ -405,6 +414,9 @@ static void kbd_parse_entry(char *buffer)
                         } else
                         if (row == -4 && col == 0) {
                             key_ctrl_column4080 = sym;
+                        } else
+                        if (row == -4 && col == 1) {
+                            key_ctrl_caps = sym;
                         } else {
                             log_error(LOG_DEFAULT,
                                       _("Bad row/column value (%d/%d) for keysym `%s'."),
@@ -571,3 +583,8 @@ void kbd_register_column4080_key(key_ctrl_column4080_func_t func)
     key_ctrl_column4080_func = func;
 }
 
+void kbd_register_caps_key(key_ctrl_caps_func_t func)
+{
+    key_ctrl_caps_func = func;
+}
+
