@@ -29,6 +29,7 @@
 #include <stdio.h>
 
 #include "kbd.h"
+#include "keyboard.h"
 
 /* PET 3032/4032 keyboard map.  */
 static keyconv pet40_keyboard[256] = {
@@ -261,13 +262,13 @@ int pet_kbd_init(void)
                     8, 0, pet40_keyboard, sizeof(pet40_keyboard));
 }
 
-int pet_kbd_init_resources(void)
+int pet_kbd_resources_init(void)
 {
-    return kbd_init_resources();
+    return kbd_resources_init();
 }
 
-int pet_kbd_init_cmdline_options(void)
+int pet_kbd_cmdline_options_init(void)
 {
-    return kbd_init_cmdline_options();
+    return kbd_cmdline_options_init();
 }
 
