@@ -57,6 +57,8 @@ static void enable_controls_for_disk_device_type(HWND hwnd, int type)
                  type == IDC_SELECTDISK);
     EnableWindow(GetDlgItem(hwnd, IDC_AUTOSTART),
                  type == IDC_SELECTDISK);
+    EnableWindow(GetDlgItem(hwnd, IDC_TOGGLE_ATTACH_READONLY),
+                 type == IDC_SELECTDISK);
     EnableWindow(GetDlgItem(hwnd, IDC_DIR),
                  type == IDC_SELECTDIR);
     EnableWindow(GetDlgItem(hwnd, IDC_BROWSEDIR),
@@ -74,6 +76,11 @@ static void init_dialog(HWND hwnd, unsigned int num)
     const char *disk_image, *dir;
     int n;
 
+    int drive_true_emulation;
+
+    resources_get_value("DriveTrueEmulation",
+                        (resource_value_t *)&drive_true_emulation);
+
     if (num >= 8 && num <= 11) {
         disk_image = file_system_get_disk_name(num);
         SetDlgItemText(hwnd, IDC_DISKIMAGE,
@@ -98,18 +105,33 @@ static void init_dialog(HWND hwnd, unsigned int num)
         CheckDlgButton(hwnd, IDC_TOGGLE_HIDENONP00,
                        n ? BST_CHECKED : BST_UNCHECKED);
 
-        if (disk_image != NULL) {
+        resources_get_sprintf("AttachDevice%dReadonly",
+                              (resource_value_t *)&n, num);
+        CheckDlgButton(hwnd, IDC_TOGGLE_ATTACH_READONLY,
+                       n ? BST_CHECKED : BST_UNCHECKED);
+
+        n = IDC_SELECTNONE;
+        if (dir != NULL)
+            if (*dir != 0)
+                n = IDC_SELECTDIR;
+        if (disk_image != NULL)
+            if (*disk_image != 0)
+                n = IDC_SELECTDISK;
+
+        if (drive_true_emulation)
+        {
             n = IDC_SELECTDISK;
-        } else if (dir != NULL) {
-            n = IDC_SELECTDIR;
-        } else {
-            n = IDC_SELECTNONE;
+
+            /* don't allow to check DIR or NONE */
+            EnableWindow(GetDlgItem(hwnd, IDC_SELECTDIR),  FALSE );
+            EnableWindow(GetDlgItem(hwnd, IDC_SELECTNONE), FALSE );
         }
+
         CheckRadioButton(hwnd, IDC_SELECTDISK, IDC_SELECTDIR, n);
         enable_controls_for_disk_device_type(hwnd, n);
     }
     if (num == 4) {
-        resources_get_value("Printer4", (resource_value_t *) &n);
+        resources_get_value("Printer4", (resource_value_t *)&n);
         CheckDlgButton(hwnd, IDC_TOGGLE_PRINTER,
                        n ? BST_CHECKED : BST_UNCHECKED);
     }
@@ -125,6 +147,22 @@ static BOOL CALLBACK dialog_proc(unsigned int num, HWND hwnd, UINT msg,
       case WM_INITDIALOG:
         init_dialog(hwnd, num);
         return TRUE;
+      case WM_DESTROY:
+          /* check if DISKIMAGE is selected? */
+          if (IsDlgButtonChecked( hwnd, IDC_SELECTDISK)!=BST_CHECKED)
+          {
+              /* no, detach the diskimage so a directory is possible as drive */
+              file_system_detach_disk(num);
+
+              /* check if DIR is selected? */
+              if (IsDlgButtonChecked( hwnd, IDC_SELECTDIR)!=BST_CHECKED)
+              {
+                  /* no, detach the virtual disk */
+                  resources_set_sprintf("FSDevice%dDir",
+                    (resource_value_t)"", num);
+              }
+          }
+          break;
       case WM_COMMAND:
         switch (LOWORD(wparam)) {
           case IDC_SELECTDIR:
@@ -132,14 +170,32 @@ static BOOL CALLBACK dialog_proc(unsigned int num, HWND hwnd, UINT msg,
           case IDC_SELECTNONE:
             enable_controls_for_disk_device_type(hwnd, LOWORD(wparam));
             break;
+          case IDC_DISKIMAGE:
+            {
+                char s[MAX_PATH];
+
+                switch (HIWORD(wparam))
+                {
+                case CBN_KILLFOCUS:
+                    GetDlgItemText(hwnd, IDC_DISKIMAGE, s, MAX_PATH);
+                    if (s)
+                        if (*s)
+                            if (file_system_attach_disk(num, s) < 0)
+                                ui_error("Cannot attach specified file");
+                    break;
+
+                default:
+                    break;
+                }
+            }
+            break;
           case IDC_BROWSEDISK:
             {
                 char *s;
 
                 s = ui_select_file(hwnd,"Attach disk image",
-                "Disk image files (*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64)\0*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64\0"
-                "Zipped files (*.zip;*.gz;*.bz2;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z)\0*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z\0"
-                "All files (*.*)\0*.*\0", FILE_SELECTOR_DISK_STYLE,NULL);
+                    UI_LIB_FILTER_ALL | UI_LIB_FILTER_DISK | UI_LIB_FILTER_ZIP,
+                    FILE_SELECTOR_DISK_STYLE,NULL);
 
                 if (s != NULL) {
                     SetDlgItemText(hwnd, IDC_DISKIMAGE, s);
@@ -154,35 +210,48 @@ static BOOL CALLBACK dialog_proc(unsigned int num, HWND hwnd, UINT msg,
                 char *s;
 
                 s = ui_select_file(hwnd,"Autostart disk image",
-                "Disk image files (*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64)\0*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64\0"
-                "Zipped files (*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z)\0*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z\0"
-                "All files (*.*)\0*.*\0", FILE_SELECTOR_DISK_STYLE,NULL);
+                    UI_LIB_FILTER_ALL | UI_LIB_FILTER_DISK | UI_LIB_FILTER_ZIP,
+                    FILE_SELECTOR_DISK_STYLE,NULL);
 
                 if (s != NULL) {
                     SetDlgItemText(hwnd, IDC_DISKIMAGE, s);
-                    if (autostart_autodetect(s, "*", 0) < 0)
+                    if (autostart_autodetect(s, "*", 0, AUTOSTART_MODE_RUN) < 0)
                         ui_error("Cannot autostart specified file.");
                     free(s);
                 }
             }
             break;
+          case IDC_DIR:
+            {
+                char s[MAX_PATH];
+                GetDlgItemText(hwnd, IDC_DIR, s, MAX_PATH);
+                resources_set_sprintf("FSDevice%dDir",
+                                      (resource_value_t)s, num);
+            }
+            break;
           case IDC_BROWSEDIR:
             {
-                BROWSEINFO    bi;
-                char          s[MAX_PATH];
-                LPITEMIDLIST  idlist;
+                BROWSEINFO bi;
+                char s[MAX_PATH];
+                LPITEMIDLIST idlist;
 
-                bi.hwndOwner=hwnd;
-                bi.pidlRoot=NULL;
-                bi.pszDisplayName=s;
-                bi.lpszTitle="Select file system directory";
-                bi.ulFlags=0;
-                bi.lpfn=NULL;
-                bi.lParam=0;
-                bi.iImage=0;
-                if ((idlist=SHBrowseForFolder(&bi))!=NULL) {
-                    SHGetPathFromIDList(idlist,s);
+                bi.hwndOwner = hwnd;
+                bi.pidlRoot = NULL;
+                bi.pszDisplayName = s;
+                bi.lpszTitle = "Select file system directory";
+                bi.ulFlags = 0;
+                bi.lpfn = NULL;
+                bi.lParam = 0;
+                bi.iImage = 0;
+                if ((idlist = SHBrowseForFolder(&bi)) != NULL) {
+                    SHGetPathFromIDList(idlist, s);
                     LocalFree(idlist);
+                    /*
+                    If a root directory is selected, \ is appended
+                    and has to be deleted.
+                    */
+                    if (s[strlen(s) - 1] == '\\')
+                        s[strlen(s) - 1] = '\0';
                     SetDlgItemText(hwnd, IDC_DIR, s);
                     resources_set_sprintf("FSDevice%dDir",
                                           (resource_value_t)s, num);
@@ -191,22 +260,27 @@ static BOOL CALLBACK dialog_proc(unsigned int num, HWND hwnd, UINT msg,
             break;
           case IDC_TOGGLE_READP00:
             sprintf(tmp, "FSDevice%dConvertP00", num);
-            resources_get_value(tmp, (resource_value_t *) &n);
-            resources_set_value(tmp, (resource_value_t) !n);
+            resources_get_value(tmp, (resource_value_t *)&n);
+            resources_set_value(tmp, (resource_value_t)!n);
             break;
           case IDC_TOGGLE_WRITEP00:
             sprintf(tmp, "FSDevice%dSaveP00", num);
-            resources_get_value(tmp, (resource_value_t *) &n);
-            resources_set_value(tmp, (resource_value_t) !n);
+            resources_get_value(tmp, (resource_value_t *)&n);
+            resources_set_value(tmp, (resource_value_t)!n);
             break;
           case IDC_TOGGLE_HIDENONP00:
             sprintf(tmp, "FSDevice%dHideCBMFiles", num);
-            resources_get_value(tmp, (resource_value_t *) &n);
-            resources_set_value(tmp, (resource_value_t) !n);
+            resources_get_value(tmp, (resource_value_t *)&n);
+            resources_set_value(tmp, (resource_value_t)!n);
+            break;
+          case IDC_TOGGLE_ATTACH_READONLY:
+            sprintf(tmp, "AttachDevice%dReadonly", num);
+            resources_get_value(tmp, (resource_value_t *)&n);
+            resources_set_value(tmp, (resource_value_t)!n);
             break;
           case IDC_TOGGLE_PRINTER:
-            resources_get_value("Printer4", (resource_value_t *) &n);
-            resources_set_value("Printer4", (resource_value_t) !n);
+            resources_get_value("Printer4", (resource_value_t *)&n);
+            resources_set_value("Printer4", (resource_value_t)!n);
             break;
         }
         return TRUE;
@@ -233,6 +307,14 @@ void ui_attach_dialog(HWND hwnd)
     PROPSHEETHEADER psh;
     int i;
 
+    int drive_true_emulation;
+    int no_of_drives;
+
+    resources_get_value("DriveTrueEmulation",
+                        (resource_value_t *)&drive_true_emulation);
+
+    no_of_drives = drive_true_emulation ? 3 : 5;
+
     psp[0].dwSize = sizeof(PROPSHEETPAGE);
     psp[0].dwFlags = PSP_USETITLE /*| PSP_HASHELP*/ ;
     psp[0].hInstance = winmain_instance;
@@ -247,7 +329,7 @@ void ui_attach_dialog(HWND hwnd)
     psp[0].pfnCallback = NULL;
 
 
-    for (i = 1; i < 5; i++) {
+    for (i = 1; i < no_of_drives; i++) {
         psp[i].dwSize = sizeof(PROPSHEETPAGE);
         psp[i].dwFlags = PSP_USETITLE /*| PSP_HASHELP*/ ;
         psp[i].hInstance = winmain_instance;
@@ -278,7 +360,7 @@ void ui_attach_dialog(HWND hwnd)
     psh.hwndParent = hwnd;
     psh.hInstance = winmain_instance;
     psh.pszCaption = "Device manager";
-    psh.nPages = 5;
+    psh.nPages = no_of_drives;
 #ifdef HAVE_UNNAMED_UNIONS
     psh.pszIcon = NULL;
     psh.nStartPage = 0;
