@@ -2,7 +2,7 @@
  * uijoystick.h - Joystick user interface for Win32 platforms.
  *
  * Written by
- *  Tibor Biczo  (crown@mail.matav.hu)
+ *  Tibor Biczo <crown@mail.matav.hu>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -28,5 +28,6 @@
 #define _UIJOYSTICK_H_
 
 void ui_joystick_settings_dialog(HWND hwnd);
+void ui_joystick_swap_joystick(void);
 
 #endif
