@@ -51,8 +51,7 @@ extern const char *archdep_default_save_resource_file_name(void);
 
 /* Logfile stuff.  */
 extern FILE *archdep_open_default_log_file(void);
-extern int archdep_default_logger(const char *level_string, const char *format,
-                                  va_list ap);
+extern int archdep_default_logger(const char *level_string, const char *txt);
 
 /* Launch program `name' (searched via the PATH environment variable)
    passing `argv' as the parameters, wait for it to exit and return its
@@ -61,7 +60,7 @@ extern int archdep_default_logger(const char *level_string, const char *format,
 extern int archdep_spawn(const char *name, char **argv,
                          const char *stdout_redir, const char *stderr_redir);
 
-/* spawn need quoting the params or expanding the filename in some archs */
+/* Spawn need quoting the params or expanding the filename in some archs */
 extern char *archdep_filename_parameter(const char *name);
 extern char *archdep_quote_parameter(const char *name);
 
@@ -71,5 +70,9 @@ extern int archdep_num_text_columns(void);
 /* Allocates a filename for a tempfile */
 extern char *archdep_tmpnam(void);
 
+/* Check file for gzip extension. */
+extern int archdep_file_is_gzip(const char *name);
+extern int archdep_file_set_gzip(const char *name);
+
 #endif
 
