@@ -44,14 +44,5 @@
 #define C128_NTSC_RFSH_PER_SEC    (1.0 / ((double)C128_NTSC_CYCLES_PER_RFSH   \
                                   / (double)C128_NTSC_CYCLES_PER_SEC))
 
-#define C128_NTSCOLD_CYCLES_PER_SEC  1022730
-#define C128_NTSCOLD_CYCLES_PER_LINE 64
-#define C128_NTSCOLD_SCREEN_LINES    262
-#define C128_NTSCOLD_CYCLES_PER_RFSH (C128_NTSCOLD_SCREEN_LINES \
-                                     * C128_NTSCOLD_CYCLES_PER_LINE)
-#define C128_NTSC_OLDRFSH_PER_SEC    (1.0                                    \
-                                     / ((double)C128_NTSCOLD_CYCLES_PER_RFSH \
-                                     / (double)C128_NTSCOLD_CYCLES_PER_SEC))
-
 #endif
 
