@@ -30,8 +30,9 @@
 
 #include "c128mem.h"
 #include "c128mmu.h"
-#include "c64mem.h"
+#include "c64cart.h"
 #include "cmdline.h"
+#include "functionrom.h"
 #include "interrupt.h"
 #include "keyboard.h"
 #include "log.h"
@@ -61,6 +62,8 @@ static int io_in;
 /* State of the 40/80 column key.  */
 static int mmu_column4080_key = 1;
 
+static int mmu_config64;
+
 /* Logging goes here.  */
 static log_t mmu_log = LOG_ERR;
 
@@ -72,19 +75,19 @@ static int set_column4080_key(resource_value_t v, void *param)
 
 #ifdef HAS_SINGLE_CANVAS
     vdc_set_canvas_refresh(mmu_column4080_key ? 0 : 1);
-    vic_ii_set_set_canvas_refresh(mmu_column4080_key ? 1 : 0);
+    vic_ii_set_canvas_refresh(mmu_column4080_key ? 1 : 0);
 #endif
     return 0;
 }
 
 static resource_t resources[] = {
-    { "40/80ColumnKey", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &mmu_column4080_key,
+    { "40/80ColumnKey", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&mmu_column4080_key,
       set_column4080_key, NULL },
     { NULL }
 };
 
-int mmu_init_resources(void)
+int mmu_resources_init(void)
 {
     return resources_register(resources);
 }
@@ -99,7 +102,7 @@ static cmdline_option_t cmdline_options[] = {
     { NULL }
 };
 
-int mmu_init_cmdline_options(void)
+int mmu_cmdline_options_init(void)
 {
     return cmdline_register_options(cmdline_options);
 }
@@ -139,11 +142,38 @@ static void mmu_set_ram_bank(BYTE value)
 #endif
 }
 
+static void mmu_update_config(void)
+{
+#ifdef MMU_DEBUG
+    log_message(mmu_log, "MMU5 %02x, MMU0 %02x, MMUC %02x\n",
+                mmu[5] & 0x40, mmu[0], mmu_config64);
+#endif
+
+    if (mmu[5] & 0x40) {
+        mem_update_config(0x80 + mmu_config64);
+    } else {
+        mem_update_config(((mmu[0] & 0x2) ? 0 : 1)
+                          | ((mmu[0] & 0x0c) >> 1)
+                          | ((mmu[0] & 0x30) >> 1)
+                          | ((mmu[0] & 0x40) ? 32 : 0)
+                          | ((mmu[0] & 0x1) ? 0 : 64));
+        z80mem_update_config((((mmu[0] & 0x1)) ? 0 : 1)
+                          | ((mmu[0] & 0x40) ? 2 : 0)
+                          | ((mmu[0] & 0x80) ? 4 : 0));
+    }
+}
+
+void mmu_set_config64(int config)
+{
+    mmu_config64 = config;
+    mmu_update_config();
+}
+
 /* ------------------------------------------------------------------------- */
 
 BYTE REGPARM1 mmu_read(ADDRESS addr)
 {
-    vic_ii_handle_pending_alarms_external(0);
+    vic_ii_handle_pending_alarms(0);
 
     addr &= 0xff;
 
@@ -154,7 +184,8 @@ BYTE REGPARM1 mmu_read(ADDRESS addr)
     if (addr < 0xb) {
         if (addr == 5) {
             /* 0x80 = 40/80 key released.  */
-            return (mmu[5] & 0x7f) | (mmu_column4080_key ? 0x80 : 0);
+            return (mmu[5] & 0x0f) | (mmu_column4080_key ? 0x80 : 0)
+                   | ((export.game ^ 1) << 4) | ((export.exrom ^ 1) << 5);
         } else {
             return mmu[addr];
         }
@@ -163,11 +194,12 @@ BYTE REGPARM1 mmu_read(ADDRESS addr)
     }
 }
 
+
 void REGPARM2 mmu_store(ADDRESS address, BYTE value)
 {
-    vic_ii_handle_pending_alarms_external(maincpu_num_write_cycles());
+    vic_ii_handle_pending_alarms(maincpu_num_write_cycles());
 
-    address &= 0xff;
+    address &= 0xf;
 
 #ifdef MMU_DEBUG
     log_message(mmu_log, "MMU STORE $%x <- #$%x.", address, value);
@@ -188,9 +220,11 @@ void REGPARM2 mmu_store(ADDRESS address, BYTE value)
             kernal_in = chargen_in = editor_in = !(value & 0x30);
             mmu_set_ram_bank(value);
 #ifdef MMU_DEBUG
-            log_message(mmu_log, "IO: %s BASLO: %s BASHI: %s KERNAL %s.",
+            log_message(mmu_log,
+                        "IO: %s BASLO: %s BASHI: %s KERNAL %s FUNCLO %s.",
                         io_in ? "on" : "off", basic_lo_in ? "on" : "off",
-                        basic_hi_in ? "on" : "off", kernal_in ? "on" : "off");
+                        basic_hi_in ? "on" : "off", kernal_in ? "on" : "off",
+                        ((value & 0xc) == 0x4) ? "on" : "off");
 #endif
             break;
           case 5:
@@ -218,47 +252,46 @@ void REGPARM2 mmu_store(ADDRESS address, BYTE value)
             break;
         }
 
-        mem_update_config(((basic_lo_in) ? 1 : 0) | ((basic_hi_in) ? 2 : 0)
-                          | ((kernal_in) ? 4 : 0) | ((mmu[0] & 0x40) ? 8 : 0)
-                          | ((io_in) ? 16 : 0));
-        z80mem_update_config(((io_in) ? 1 : 0) | ((mmu[0] & 0x40) ? 2 : 0)
-                          | ((mmu[0] & 0x80) ? 4 : 0));
+        mmu_update_config();
     }
 }
 
-/* $FF00 - $FFFF: RAM or Kernal, with MMU at $FF00 - $FF04.  */
+/* $FF00 - $FFFF: RAM, Kernal or internal function ROM, with MMU at
+   $FF00 - $FF04.  */
 BYTE REGPARM1 mmu_ffxx_read(ADDRESS addr)
 {
-    if (addr == 0xff00)
-        return mmu[0];
+    if (addr >= 0xff00 && addr <= 0xff04)
+        return mmu[addr & 0xf];
 
-    if (kernal_in)
-        return read_kernal(addr);
-   
-    return read_top_shared(addr);
+    if ((mmu[0] & 0x30) == 0x00)
+        return kernal_read(addr);
+    if ((mmu[0] & 0x30) == 0x10)
+        return internal_function_rom_read(addr);
+ 
+    return top_shared_read(addr);
 }
 
 BYTE REGPARM1 mmu_ffxx_read_z80(ADDRESS addr)
 {
-    if (addr == 0xff00)
-        return mmu[0];
+    if (addr >= 0xff00 && addr <= 0xff04)
+        return mmu[addr & 0xf];
 
-    return read_top_shared(addr);
+    return top_shared_read(addr);
 }
 
 void REGPARM2 mmu_ffxx_store(ADDRESS addr, BYTE value)
 {
-    if (addr == 0xff00)
-    {
+    if (addr == 0xff00) {
         mmu_store(0, value);
         /* FIXME? [SRT] does reu_dma(-1) work here, or should
         it be deferred until later? */
         reu_dma(-1);
+    } else {
+        if (addr <= 0xff04)
+            mmu_store(0, mmu[addr & 0xf]);
+        else
+            top_shared_store(addr, value);
     }
-    else if (addr <= 0xff04)
-        mmu_store(0, mmu[addr & 0xf]);
-    else
-        store_top_shared(addr, value);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -275,10 +308,10 @@ void mmu_init(void)
 
 void mmu_reset(void)
 {
-    /* FIXME?  Is this the real configuration?  */
-    basic_lo_in = basic_hi_in = kernal_in = editor_in = 1;
-    io_in = 1;
-    chargen_in = 0;
+    ADDRESS i;
+
+    for (i = 0; i < 0xb; i++)
+        mmu[i] = 0;
 
     kbd_register_column4080_key(mmu_toggle_column4080_key);
 }
