@@ -29,6 +29,7 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "c128io.h"
 #include "c128mem.h"
 #include "c128mmu.h"
 #include "c64cia.h"
@@ -99,25 +100,20 @@ static int z80mem_load_bios(void)
 
 static int set_z80bios_rom_name(resource_value_t v, void *param)
 {
-    const char *name = (const char *) v;
-
-    if (z80bios_rom_name != NULL && name != NULL
-        && strcmp(name, z80bios_rom_name) == 0)
+    if (util_string_set(&z80bios_rom_name, (const char *)v))
         return 0;
 
-    string_set(&z80bios_rom_name, name);
-
     return z80mem_load_bios();
 }
 
 static resource_t resources[] = {
-    { "Z80BiosName", RES_STRING, (resource_value_t) "z80bios",
-      (resource_value_t *) &z80bios_rom_name,
+    { "Z80BiosName", RES_STRING, (resource_value_t)"z80bios",
+      (resource_value_t *)&z80bios_rom_name,
       set_z80bios_rom_name, NULL },
     { NULL }
 };
 
-int z80mem_init_resources(void)
+int z80mem_resources_init(void)
 {
     return resources_register(resources);
 }
@@ -129,7 +125,7 @@ static cmdline_option_t cmdline_options[] =
     { NULL }
 };
 
-int z80mem_init_cmdline_options(void)
+int z80mem_cmdline_options_init(void)
 {
     return cmdline_register_options(cmdline_options);
 }
@@ -147,36 +143,36 @@ static BYTE REGPARM1 z80mem_read(ADDRESS addr)
     return _z80mem_read_tab_ptr[addr >> 8](addr);
 }
 
-static BYTE REGPARM1 read_ram(ADDRESS addr)
+static BYTE REGPARM1 ram_read(ADDRESS addr)
 {
     return ram_bank[addr];
 }
 
-static void REGPARM2 store_ram(ADDRESS addr, BYTE value)
+static void REGPARM2 ram_store(ADDRESS addr, BYTE value)
 {
     ram_bank[addr] = value;
 }
 
-static BYTE REGPARM1 read_ram0(ADDRESS addr)
-{
-    return ram[addr];
-}
-
-static void REGPARM2 store_ram0(ADDRESS addr, BYTE value)
-{
-    ram[addr] = value;
-}
-
-BYTE REGPARM1 read_bios(ADDRESS addr)
+BYTE REGPARM1 bios_read(ADDRESS addr)
 {
     return z80bios_rom[addr & 0x0fff];
 }
 
-void REGPARM2 store_bios(ADDRESS addr, BYTE value)
+void REGPARM2 bios_store(ADDRESS addr, BYTE value)
 {
     z80bios_rom[addr] = value;
 }
 
+static BYTE REGPARM1 z80_read_zero(ADDRESS addr)
+{
+    return page_zero[addr];
+}
+
+static void REGPARM2 z80_store_zero(ADDRESS addr, BYTE value)
+{
+    page_zero[addr] = value;
+}
+
 static BYTE REGPARM1 read_one(ADDRESS addr)
 {
     return page_one[addr - 0x100];
@@ -199,7 +195,7 @@ static void REGPARM2 store_unconnected_io(ADDRESS addr, BYTE value)
 }
 
 #ifdef _MSC_VER
-#pragma optimize("",off);
+#pragma optimize("",off)
 #endif
 
 void z80mem_initialize(void)
@@ -215,26 +211,26 @@ void z80mem_initialize(void)
         }
     }
 
-    mem_read_tab[0][0] = read_bios;
-    mem_write_tab[0][0] = store_zero;
-    mem_read_tab[1][0] = read_bios;
-    mem_write_tab[1][0] = store_zero;
-    mem_read_tab[2][0] = read_zero;
-    mem_write_tab[2][0] = store_zero;
-    mem_read_tab[3][0] = read_zero;
-    mem_write_tab[3][0] = store_zero;
-    mem_read_tab[4][0] = read_zero;
-    mem_write_tab[4][0] = store_zero;
-    mem_read_tab[5][0] = read_zero;
-    mem_write_tab[5][0] = store_zero;
-    mem_read_tab[6][0] = read_zero;
-    mem_write_tab[6][0] = store_zero;
-    mem_read_tab[7][0] = read_zero;
-    mem_write_tab[7][0] = store_zero;
+    mem_read_tab[0][0] = bios_read;
+    mem_write_tab[0][0] = z80_store_zero;
+    mem_read_tab[1][0] = bios_read;
+    mem_write_tab[1][0] = z80_store_zero;
+    mem_read_tab[2][0] = z80_read_zero;
+    mem_write_tab[2][0] = z80_store_zero;
+    mem_read_tab[3][0] = z80_read_zero;
+    mem_write_tab[3][0] = z80_store_zero;
+    mem_read_tab[4][0] = z80_read_zero;
+    mem_write_tab[4][0] = z80_store_zero;
+    mem_read_tab[5][0] = z80_read_zero;
+    mem_write_tab[5][0] = z80_store_zero;
+    mem_read_tab[6][0] = z80_read_zero;
+    mem_write_tab[6][0] = z80_store_zero;
+    mem_read_tab[7][0] = z80_read_zero;
+    mem_write_tab[7][0] = z80_store_zero;
  
-    mem_read_tab[0][1] = read_bios;
+    mem_read_tab[0][1] = bios_read;
     mem_write_tab[0][1] = store_one;
-    mem_read_tab[1][1] = read_bios;
+    mem_read_tab[1][1] = bios_read;
     mem_write_tab[1][1] = store_one;
     mem_read_tab[2][1] = read_one;
     mem_write_tab[2][1] = store_one;
@@ -250,124 +246,124 @@ void z80mem_initialize(void)
     mem_write_tab[7][1] = store_one;
 
     for (i = 2; i < 0x10; i++) {
-        mem_read_tab[0][i] = read_bios;
-        mem_write_tab[0][i] = store_ram;
-        mem_read_tab[1][i] = read_bios;
-        mem_write_tab[1][i] = store_ram;
-        mem_read_tab[2][i] = read_lo;
-        mem_write_tab[2][i] = store_lo;
-        mem_read_tab[3][i] = read_lo;
-        mem_write_tab[3][i] = store_lo;
-        mem_read_tab[4][i] = read_ram;
-        mem_write_tab[4][i] = store_ram;
-        mem_read_tab[5][i] = read_ram;
-        mem_write_tab[5][i] = store_ram;
-        mem_read_tab[6][i] = read_lo;
-        mem_write_tab[6][i] = store_lo;
-        mem_read_tab[7][i] = read_lo;
-        mem_write_tab[7][i] = store_lo;
+        mem_read_tab[0][i] = bios_read;
+        mem_write_tab[0][i] = ram_store;
+        mem_read_tab[1][i] = bios_read;
+        mem_write_tab[1][i] = ram_store;
+        mem_read_tab[2][i] = lo_read;
+        mem_write_tab[2][i] = lo_store;
+        mem_read_tab[3][i] = lo_read;
+        mem_write_tab[3][i] = lo_store;
+        mem_read_tab[4][i] = ram_read;
+        mem_write_tab[4][i] = ram_store;
+        mem_read_tab[5][i] = ram_read;
+        mem_write_tab[5][i] = ram_store;
+        mem_read_tab[6][i] = lo_read;
+        mem_write_tab[6][i] = lo_store;
+        mem_read_tab[7][i] = lo_read;
+        mem_write_tab[7][i] = lo_store;
     }
 
     for (i = 0x10; i <= 0x13; i++) {
-        mem_read_tab[0][i] = read_ram;
-        mem_write_tab[0][i] = store_ram;
+        mem_read_tab[0][i] = ram_read;
+        mem_write_tab[0][i] = ram_store;
         mem_read_tab[1][i] = colorram_read;
         mem_write_tab[1][i] = colorram_store;
-        mem_read_tab[2][i] = read_lo;
-        mem_write_tab[2][i] = store_lo;
+        mem_read_tab[2][i] = lo_read;
+        mem_write_tab[2][i] = lo_store;
         mem_read_tab[3][i] = colorram_read;
         mem_write_tab[3][i] = colorram_store;
-        mem_read_tab[4][i] = read_ram;
-        mem_write_tab[4][i] = store_ram;
+        mem_read_tab[4][i] = ram_read;
+        mem_write_tab[4][i] = ram_store;
         mem_read_tab[5][i] = colorram_read;
         mem_write_tab[5][i] = colorram_store;
-        mem_read_tab[6][i] = read_lo;
-        mem_write_tab[6][i] = store_lo;
+        mem_read_tab[6][i] = lo_read;
+        mem_write_tab[6][i] = lo_store;
         mem_read_tab[7][i] = colorram_read;
         mem_write_tab[7][i] = colorram_store;
     }
 
     for (i = 0x14; i <= 0x3f; i++) {
-        mem_read_tab[0][i] = read_ram;
-        mem_write_tab[0][i] = store_ram;
-        mem_read_tab[1][i] = read_ram;
-        mem_write_tab[1][i] = store_ram;
-        mem_read_tab[2][i] = read_lo;
-        mem_write_tab[2][i] = store_lo;
-        mem_read_tab[3][i] = read_lo;
-        mem_write_tab[3][i] = store_lo;
-        mem_read_tab[4][i] = read_ram;
-        mem_write_tab[4][i] = store_ram;
-        mem_read_tab[5][i] = read_ram;
-        mem_write_tab[5][i] = store_ram;
-        mem_read_tab[6][i] = read_lo;
-        mem_write_tab[6][i] = store_lo;
-        mem_read_tab[7][i] = read_lo;
-        mem_write_tab[7][i] = store_lo;
+        mem_read_tab[0][i] = ram_read;
+        mem_write_tab[0][i] = ram_store;
+        mem_read_tab[1][i] = ram_read;
+        mem_write_tab[1][i] = ram_store;
+        mem_read_tab[2][i] = lo_read;
+        mem_write_tab[2][i] = lo_store;
+        mem_read_tab[3][i] = lo_read;
+        mem_write_tab[3][i] = lo_store;
+        mem_read_tab[4][i] = ram_read;
+        mem_write_tab[4][i] = ram_store;
+        mem_read_tab[5][i] = ram_read;
+        mem_write_tab[5][i] = ram_store;
+        mem_read_tab[6][i] = lo_read;
+        mem_write_tab[6][i] = lo_store;
+        mem_read_tab[7][i] = lo_read;
+        mem_write_tab[7][i] = lo_store;
     }
 
     for (j = 0; j < NUM_CONFIGS; j++) {
         for (i = 0x40; i <= 0xbf; i++) {
-            mem_read_tab[j][i] = read_ram;
-            mem_write_tab[j][i] = store_ram;
+            mem_read_tab[j][i] = ram_read;
+            mem_write_tab[j][i] = ram_store;
         }
     }
 
     for (i = 0xc0; i <= 0xcf; i++) {
-        mem_read_tab[0][i] = read_ram;
-        mem_write_tab[0][i] = store_ram;
-        mem_read_tab[1][i] = read_ram;
-        mem_write_tab[1][i] = store_ram;
-        mem_read_tab[2][i] = read_top_shared;
-        mem_write_tab[2][i] = store_top_shared;
-        mem_read_tab[3][i] = read_top_shared;
-        mem_write_tab[3][i] = store_top_shared;
-        mem_read_tab[4][i] = read_ram;
-        mem_write_tab[4][i] = store_ram;
-        mem_read_tab[5][i] = read_ram;
-        mem_write_tab[5][i] = store_ram;
-        mem_read_tab[6][i] = read_top_shared;
-        mem_write_tab[6][i] = store_top_shared;
-        mem_read_tab[7][i] = read_top_shared;
-        mem_write_tab[7][i] = store_top_shared;
+        mem_read_tab[0][i] = ram_read;
+        mem_write_tab[0][i] = ram_store;
+        mem_read_tab[1][i] = ram_read;
+        mem_write_tab[1][i] = ram_store;
+        mem_read_tab[2][i] = top_shared_read;
+        mem_write_tab[2][i] = top_shared_store;
+        mem_read_tab[3][i] = top_shared_read;
+        mem_write_tab[3][i] = top_shared_store;
+        mem_read_tab[4][i] = ram_read;
+        mem_write_tab[4][i] = ram_store;
+        mem_read_tab[5][i] = ram_read;
+        mem_write_tab[5][i] = ram_store;
+        mem_read_tab[6][i] = top_shared_read;
+        mem_write_tab[6][i] = top_shared_store;
+        mem_read_tab[7][i] = top_shared_read;
+        mem_write_tab[7][i] = top_shared_store;
     }
 
     for (i = 0xd0; i <= 0xdf; i++) {
-        mem_read_tab[0][i] = read_ram;
-        mem_write_tab[0][i] = store_ram;
-        mem_read_tab[1][i] = read_ram;
-        mem_write_tab[1][i] = store_ram;
-        mem_read_tab[2][i] = read_top_shared;
-        mem_write_tab[2][i] = store_top_shared;
-        mem_read_tab[3][i] = read_top_shared;
-        mem_write_tab[3][i] = store_top_shared;
-        mem_read_tab[4][i] = read_ram;
-        mem_write_tab[4][i] = store_ram;
-        mem_read_tab[5][i] = read_ram;
-        mem_write_tab[5][i] = store_ram;
-        mem_read_tab[6][i] = read_top_shared;
-        mem_write_tab[6][i] = store_top_shared;
-        mem_read_tab[7][i] = read_top_shared;
-        mem_write_tab[7][i] = store_top_shared;
+        mem_read_tab[0][i] = ram_read;
+        mem_write_tab[0][i] = ram_store;
+        mem_read_tab[1][i] = ram_read;
+        mem_write_tab[1][i] = ram_store;
+        mem_read_tab[2][i] = top_shared_read;
+        mem_write_tab[2][i] = top_shared_store;
+        mem_read_tab[3][i] = top_shared_read;
+        mem_write_tab[3][i] = top_shared_store;
+        mem_read_tab[4][i] = ram_read;
+        mem_write_tab[4][i] = ram_store;
+        mem_read_tab[5][i] = ram_read;
+        mem_write_tab[5][i] = ram_store;
+        mem_read_tab[6][i] = top_shared_read;
+        mem_write_tab[6][i] = top_shared_store;
+        mem_read_tab[7][i] = top_shared_read;
+        mem_write_tab[7][i] = top_shared_store;
     }
 
     for (i = 0xe0; i <= 0xfe; i++) {
-        mem_read_tab[0][i] = read_ram;
-        mem_write_tab[0][i] = store_ram;
-        mem_read_tab[1][i] = read_ram;
-        mem_write_tab[1][i] = store_ram;
-        mem_read_tab[2][i] = read_top_shared;
-        mem_write_tab[2][i] = store_top_shared;
-        mem_read_tab[3][i] = read_top_shared;
-        mem_write_tab[3][i] = store_top_shared;
-        mem_read_tab[4][i] = read_ram;
-        mem_write_tab[4][i] = store_ram;
-        mem_read_tab[5][i] = read_ram;
-        mem_write_tab[5][i] = store_ram;
-        mem_read_tab[6][i] = read_top_shared;
-        mem_write_tab[6][i] = store_top_shared;
-        mem_read_tab[7][i] = read_top_shared;
-        mem_write_tab[7][i] = store_top_shared;
+        mem_read_tab[0][i] = ram_read;
+        mem_write_tab[0][i] = ram_store;
+        mem_read_tab[1][i] = ram_read;
+        mem_write_tab[1][i] = ram_store;
+        mem_read_tab[2][i] = top_shared_read;
+        mem_write_tab[2][i] = top_shared_store;
+        mem_read_tab[3][i] = top_shared_read;
+        mem_write_tab[3][i] = top_shared_store;
+        mem_read_tab[4][i] = ram_read;
+        mem_write_tab[4][i] = ram_store;
+        mem_read_tab[5][i] = ram_read;
+        mem_write_tab[5][i] = ram_store;
+        mem_read_tab[6][i] = top_shared_read;
+        mem_write_tab[6][i] = top_shared_store;
+        mem_read_tab[7][i] = top_shared_read;
+        mem_write_tab[7][i] = top_shared_store;
     }
 
     for (j = 0; j < NUM_CONFIGS; j++) {
@@ -441,7 +437,7 @@ void z80mem_initialize(void)
 }
 
 #ifdef _MSC_VER
-#pragma optimize("",on);
+#pragma optimize("",on)
 #endif
 
 void z80mem_set_bank_pointer(BYTE **base, int *limit)
