@@ -2,7 +2,7 @@
  * c64datasette.c - C64 specific CBM cassette implementation.
  *
  * Written by
- *  Andreas Boose (boose@linux.rz.fh-hannover.de)
+ *  Andreas Boose <boose@linux.rz.fh-hannover.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -27,10 +27,15 @@
 #include "vice.h"
 
 #include "c64cia.h"
-#include "datasette.h"
+#include "c64mem.h"
 
 void datasette_trigger_flux_change(void)
 {
     cia1_set_flag();
 }
 
+void datasette_set_tape_sense(int sense)
+{
+    mem_set_tape_sense(sense);
+}
+
