@@ -35,67 +35,35 @@
 #include <sys/types.h>
 #endif
 
-#include "archdep.h"
+#include "c64-snapshot.h"
+#include "c64-resources.h"
 #include "c64cart.h"
 #include "c64cia.h"
+#include "c64io.h"
 #include "c64mem.h"
+#include "c64memlimit.h"
+#include "c64pla.h"
 #include "cartridge.h"
-#include "cmdline.h"
-#include "datasette.h"
-#include "emuid.h"
 #include "interrupt.h"
 #include "log.h"
 #include "maincpu.h"
+#include "mem.h"
 #include "mon.h"
 #include "parallel.h"
 #include "patchrom.h"
 #include "resources.h"
 #include "reu.h"
 #include "sid.h"
-#include "snapshot.h"
 #include "sysfile.h"
-#include "ui.h"
 #include "utils.h"
 #include "vicii-mem.h"
 #include "vicii.h"
 
-#ifdef HAVE_RS232
-#include "c64acia.h"
-#endif
-
-/* ------------------------------------------------------------------------- */
-
-static int mem_load_kernal(void);
-static int mem_load_basic(void);
-static int mem_load_chargen(void);
 
 /* ------------------------------------------------------------------------- */
 
 /* C64 memory-related resources.  */
 
-/* Name of the character ROM.  */
-static char *chargen_rom_name = NULL;
-
-/* Name of the BASIC ROM.  */
-static char *basic_rom_name = NULL;
-
-/* Name of the Kernal ROM.  */
-static char *kernal_rom_name = NULL;
-
-/* Kernal revision for ROM patcher.  */
-static char *kernal_revision;
-
-/* Flag: Do we enable the Emulator ID?  */
-static int emu_id_enabled;
-
-/* Flag: Do we enable the external REU?  */
-static int reu_enabled;
-
-#ifdef HAVE_RS232
-/* Flag: Do we enable the $DE** ACIA RS232 interface emulation?  */
-static int acia_de_enabled;
-#endif
-
 /* Adjust this pointer when the MMU changes banks.  */
 static BYTE **bank_base;
 static int *bank_limit = NULL;
@@ -104,197 +72,11 @@ unsigned int old_reg_pc;
 const char *mem_romset_resources_list[] = {
     "KernalName", "ChargenName", "BasicName",
     "CartridgeType", "CartridgeFile",
-    "DosName2031", "DosName1001", 
+    "DosName2031", "DosName1001",
     "DosName1541", "DosName1571", "DosName1581", "DosName1541ii",
     NULL
 };
 
-
-static int set_chargen_rom_name(resource_value_t v, void *param)
-{
-    const char *name = (const char *) v;
-
-    if (chargen_rom_name != NULL && name != NULL
-        && strcmp(name, chargen_rom_name) == 0)
-        return 0;
-
-    string_set(&chargen_rom_name, name);
-
-    return mem_load_chargen();
-}
-
-static int set_kernal_rom_name(resource_value_t v, void *param)
-{
-    const char *name = (const char *) v;
-
-    if (kernal_rom_name != NULL && name != NULL
-        && strcmp(name, kernal_rom_name) == 0)
-        return 0;
-
-    string_set(&kernal_rom_name, name);
-
-    return mem_load_kernal();
-}
-
-static int set_basic_rom_name(resource_value_t v, void *param)
-{
-    const char *name = (const char *) v;
-
-    if (basic_rom_name != NULL
-        && name != NULL
-        && strcmp(name, basic_rom_name) == 0)
-        return 0;
-
-    string_set(&basic_rom_name, name);
-
-    return mem_load_basic();
-}
-
-static int set_emu_id_enabled(resource_value_t v, void *param)
-{
-    if (!(int) v) {
-        emu_id_enabled = 0;
-        return 0;
-    } else if (mem_cartridge_type == CARTRIDGE_NONE) {
-        emu_id_enabled = 1;
-        return 0;
-    } else {
-        /* Other extensions share the same address space, so they cannot be
-           enabled at the same time.  */
-        return -1;
-    }
-}
-
-/*
- * Some cartridges can coexist with the REU.
- * This list might not be complete, but atleast these are known (to me -> nathan)
- * to work. Feel free to add more coexisting cartridges to this list.
- */
-static int reu_coexist_cartridge(void)
-{
-	int result;
-
-	switch (mem_cartridge_type)
-		{
-		case (CARTRIDGE_NONE):
-		case (CARTRIDGE_SUPER_SNAPSHOT_V5):
-		case (CARTRIDGE_EXPERT):
-			result = TRUE;
-			break;
-		default:
-			result = FALSE;
-		}
-
-	return result;
-}
-
-/* FIXME: Should initialize the REU when turned on.  */
-static int set_reu_enabled(resource_value_t v, void *param)
-{
-    if (!(int) v) {
-        reu_enabled = 0;
-        reu_deactivate();
-        return 0;
-    } else if (reu_coexist_cartridge() == TRUE) {
-        reu_enabled = 1;
-        reu_activate();
-        return 0;
-    } else {
-        /* The REU and the IEEE488 interface share the same address space, so
-           they cannot be enabled at the same time.  */
-        return -1;
-    }
-}
-
-/* FIXME: Should patch the ROM on-the-fly.  */
-static int set_kernal_revision(resource_value_t v, void *param)
-{
-    const char *rev = (const char *) v;
-
-    string_set(&kernal_revision, rev);
-    return 0;
-}
-
-#ifdef HAVE_RS232
-
-static int set_acia_de_enabled(resource_value_t v, void *param)
-{
-    acia_de_enabled = (int) v;
-    return 0;
-}
-
-#endif
-
-static resource_t resources[] = {
-    { "ChargenName", RES_STRING, (resource_value_t) "chargen",
-      (resource_value_t *) &chargen_rom_name,
-      set_chargen_rom_name, NULL },
-    { "KernalName", RES_STRING, (resource_value_t) "kernal",
-      (resource_value_t *) &kernal_rom_name,
-      set_kernal_rom_name, NULL },
-    { "BasicName", RES_STRING, (resource_value_t) "basic",
-      (resource_value_t *) &basic_rom_name,
-      set_basic_rom_name, NULL },
-    { "REU", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &reu_enabled,
-      set_reu_enabled, NULL },
-    { "EmuID", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &emu_id_enabled,
-      set_emu_id_enabled, NULL },
-    { "KernalRev", RES_STRING, (resource_value_t) NULL,
-      (resource_value_t *) &kernal_revision,
-      set_kernal_revision, NULL },
-#ifdef HAVE_RS232
-    { "AciaDE", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &acia_de_enabled,
-      set_acia_de_enabled, NULL },
-#endif
-    { NULL }
-};
-
-int c64_mem_init_resources(void)
-{
-    return resources_register(resources);
-}
-
-/* ------------------------------------------------------------------------- */
-
-/* C64 memory-related command-line options.  */
-/* FIXME: Maybe the `-kernal', `-basic' and `-chargen' options should not
-   really affect resources.  */
-
-static cmdline_option_t cmdline_options[] =
-{
-    { "-kernal", SET_RESOURCE, 1, NULL, NULL, "KernalName", NULL,
-      "<name>", "Specify name of Kernal ROM image" },
-    { "-basic", SET_RESOURCE, 1, NULL, NULL, "BasicName", NULL,
-      "<name>", "Specify name of BASIC ROM image" },
-    { "-chargen", SET_RESOURCE, 1, NULL, NULL, "ChargenName", NULL,
-      "<name>", "Specify name of character generator ROM image" },
-    { "-reu", SET_RESOURCE, 0, NULL, NULL, "REU", (resource_value_t) 1,
-      NULL, "Enable the 512K RAM expansion unit" },
-    { "+reu", SET_RESOURCE, 0, NULL, NULL, "REU", (resource_value_t) 0,
-      NULL, "Disable the 512K RAM expansion unit" },
-    { "-emuid", SET_RESOURCE, 0, NULL, NULL, "EmuID", (resource_value_t) 1,
-      NULL, "Enable emulator identification" },
-    { "+emuid", SET_RESOURCE, 0, NULL, NULL, "EmuID", (resource_value_t) 0,
-      NULL, "Disable emulator identification" },
-    { "-kernalrev", SET_RESOURCE, 1, NULL, NULL, "KernalRev", NULL,
-      "<revision>", "Patch the Kernal ROM to the specified <revision>" },
-#ifdef HAVE_RS232
-    { "-acia1", SET_RESOURCE, 0, NULL, NULL, "AciaDE", (resource_value_t) 1,
-      NULL, "Enable the $DE** ACIA RS232 interface emulation" },
-    { "+acia1", SET_RESOURCE, 0, NULL, NULL, "AciaDE", (resource_value_t) 0,
-      NULL, "Disable the $DE** ACIA RS232 interface emulation" },
-#endif
-    { NULL }
-};
-
-int c64_mem_init_cmdline_options(void)
-{
-    return cmdline_register_options(cmdline_options);
-}
-
 /* ------------------------------------------------------------------------- */
 
 /* Number of possible memory configurations.  */
@@ -332,11 +114,6 @@ static read_func_ptr_t mem_read_tab_watch[0x101];
 static store_func_ptr_t mem_write_tab_orig[NUM_VBANKS][NUM_CONFIGS][0x101];
 static read_func_ptr_t mem_read_tab_orig[NUM_CONFIGS][0x101];
 
-/* Processor port.  */
-static struct {
-    BYTE dir, data, data_out;
-} pport;
-
 /* Current video bank (0, 1, 2 or 3).  */
 static int vbank;
 
@@ -346,12 +123,6 @@ static int mem_config;
 /* Tape sense status: 1 = some button pressed, 0 = no buttons pressed.  */
 static int tape_sense = 0;
 
-/* Tape motor status.  */
-static BYTE old_port_data_out = 0xff;
-
-/* Tape write line status.  */
-static BYTE old_port_write_bit = 0xff;
-
 /* Logging goes here.  */
 static log_t c64_mem_log = LOG_ERR;
 
@@ -377,28 +148,7 @@ inline void pla_config_changed(void)
     mem_config = (((~pport.dir | pport.data) & 0x7) | (export.exrom << 3)
                   | (export.game << 4));
 
-    pport.data_out = (pport.data_out & ~pport.dir)
-                     | (pport.data & pport.dir);
-
-    ram[1] = ((pport.data | ~pport.dir) & (pport.data_out | 0x17));
-
-    if (!(pport.dir & 0x20))
-      ram[1] &= 0xdf;
-
-    if (tape_sense && !(pport.dir & 0x10))
-      ram[1] &= 0xef;
-
-    if (((pport.dir & pport.data) & 0x20) != old_port_data_out) {
-        old_port_data_out = (pport.dir & pport.data) & 0x20;
-        datasette_set_motor(!old_port_data_out);
-    }
-
-    if (((~pport.dir | pport.data) & 0x8) != old_port_write_bit) {
-        old_port_write_bit = (~pport.dir | pport.data) & 0x8;
-        datasette_toggle_write_bit((~pport.dir | pport.data) & 0x8);
-    }
-
-    ram[0] = pport.dir;
+    c64pla_config_changed(tape_sense, 0);
 
     if (any_watchpoints(e_comp_space)) {
         _mem_read_tab_ptr = mem_read_tab_watch;
@@ -414,7 +164,7 @@ inline void pla_config_changed(void)
     if (bank_limit != NULL) {
         *bank_base = _mem_read_base_tab_ptr[old_reg_pc >> 8];
         if (*bank_base != 0)
-            *bank_base = _mem_read_base_tab_ptr[old_reg_pc >> 8] 
+            *bank_base = _mem_read_base_tab_ptr[old_reg_pc >> 8]
                          - (old_reg_pc & 0xff00);
         *bank_limit = mem_read_limit_tab_ptr[old_reg_pc >> 8];
     }
@@ -483,59 +233,14 @@ void REGPARM2 ram_store(ADDRESS addr, BYTE value)
     ram[addr] = value;
 }
 
-void REGPARM2 store_ram_hi(ADDRESS addr, BYTE value)
+void REGPARM2 ram_hi_store(ADDRESS addr, BYTE value)
 {
     ram[addr] = value;
-    if (reu_enabled && addr == 0xff00)
+
+    if (addr == 0xff00)
         reu_dma(-1);
 }
 
-void REGPARM2 io2_store(ADDRESS addr, BYTE value)
-{
-    if (mem_cartridge_type != CARTRIDGE_NONE)
-        cartridge_store_io2(addr, value);
-    if (reu_enabled)
-        reu_store((ADDRESS)(addr & 0x0f), value);
-    return;
-}
-
-BYTE REGPARM1 io2_read(ADDRESS addr)
-{
-    if (mem_cartridge_type != CARTRIDGE_NONE)
-        return cartridge_read_io2(addr);
-    if (emu_id_enabled && addr >= 0xdfa0) {
-        addr &= 0xff;
-        if (addr == 0xff)
-            emulator_id[addr - 0xa0] ^= 0xff;
-        return emulator_id[addr - 0xa0];
-    }
-    if (reu_enabled)
-        return reu_read((ADDRESS)(addr & 0x0f));
-    return rand();
-}
-
-void REGPARM2 io1_store(ADDRESS addr, BYTE value)
-{
-    if (mem_cartridge_type != CARTRIDGE_NONE)
-        cartridge_store_io1(addr, value);
-#ifdef HAVE_RS232
-    if (acia_de_enabled)
-        acia1_store(addr & 0x03, value);
-#endif
-    return;
-}
-
-BYTE REGPARM1 io1_read(ADDRESS addr)
-{
-    if (mem_cartridge_type != CARTRIDGE_NONE)
-        return cartridge_read_io1(addr);
-#ifdef HAVE_RS232
-    if (acia_de_enabled)
-        return acia1_read(addr & 0x03);
-#endif
-    return rand();
-}
-
 BYTE REGPARM1 rom_read(ADDRESS addr)
 {
     switch (addr & 0xf000) {
@@ -573,27 +278,27 @@ void REGPARM2 rom_store(ADDRESS addr, BYTE value)
 
 static void REGPARM2 cartridge_decode_store(ADDRESS addr, BYTE value)
 {
-	/*
-	 * Enable cartridge first before making an access.
-	 */
-	cartridge_decode_address(addr);
+    /*
+     * Enable cartridge first before making an access.
+     */
+    cartridge_decode_address(addr);
 
-	/*
-	 * Store data at the decoded address.
-	 */
-	mem_write_tab_orig[vbank][mem_config][addr >> 8](addr, value);
+    /*
+     * Store data at the decoded address.
+     */
+    mem_write_tab_orig[vbank][mem_config][addr >> 8](addr, value);
 }
 
 static BYTE REGPARM1 cartridge_decode_read(ADDRESS addr)
 {
-	/*
-	 * Enable cartridge first before making an access.
-	 */
-	cartridge_decode_address(addr);
+    /*
+     * Enable cartridge first before making an access.
+     */
+    cartridge_decode_address(addr);
 
-	/*
-	 * Read data from decoded address.
-	 */
+    /*
+     * Read data from decoded address.
+     */
     return mem_read_tab_orig[mem_config][addr >> 8](addr);
 }
 
@@ -613,7 +318,7 @@ BYTE REGPARM1 mem_read(ADDRESS addr)
 
 /* ------------------------------------------------------------------------- */
 
-static void set_write_hook(int config, int page, store_func_t * f)
+static void set_write_hook(int config, int page, store_func_t *f)
 {
     int i;
 
@@ -622,7 +327,7 @@ static void set_write_hook(int config, int page, store_func_t * f)
     }
 }
 
-void initialize_memory(void)
+void mem_initialize_memory(void)
 {
     int i, j, k;
     /* IO is enabled at memory configs 5, 6, 7 and Ultimax.  */
@@ -642,37 +347,7 @@ void initialize_memory(void)
                              0xe0, 0xe0, 0xe0, 0xe0, 0xe0, 0xe0, 0xe0, 0xe0,
                              0x00, 0x00, 0xa0, 0xa0, 0x00, 0x00, 0xa0, 0xa0 };
 
-    int limit_tab[6][NUM_CONFIGS] = {
-    /* 0000-7fff */
-    { 0xfffd, 0xcffd, 0xcffd, 0x9ffd, 0xfffd, 0xcffd, 0xcffd, 0x9ffd,
-      0xfffd, 0xcffd, 0x9ffd, 0x7ffd, 0xfffd, 0xcffd, 0x9ffd, 0x7ffd,
-      0x7ffd, 0x7ffd, 0x7ffd, 0x7ffd, 0x7ffd, 0x7ffd, 0x7ffd, 0x7ffd,
-      0xfffd, 0xcffd, 0x9ffd, 0x7ffd, 0xfffd, 0xcffd, 0x9ffd, 0x7ffd },
-    /* 8000-9fff */
-    { 0xfffd, 0xcffd, 0xcffd, 0x9ffd, 0xfffd, 0xcffd, 0xcffd, 0x9ffd,
-      0xfffd, 0xcffd, 0x9ffd,     -1, 0xfffd, 0xcffd, 0x9ffd,     -1,
-          -1,     -1,     -1,     -1,     -1,     -1,     -1,     -1,
-      0xfffd, 0xcffd, 0x9ffd,     -1, 0xfffd, 0xcffd, 0x9ffd,     -1 },
-    /* a000-bfff */
-    { 0xfffd, 0xcffd, 0xcffd, 0xbffd, 0xfffd, 0xcffd, 0xcffd, 0xbffd,
-      0xfffd, 0xcffd,     -1,     -1, 0xfffd, 0xcffd,     -1,     -1,
-          -1,     -1,     -1,     -1,     -1,     -1,     -1,     -1,
-      0xfffd, 0xcffd,     -1,     -1, 0xfffd, 0xcffd,     -1,     -1 },
-    /* c000-cfff */
-    { 0xfffd, 0xcffd, 0xcffd, 0xcffd, 0xfffd, 0xcffd, 0xcffd, 0xcffd,
-      0xfffd, 0xcffd, 0xcffd, 0xcffd, 0xfffd, 0xcffd, 0xcffd, 0xcffd,
-      0xcffd, 0xcffd, 0xcffd, 0xcffd, 0xcffd, 0xcffd, 0xcffd, 0xcffd,
-      0xfffd, 0xcffd, 0xcffd, 0xcffd, 0xfffd, 0xcffd, 0xcffd, 0xcffd },
-    /* d000-dfff */
-    { 0xfffd, 0xdffd, 0xdffd, 0xdffd, 0xfffd,     -1,     -1,     -1,
-      0xfffd, 0xdffd, 0xdffd, 0xdffd, 0xfffd,     -1,     -1,     -1,
-          -1,     -1,     -1,     -1,     -1,     -1,     -1,     -1,
-      0xfffd, 0xdffd, 0xdffd, 0xdffd, 0xfffd,     -1,     -1,     -1 },
-    /* e000-ffff */
-    { 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
-      0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
-          -1,     -1,     -1,     -1,     -1,     -1,     -1,     -1,
-      0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd } };
+    mem_limit_init(mem_read_limit_tab);
 
 /*
     if (c64_mem_log == LOG_ERR)
@@ -688,22 +363,20 @@ void initialize_memory(void)
         set_write_hook(i, 0, store_zero);
         mem_read_tab[i][0] = read_zero;
         mem_read_base_tab[i][0] = ram;
-        mem_read_limit_tab[i][0] = 0xfffd;
         for (j = 1; j <= 0xfe; j++) {
             mem_read_tab[i][j] = ram_read;
             mem_read_base_tab[i][j] = ram + (j << 8);
-            mem_read_limit_tab[i][j] = 0xfffd;
             for (k = 0; k < NUM_VBANKS; k++) {
                 if ((j & 0xc0) == (k << 6)) {
-                    switch (j & 0x3fff) {
+                    switch (j & 0x3f) {
                       case 0x39:
-                        mem_write_tab[k][i][j] = store_vbank_39xx;
+                        mem_write_tab[k][i][j] = vicii_mem_vbank_39xx_store;
                         break;
                       case 0x3f:
-                        mem_write_tab[k][i][j] = store_vbank_3fxx;
+                        mem_write_tab[k][i][j] = vicii_mem_vbank_3fxx_store;
                         break;
                       default:
-                        mem_write_tab[k][i][j] = store_vbank;
+                        mem_write_tab[k][i][j] = vicii_mem_vbank_store;
                     }
                 } else {
                     mem_write_tab[k][i][j] = ram_store;
@@ -712,13 +385,12 @@ void initialize_memory(void)
         }
         mem_read_tab[i][0xff] = ram_read;
         mem_read_base_tab[i][0xff] = ram + 0xff00;
-        mem_read_limit_tab[i][0xff] = 0xfffd;
 
         /* FIXME: we do not care about vbank writes here, but we probably
            should.  Anyway, the $FFxx addresses are not so likely to contain
            sprites or other stuff that really needs the special handling, and
            it's much easier this way.  */
-        set_write_hook(i, 0xff, store_ram_hi);
+        set_write_hook(i, 0xff, ram_hi_store);
     }
 
     /* Setup BASIC ROM at $A000-$BFFF (memory configs 3, 7, 11, 15).  */
@@ -824,17 +496,17 @@ void initialize_memory(void)
     for (j = 0; j < NUM_CONFIGS; j++) {
         if (roml_config[j]) {
             for (i = 0x80; i <= 0x9f; i++) {
-                mem_read_tab[j][i] = read_roml;
+                mem_read_tab[j][i] = roml_read;
                 mem_read_base_tab[j][i] = NULL;
             }
         }
     }
     for (j = 16; j < 24; j++) {
         for (i = 0x80; i <= 0x9f; i++)
-            set_write_hook(j, i, store_roml);
+            set_write_hook(j, i, roml_store);
         for (i = 0xa0; i <= 0xbf; i++) {
-            mem_read_tab[j][i] = read_ultimax_a000_bfff;
-            set_write_hook(j, i, store_ultimax_a000_bfff);
+            mem_read_tab[j][i] = ultimax_a000_bfff_read;
+            set_write_hook(j, i, ultimax_a000_bfff_store);
         }
     }
 
@@ -842,7 +514,7 @@ void initialize_memory(void)
     for (j = 0; j < NUM_CONFIGS; j++) {
         if (romh_config[j]) {
             for (i = romh_mapping[j]; i <= (romh_mapping[j] + 0x1f); i++) {
-                mem_read_tab[j][i] = read_romh;
+                mem_read_tab[j][i] = romh_read;
                 mem_read_base_tab[j][i] = NULL;
             }
         }
@@ -854,17 +526,6 @@ void initialize_memory(void)
             mem_write_tab[j][i][0x100] = mem_write_tab[j][i][0];
         }
         mem_read_base_tab[i][0x100] = mem_read_base_tab[i][0];
-        mem_read_limit_tab[i][0x100] = 0;
-    }
-
-    for (i = 0; i < NUM_CONFIGS; i++) {
-        int mstart[6] = { 0x00, 0x80, 0xa0, 0xc0, 0xd0, 0xe0 };
-        int mend[6]   = { 0x7f, 0x9f, 0xbf, 0xcf, 0xdf, 0xff };
-        for (j = 0; j < 6; j++) {
-            for (k = mstart[j]; k <= mend[j]; k++) {
-                mem_read_limit_tab[i][k] = limit_tab[j][i];
-            }
-        }
     }
 
     _mem_read_tab_ptr = mem_read_tab[7];
@@ -877,65 +538,61 @@ void initialize_memory(void)
     export.exrom = 0;
     export.game = 0;
 
-	/*
-	 * Copy mapping to a separate table.
-	 * This table will contain the original (unmodified) mapping.
-	 */
-	memcpy(mem_write_tab_orig, mem_write_tab, NUM_VBANKS*sizeof(*mem_write_tab));
-	memcpy(mem_read_tab_orig, mem_read_tab, NUM_CONFIGS*sizeof(*mem_read_tab));
+    /*
+     * Copy mapping to a separate table.
+     * This table will contain the original (unmodified) mapping.
+     */
+    memcpy(mem_write_tab_orig, mem_write_tab,
+           NUM_VBANKS * sizeof(*mem_write_tab));
+    memcpy(mem_read_tab_orig, mem_read_tab,
+           NUM_CONFIGS * sizeof(*mem_read_tab));
 
-	/*
-	 * Change address decoding.
-	 */
-	if (mem_cartridge_type == CARTRIDGE_EXPERT)
-		{
-		/*
-		 * Mapping for ~GAME disabled
-		 */
-		for (j = 0; j < 16; j++)
-			{
-			for (i = 0x80; i <= 0x9f; i++)
-				{
-				/* $8000 - $9FFF */
-				mem_read_tab[j][i] = cartridge_decode_read;
+    /*
+     * Change address decoding.
+     */
+    if (mem_cartridge_type == CARTRIDGE_EXPERT) {
 
-				/* Setup writing at $8000-$9FFF */
-				set_write_hook(j, i, cartridge_decode_store);
+        /*
+         * Mapping for ~GAME disabled
+         */
+        for (j = 0; j < 16; j++) {
+            for (i = 0x80; i <= 0x9f; i++) {
+                /* $8000 - $9FFF */
+                mem_read_tab[j][i] = cartridge_decode_read;
 
-				/* $E000 - $FFFF */
-				mem_read_tab[j][i+0x60] = cartridge_decode_read;
+                /* Setup writing at $8000-$9FFF */
+                set_write_hook(j, i, cartridge_decode_store);
 
-				/* Setup writing at $E000-$FFFF */
-				set_write_hook(j, i+0x60, cartridge_decode_store);
-				}
-			}
+                /* $E000 - $FFFF */
+                mem_read_tab[j][i + 0x60] = cartridge_decode_read;
+                /* Setup writing at $E000-$FFFF */
+                set_write_hook(j, i + 0x60, cartridge_decode_store);
+            }
+        }
 
-		/*
-		 * Mapping for ~GAME enabled.
-		 */
-		for (j = 16; j < NUM_CONFIGS; j++)
-			{
-			/* $0000 - $7FFF */
-			for (i = 0x00; i <= 0x7f; i++)
-				{
-				/* Setup reading */
-				mem_read_tab[j][i] = cartridge_decode_read;
+        /*
+         * Mapping for ~GAME enabled.
+         */
+        for (j = 16; j < NUM_CONFIGS; j++) {
+            /* $0000 - $7FFF */
+            for (i = 0x00; i <= 0x7f; i++) {
+                /* Setup reading */
+                mem_read_tab[j][i] = cartridge_decode_read;
 
-				/* Setup writing */
-				set_write_hook(j, i, cartridge_decode_store);
-				}
+                /* Setup writing */
+                set_write_hook(j, i, cartridge_decode_store);
+            }
 
-			/* $A000 - $FFFF */
-			for (i = 0xa0; i <= 0xff; i++)
-				{
-				/* Setup reading */
-				mem_read_tab[j][i] = cartridge_decode_read;
+            /* $A000 - $FFFF */
+            for (i = 0xa0; i <= 0xff; i++) {
+                /* Setup reading */
+                mem_read_tab[j][i] = cartridge_decode_read;
 
-				/* Setup writing */
-				set_write_hook(j, i, cartridge_decode_store);
-				}
-			}
-		}
+                /* Setup writing */
+                set_write_hook(j, i, cartridge_decode_store);
+            }
+        }
+    }
 
     /* Setup initial memory configuration.  */
     pla_config_changed();
@@ -955,7 +612,7 @@ void mem_powerup(void)
     }
 }
 
-static int c64mem_get_kernal_checksum(void)
+int c64mem_get_kernal_checksum(void)
 {
     int i;
     WORD sum;                   /* ROM checksum */
@@ -979,8 +636,8 @@ static int c64mem_get_kernal_checksum(void)
         || (id == 0x64
             && sum != C64_KERNAL_CHECKSUM_R64)) {
         log_warning(c64_mem_log,
-                    "Warning: Unknown Kernal image `%s'.  Sum: %d ($%04X).",
-                    kernal_rom_name, sum, sum);
+                    "Warning: Unknown Kernal image.  Sum: %d ($%04X).",
+                    sum, sum);
     } else if (kernal_revision != NULL) {
         if (patch_rom(kernal_revision) < 0)
             return -1;
@@ -997,36 +654,36 @@ static int c64mem_get_kernal_checksum(void)
     return 0;
 }
 
-static int mem_load_kernal(void)
+int mem_load_kernal(const char *rom_name)
 {
     int trapfl;
 
-    if(!rom_loaded) return 0;
+    if (!rom_loaded)
+        return 0;
 
     /* Make sure serial code assumes there are no traps installed.  */
     /* serial_remove_traps(); */
     /* we also need the TAPE traps!!! therefore -> */
     /* disable traps before saving the ROM */
-    resources_get_value("VirtualDevices", (resource_value_t*) &trapfl);
-    resources_set_value("VirtualDevices", (resource_value_t) 1);
+    resources_get_value("VirtualDevices", (resource_value_t*)&trapfl);
+    resources_set_value("VirtualDevices", (resource_value_t)1);
 
     /* Load Kernal ROM.  */
-    if (sysfile_load(kernal_rom_name,
-        kernal_rom, C64_KERNAL_ROM_SIZE,
-        C64_KERNAL_ROM_SIZE) < 0) {
+    if (sysfile_load(rom_name,
+        kernal_rom, C64_KERNAL_ROM_SIZE, C64_KERNAL_ROM_SIZE) < 0) {
         log_error(c64_mem_log, "Couldn't load kernal ROM `%s'.",
-                  kernal_rom_name);
-        resources_set_value("VirtualDevices", (resource_value_t) trapfl);
+                  rom_name);
+        resources_set_value("VirtualDevices", (resource_value_t)trapfl);
         return -1;
     }
     c64mem_get_kernal_checksum();
 
-    resources_set_value("VirtualDevices", (resource_value_t) trapfl);
+    resources_set_value("VirtualDevices", (resource_value_t)trapfl);
 
     return 0;
 }
 
-static int c64mem_get_basic_checksum(void)
+int c64mem_get_basic_checksum(void)
 {
     int i;
     WORD sum;
@@ -1038,40 +695,40 @@ static int c64mem_get_basic_checksum(void)
 
     if (sum != C64_BASIC_CHECKSUM)
         log_warning(c64_mem_log,
-                    "Warning: Unknown Basic image `%s'.  Sum: %d ($%04X).",
-                    basic_rom_name, sum, sum);
+                    "Warning: Unknown Basic image.  Sum: %d ($%04X).",
+                    sum, sum);
 
     return 0;
 }
 
-static int mem_load_basic(void) 
+int mem_load_basic(const char *rom_name)
 {
-    if(!rom_loaded) return 0;
+    if (!rom_loaded)
+        return 0;
 
     /* Load Basic ROM.  */
-    if (sysfile_load(basic_rom_name,
-        basic_rom, C64_BASIC_ROM_SIZE,
-        C64_BASIC_ROM_SIZE) < 0) {
+    if (sysfile_load(rom_name,
+        basic_rom, C64_BASIC_ROM_SIZE, C64_BASIC_ROM_SIZE) < 0) {
         log_error(c64_mem_log,
                   "Couldn't load basic ROM `%s'.",
-                  basic_rom_name);
+                  rom_name);
         return -1;
     }
     return c64mem_get_basic_checksum();
 }
 
 
-static int mem_load_chargen(void) 
+int mem_load_chargen(const char *rom_name)
 {
-    if(!rom_loaded) return 0;
-    
+    if (!rom_loaded)
+        return 0;
+
     /* Load chargen ROM.  */
 
-    if (sysfile_load(chargen_rom_name,
-        chargen_rom, C64_CHARGEN_ROM_SIZE,
-        C64_CHARGEN_ROM_SIZE) < 0) {
+    if (sysfile_load(rom_name,
+        chargen_rom, C64_CHARGEN_ROM_SIZE, C64_CHARGEN_ROM_SIZE) < 0) {
         log_error(c64_mem_log, "Couldn't load character ROM `%s'.",
-                  chargen_rom_name);
+                  rom_name);
         return -1;
     }
 
@@ -1081,6 +738,8 @@ static int mem_load_chargen(void)
 
 int mem_load(void)
 {
+    char *rom_name = NULL;
+
     mem_powerup();
 
     if (c64_mem_log == LOG_ERR)
@@ -1088,14 +747,20 @@ int mem_load(void)
 
     rom_loaded = 1;
 
-    if (mem_load_kernal() < 0) 
-	return -1;
+    if (resources_get_value("KernalName", (resource_value_t)&rom_name) < 0)
+        return -1;
+    if (mem_load_kernal(rom_name) < 0)
+        return -1;
 
-    if (mem_load_basic() < 0) 
-	return -1;
+    if (resources_get_value("BasicName", (resource_value_t)&rom_name) < 0)
+        return -1;
+    if (mem_load_basic(rom_name) < 0)
+        return -1;
 
-    if (mem_load_chargen() < 0) 
-	return -1;
+    if (resources_get_value("ChargenName", (resource_value_t)&rom_name) < 0)
+        return -1;
+    if (mem_load_chargen(rom_name) < 0)
+        return -1;
 
     return 0;
 }
@@ -1140,7 +805,7 @@ void mem_set_bank_pointer(BYTE **base, int *limit)
 
 /* FIXME: this part needs to be checked.  */
 
-void mem_get_basic_text(ADDRESS * start, ADDRESS * end)
+void mem_get_basic_text(ADDRESS *start, ADDRESS *end)
 {
     if (start != NULL)
         *start = ram[0x2b] | (ram[0x2c] << 8);
@@ -1160,7 +825,27 @@ void mem_set_basic_text(ADDRESS start, ADDRESS end)
 
 int mem_rom_trap_allowed(ADDRESS addr)
 {
-    return addr >= 0xe000 && (mem_config & 0x2);
+    if (addr >= 0xe000) {
+        switch (mem_config) {
+          case 2:
+          case 3:
+          case 6:
+          case 7:
+          case 10:
+          case 11:
+          case 14:
+          case 15:
+          case 26:
+          case 27:
+          case 30:
+          case 31:
+            return 1;
+          default: 
+            return 0;
+       }
+    }
+
+    return 0;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -1307,24 +992,24 @@ BYTE mem_bank_read(int bank, ADDRESS addr)
         return mem_read(addr);
         break;
       case 3:                   /* io */
-        if ((addr >= 0xd000) && (addr < 0xe000)) {
+        if (addr >= 0xd000 && addr < 0xe000) {
             return read_bank_io(addr);
         }
       case 4:                   /* cart */
-        if ((addr >= 0x8000) && (addr <= 0x9FFF)) {
+        if (addr >= 0x8000 && addr <= 0x9fff) {
             return roml_banks[addr & 0x1fff];
         }
-        if ((addr >= 0xA000) && (addr <= 0xBFFF)) {
+        if (addr >= 0xa000 && addr <= 0xbfff) {
             return romh_banks[addr & 0x1fff];
         }
       case 2:                   /* rom */
-        if ((addr >= 0xA000) && (addr <= 0xBFFF)) {
+        if (addr >= 0xa000 && addr <= 0xbfff) {
             return basic_rom[addr & 0x1fff];
         }
-        if ((addr >= 0xD000) && (addr <= 0xDfff)) {
+        if (addr >= 0xd000 && addr <= 0xdfff) {
             return chargen_rom[addr & 0x0fff];
         }
-        if ((addr >= 0xE000) && (addr <= 0xffff)) {
+        if (addr >= 0xe000 && addr <= 0xffff) {
             return kernal_rom[addr & 0x1fff];
         }
       case 1:                   /* ram */
@@ -1359,13 +1044,13 @@ void mem_bank_write(int bank, ADDRESS addr, BYTE byte)
             return;
         }
       case 2:                   /* rom */
-        if (addr >= 0xA000 && addr <= 0xBFFF) {
+        if (addr >= 0xa000 && addr <= 0xbfff) {
             return;
         }
-        if (addr >= 0xD000 && addr <= 0xDfff) {
+        if (addr >= 0xd000 && addr <= 0xdfff) {
             return;
         }
-        if (addr >= 0xE000 && addr <= 0xffff) {
+        if (addr >= 0xe000 && addr <= 0xffff) {
             return;
         }
       case 1:                   /* ram */
@@ -1374,6 +1059,35 @@ void mem_bank_write(int bank, ADDRESS addr, BYTE byte)
     ram[addr] = byte;
 }
 
+mem_ioreg_list_t *mem_ioreg_list_get(void)
+{
+    mem_ioreg_list_t *mem_ioreg_list;
+
+    mem_ioreg_list = (mem_ioreg_list_t *)xmalloc(sizeof(mem_ioreg_list_t) * 4);
+
+    mem_ioreg_list[0].name = "VIC-II";
+    mem_ioreg_list[0].start = 0xd000;
+    mem_ioreg_list[0].end = 0xd02e;
+    mem_ioreg_list[0].next = &mem_ioreg_list[1];
+
+    mem_ioreg_list[1].name = "SID";
+    mem_ioreg_list[1].start = 0xd400;
+    mem_ioreg_list[1].end = 0xd41f;
+    mem_ioreg_list[1].next = &mem_ioreg_list[2];
+
+    mem_ioreg_list[2].name = "CIA1";
+    mem_ioreg_list[2].start = 0xdc00;
+    mem_ioreg_list[2].end = 0xdc0f;
+    mem_ioreg_list[2].next = &mem_ioreg_list[3];
+
+    mem_ioreg_list[3].name = "CIA2";
+    mem_ioreg_list[3].start = 0xdd00;
+    mem_ioreg_list[3].end = 0xdd0f;
+    mem_ioreg_list[3].next = NULL;
+
+    return mem_ioreg_list;
+}
+
 void mem_get_screen_parameter(ADDRESS *base, BYTE *rows, BYTE *columns)
 {
     *base = ((vic_peek(0xd018) & 0xf0) << 6)
@@ -1387,241 +1101,7 @@ void mem_get_screen_parameter(ADDRESS *base, BYTE *rows, BYTE *columns)
 void mem_set_exrom(int active)
 {
     export.exrom = active ? 0 : 1;
- 
-    pla_config_changed(); 
-}
-
-/* ------------------------------------------------------------------------- */
-
-/* Snapshot.  */
-
-#define SNAP_ROM_MAJOR 0
-#define SNAP_ROM_MINOR 0
-static const char snap_rom_module_name[] = "C64ROM";
-
-static int mem_write_rom_snapshot_module(snapshot_t *s)
-{
-    snapshot_module_t *m;
-    int trapfl;
-
-    /* Main memory module.  */
-
-    m = snapshot_module_create(s, snap_rom_module_name, 
-					SNAP_ROM_MAJOR, SNAP_ROM_MINOR);
-    if (m == NULL)
-        return -1;
-
-    /* disable traps before saving the ROM */
-    resources_get_value("VirtualDevices", (resource_value_t*) &trapfl);
-    resources_set_value("VirtualDevices", (resource_value_t) 1);
-
-    if (snapshot_module_write_byte_array(m, kernal_rom, 
-						C64_KERNAL_ROM_SIZE) < 0
-        || snapshot_module_write_byte_array(m, basic_rom, 
-						C64_BASIC_ROM_SIZE) < 0
-        || snapshot_module_write_byte_array(m, chargen_rom, 
-						C64_CHARGEN_ROM_SIZE) < 0
-        )
-	goto fail;
-
-    /* FIXME: save cartridge ROM (& RAM?) areas:
-       first write out the configuration, i.e. 
-       - type of cartridge (banking scheme type)
-       - state of cartridge (active/which bank, ...)
-       then the ROM/RAM arrays:
-       - cartridge ROM areas
-       - cartridge RAM areas  */
-
-    ui_update_menus();
-
-    if (snapshot_module_close(m) < 0)
-        goto fail;
-
-    resources_set_value("VirtualDevices", (resource_value_t) trapfl);
-
-    return 0;
-
-fail:
-    if (m != NULL)
-        snapshot_module_close(m);
-
-    resources_set_value("VirtualDevices", (resource_value_t) trapfl);
-
-    return -1;
-}
- 
-int mem_read_rom_snapshot_module(snapshot_t *s)
-{
-    BYTE major_version, minor_version;
-    snapshot_module_t *m;
-    int trapfl;
-
-    /* Main memory module.  */
-
-    m = snapshot_module_open(s, snap_rom_module_name,
-                             &major_version, &minor_version);
-    if (m == NULL) {
-	/* this module is optional */
-	/* FIXME: reset all cartridge stuff to standard C64 behaviour */
-        return 0;
-    }
-
-    if (major_version > SNAP_ROM_MAJOR || minor_version > SNAP_ROM_MINOR) {
-        log_error(c64_mem_log,
-                  "Snapshot module version (%d.%d) newer than %d.%d.",
-                  major_version, minor_version,
-                  SNAP_ROM_MAJOR, SNAP_ROM_MINOR);
-        snapshot_module_close(m);
-	return -1;
-    }
-
-    /* disable traps before loading the ROM */
-    resources_get_value("VirtualDevices", (resource_value_t*) &trapfl);
-    resources_set_value("VirtualDevices", (resource_value_t) 1);
-
-    if (snapshot_module_read_byte_array(m, kernal_rom, 
-						C64_KERNAL_ROM_SIZE) < 0
-        || snapshot_module_read_byte_array(m, basic_rom, 
-						C64_BASIC_ROM_SIZE) < 0
-        || snapshot_module_read_byte_array(m, chargen_rom, 
-						C64_CHARGEN_ROM_SIZE) < 0
-        )
-	goto fail;
-
-    /* FIXME: read cartridge ROM (& RAM?) areas:
-       first read out the configuration, i.e. 
-       - type of cartridge (banking scheme type)
-       - state of cartridge (active/which bank, ...)
-       then the ROM/RAM arrays:
-       - cartridge ROM areas
-       - cartridge RAM areas
-    */
-
-    if (snapshot_module_close(m) < 0)
-        goto fail;
-
-    c64mem_get_kernal_checksum();
-    c64mem_get_basic_checksum();
-    /* enable traps again when necessary */
-    resources_set_value("VirtualDevices", (resource_value_t) trapfl);
-
-
-    return 0;
-
-fail:
-    if (m != NULL)
-        snapshot_module_close(m);
-    resources_set_value("VirtualDevices", (resource_value_t) trapfl);
-    return -1;
-}
-
-
-#define SNAP_MAJOR 0
-#define SNAP_MINOR 0
-static const char snap_mem_module_name[] = "C64MEM";
-
-int mem_write_snapshot_module(snapshot_t *s, int save_roms)
-{
-    snapshot_module_t *m;
-
-    /* Main memory module.  */
-
-    m = snapshot_module_create(s, snap_mem_module_name, SNAP_MAJOR, SNAP_MINOR);
-    if (m == NULL)
-        return -1;
-
-    if (snapshot_module_write_byte(m, pport.data) < 0
-        || snapshot_module_write_byte(m, pport.dir) < 0
-        || snapshot_module_write_byte(m, export.exrom) < 0
-        || snapshot_module_write_byte(m, export.game) < 0
-        || snapshot_module_write_byte_array(m, ram, C64_RAM_SIZE) < 0)
-        goto fail;
-
-    if (snapshot_module_close(m) < 0)
-        goto fail;
-    m = NULL;
-
-    if (save_roms && mem_write_rom_snapshot_module(s) < 0)
-	goto fail;
-	
-    /* REU module.  */
-    if (reu_enabled && reu_write_snapshot_module(s) < 0)
-        goto fail;
-
-#ifdef HAVE_RS232
-    /* ACIA module.  */
-    if (acia_de_enabled && acia1_write_snapshot_module(s) < 0)
-        goto fail;
-#endif
-
-    return 0;
-
-fail:
-    if (m != NULL)
-        snapshot_module_close(m);
-    return -1;
-}
-
-int mem_read_snapshot_module(snapshot_t *s)
-{
-    BYTE major_version, minor_version;
-    snapshot_module_t *m;
-
-    /* Main memory module.  */
-
-    m = snapshot_module_open(s, snap_mem_module_name,
-                             &major_version, &minor_version);
-    if (m == NULL)
-        return -1;
-
-    if (major_version > SNAP_MAJOR || minor_version > SNAP_MINOR) {
-        log_error(c64_mem_log,
-                  "Snapshot module version (%d.%d) newer than %d.%d.",
-                  major_version, minor_version,
-                  SNAP_MAJOR, SNAP_MINOR);
-        goto fail;
-    }
-
-    if (snapshot_module_read_byte(m, &pport.data) < 0
-        || snapshot_module_read_byte(m, &pport.dir) < 0
-        || snapshot_module_read_byte(m, &export.exrom) < 0
-        || snapshot_module_read_byte(m, &export.game) < 0
-        || snapshot_module_read_byte_array(m, ram, C64_RAM_SIZE) < 0)
-        goto fail;
 
     pla_config_changed();
-
-    if (snapshot_module_close(m) < 0)
-        goto fail;
-    m = NULL;
-
-    if (mem_read_rom_snapshot_module(s) < 0)
-	goto fail;
-
-    /* REU module.  */
-    if (reu_read_snapshot_module(s) < 0) {
-        reu_enabled = 0;
-    } else {
-        reu_enabled = 1;
-    }
-
-#ifdef HAVE_RS232
-    /* ACIA module.  */
-    if (acia1_read_snapshot_module(s) < 0) {
-        acia_de_enabled = 0;
-    } else {
-        /* FIXME: Why do we need to do so???  */
-        acia1_reset();          /* Clear interrupts.  */
-        acia_de_enabled = 1;
-    }
-#endif
-
-    ui_update_menus();
-
-    return 0;
-
-fail:
-    if (m != NULL)
-        snapshot_module_close(m);
-    return -1;
 }
+
