@@ -37,8 +37,8 @@ extern void REGPARM2 tpi_store(ADDRESS addr, BYTE byte);
 extern BYTE REGPARM1 tpi_read(ADDRESS addr);
 extern BYTE tpi_peek(ADDRESS addr);
 
-extern int tpi_write_snapshot_module(struct snapshot_s *p);
-extern int tpi_read_snapshot_module(struct snapshot_s *p);
+extern int tpi_snapshot_write_module(struct snapshot_s *p);
+extern int tpi_snapshot_read_module(struct snapshot_s *p);
 
 #endif
 
