@@ -29,6 +29,7 @@
 #include "maincpu.h"
 #include "tpicore.h"
 #include "types.h"
+#include "c610mem.h"
 
 /*----------------------------------------------------------------------*/
 /* renaming of exported functions */
@@ -40,8 +41,8 @@
 #define mytpi_peek tpi2_peek
 #define mytpi_set_int tpi2_set_int
 #define mytpi_restore_int tpi2_restore_int
-#define mytpi_write_snapshot_module tpi2_write_snapshot_module
-#define mytpi_read_snapshot_module tpi2_read_snapshot_module
+#define mytpi_snapshot_write_module tpi2_snapshot_write_module
+#define mytpi_snapshot_read_module tpi2_snapshot_read_module
 
 #define MYTPI_NAME      "TPI2"
 
@@ -86,6 +87,7 @@ _TPI_FUNC void store_pb(BYTE byte)
 
 _TPI_FUNC void store_pc(BYTE byte)
 {
+    cbm2_set_tpi2pc(byte);
 }
 
 _TPI_FUNC void undump_pa(BYTE byte)
@@ -98,6 +100,7 @@ _TPI_FUNC void undump_pb(BYTE byte)
 
 _TPI_FUNC void undump_pc(BYTE byte)
 {
+    cbm2_set_tpi2pc(byte);
 }
 
 _TPI_FUNC BYTE read_pa(void)
