@@ -48,8 +48,9 @@
 static log_t disk_image_log = LOG_ERR;
 
 /* Defines for probing the disk image type.  */
-#define IS_D64_LEN(x) ((x) == D64_FILE_SIZE_35 || (x) == D64_FILE_SIZE_35E || \
-                       (x) == D64_FILE_SIZE_40 || (x) == D64_FILE_SIZE_40E)
+/* #define IS_D64_LEN(x) removed,
+   now calculated in disk_image_check_for_d64 for 35-42 track support */
+#define IS_D67_LEN(x) ((x) == D67_FILE_SIZE)
 #define IS_D71_LEN(x) ((x) == D71_FILE_SIZE)
 #define IS_D81_LEN(x) ((x) == D81_FILE_SIZE)
 #define IS_D80_LEN(x) ((x) == D80_FILE_SIZE)
@@ -110,85 +111,141 @@ unsigned int disk_image_speed_map_1571(unsigned int track)
 /*-----------------------------------------------------------------------*/
 /* Disk image probing.  */
 
+static void disk_image_check_log(disk_image_t *image, const char *type)
+{
+    log_message(disk_image_log, "%s disk image recognised: %s, %d tracks%s",
+                type, image->name, image->tracks,
+                image->read_only ? " (read only)." : ".");
+}
+
+static int disk_image_check_min_block(unsigned int blk, unsigned int length)
+{
+    if (blk < length) {
+        log_error(disk_image_log, "Cannot read block %d.", blk);
+        return -1;
+    }
+    return 0;
+}
+
+
 static int disk_image_check_for_d64(disk_image_t *image)
 {
-    int blk = 0, len;
+    int countbytes;
+
+    /*** detect 35..42 track d64 image, determine image parameters.
+         Walk from 35 to 42, calculate expected image file size for each track,
+         and compare this with the size of the given image.
+         */
+
+    int checkimage_tracks,checkimage_blocks;
+    int checkimage_realsize,checkimage_errorinfo;
+
+    checkimage_errorinfo=0;
+    checkimage_realsize=util_file_length(image->fd);
+    checkimage_tracks=NUM_TRACKS_1541; /* start at track 35 */
+    checkimage_blocks=D64_FILE_SIZE_35/256;
+
+    while (1) {
+
+        /* check if image matches "checkimage_tracks" */
+        if (checkimage_realsize==checkimage_blocks*256) {
+            /* image file matches size-with-no-error-info */
+            checkimage_errorinfo=0;
+            break;
+
+        } else if (checkimage_realsize==checkimage_blocks*256
+            + checkimage_blocks) {
+            /* image file matches size-with-error-info */
+            checkimage_errorinfo=1;
+            break;
+        }
+
+        /* try next track (all tracks from 35 to 42 have 17 blocks) */
+        checkimage_tracks++;
+        checkimage_blocks+=17;
+
+        /* we tried them all up to 42, none worked, image must be corrupt */
+        if (checkimage_tracks>MAX_TRACKS_1541)
+            return 0;
+    }
+
+    /*** test image file: read it (fgetc is pretty fast).
+         further size checks are no longer necessary (done during detection) */
+    rewind(image->fd);
+    for (countbytes=0; countbytes<checkimage_realsize; countbytes++) {
+        if (fgetc(image->fd)==EOF) {
+            log_error(disk_image_log, "Cannot read D64 image.");
+            return 0;
+        }
+    }
+
+    /*** set parameters in image structure, read error info */
+    image->type = DISK_IMAGE_TYPE_D64;
+    image->tracks = checkimage_tracks;
+    if (checkimage_errorinfo) {
+        image->error_info = (BYTE *)xcalloc(1, MAX_BLOCKS_1541);
+        if (fseek(image->fd, 256 * checkimage_blocks, SEEK_SET) < 0)
+            return 0;
+        if (fread(image->error_info, 1, checkimage_blocks, image->fd)
+            < checkimage_blocks)
+            return 0;
+    }
+
+    /*** log and return successfully */
+    disk_image_check_log(image,"D64");
+    return 1;
+}
+
+
+static int disk_image_check_for_d67(disk_image_t *image)
+{
+    unsigned int blk = 0;
+    size_t len;
     BYTE block[256];
 
-    if (!(IS_D64_LEN(file_length(image->fd))))
+    if (!(IS_D67_LEN(util_file_length(image->fd))))
         return 0;
 
-    image->type = DISK_IMAGE_TYPE_D64;
-    image->tracks = NUM_TRACKS_1541;
+    image->type = DISK_IMAGE_TYPE_D67;
+    image->tracks = NUM_TRACKS_2040;
 
-    if (fseek(image->fd, 256 * blk, SEEK_SET) < 0)
-        return 0;
+    rewind(image->fd);
 
     while ((len = fread(block, 1, 256, image->fd)) == 256) {
-        if (++blk > (EXT_BLOCKS_1541 + 3)) {
+        /* FIXME */
+        if (++blk > (NUM_BLOCKS_2040)) {
             log_error(disk_image_log, "Disk image too large");
             break;
         }
     }
 
-    if (blk < NUM_BLOCKS_1541) {
-        log_error(disk_image_log, "Cannot read block %d.", blk);
+    if (disk_image_check_min_block(blk, NUM_BLOCKS_2040) < 0)
         return 0;
-    }
 
     switch (blk) {
-      case NUM_BLOCKS_1541:
-        image->tracks = NUM_TRACKS_1541;
-        break;
-      case NUM_BLOCKS_1541 + 2:
-        if (len != 171) {
-            log_message(disk_image_log, "Cannot read block %d.", blk);
-            return 0;
-        }
-        image->error_info = (BYTE *)xmalloc(MAX_BLOCKS_1541);
-        memset(image->error_info, 0, MAX_BLOCKS_1541);
-        if (fseek(image->fd, 256 * NUM_BLOCKS_1541, SEEK_SET) < 0)
-            return 0;
-        if (fread(image->error_info, 1, NUM_BLOCKS_1541, image->fd)
-            < NUM_BLOCKS_1541)
-            return 0;
-        image->tracks = NUM_TRACKS_1541;
-        break;
-      case EXT_BLOCKS_1541:
-        image->tracks = EXT_TRACKS_1541;
-        break;
-      case EXT_BLOCKS_1541 + 3:
-        image->error_info = (BYTE *)xmalloc(MAX_BLOCKS_1541);
-        memset(image->error_info, 0, MAX_BLOCKS_1541);
-        if (fseek(image->fd, 256 * EXT_BLOCKS_1541, SEEK_SET) < 0)
-            return 0;
-        if (fread(image->error_info, 1, EXT_BLOCKS_1541, image->fd)
-            < EXT_BLOCKS_1541)
-            return 0;
-
-        image->tracks = EXT_TRACKS_1541;
+      case NUM_BLOCKS_2040:
+        image->tracks = NUM_TRACKS_2040;
         break;
       default:
         return 0;
     }
-    log_message(disk_image_log, "D64 disk image recognised: %s%s",
-                image->name, image->read_only ? " (read only)." : ".");
+    disk_image_check_log(image, "D67");
     return 1;
 }
 
 static int disk_image_check_for_d71(disk_image_t *image)
 {
-    int blk = 0, len;
+    unsigned int blk = 0;
+    size_t len;
     BYTE block[256];
 
-    if (!(IS_D71_LEN(file_length(image->fd))))
+    if (!(IS_D71_LEN(util_file_length(image->fd))))
         return 0;
 
     image->type = DISK_IMAGE_TYPE_D71;
     image->tracks = NUM_TRACKS_1571;
 
-    if (fseek(image->fd, 256 * blk, SEEK_SET) < 0)
-        return 0;
+    rewind(image->fd);
 
     while ((len = fread(block, 1, 256, image->fd)) == 256) {
         if (++blk > 1372) {
@@ -197,10 +254,8 @@ static int disk_image_check_for_d71(disk_image_t *image)
         }
     }
 
-    if (blk < NUM_BLOCKS_1571) {
-        log_error(disk_image_log, "Cannot read block %d.", blk);
+    if (disk_image_check_min_block(blk, NUM_BLOCKS_1571) < 0)
         return 0;
-    }
 
     switch (blk) {
       case 1366:
@@ -209,24 +264,23 @@ static int disk_image_check_for_d71(disk_image_t *image)
       default:
         return 0;
     }
-    log_message(disk_image_log, "D71 disk image recognised: %s%s.",
-                image->name, image->read_only ? " (read only)." : ".");
+    disk_image_check_log(image, "D71");
     return 1;
 }
 
 static int disk_image_check_for_d81(disk_image_t *image)
 {
-    int blk = 0, len;
+    unsigned int blk = 0;
+    size_t len;
     BYTE block[256];
 
-    if (!(IS_D81_LEN(file_length(image->fd))))
+    if (!(IS_D81_LEN(util_file_length(image->fd))))
         return 0;
 
     image->type = DISK_IMAGE_TYPE_D81;
     image->tracks = NUM_TRACKS_1581;
 
-    if (fseek(image->fd, 256 * blk, SEEK_SET) < 0)
-        return 0;
+    rewind(image->fd);
 
     while ((len = fread(block, 1, 256, image->fd)) == 256) {
         if (++blk > 3213) {
@@ -235,10 +289,8 @@ static int disk_image_check_for_d81(disk_image_t *image)
         }
     }
 
-    if (blk < NUM_BLOCKS_1581) {
-        log_error(disk_image_log, "Cannot read block %d.", blk);
+    if (disk_image_check_min_block(blk, NUM_BLOCKS_1581) < 0)
         return 0;
-    }
 
     switch (blk) {
       case 3200:
@@ -247,24 +299,23 @@ static int disk_image_check_for_d81(disk_image_t *image)
       default:
         return 0;
     }
-    log_message(disk_image_log, "D81 disk image recognised: %s%s.",
-                image->name, image->read_only ? " (read only)." : "");
+    disk_image_check_log(image, "D81");
     return 1;
 }
 
 static int disk_image_check_for_d80(disk_image_t *image)
 {
-    int blk = 0, len;
+    unsigned int blk = 0;
+    size_t len;
     BYTE block[256];
 
-    if (!(IS_D80_LEN(file_length(image->fd))))
+    if (!(IS_D80_LEN(util_file_length(image->fd))))
         return 0;
 
     image->type = DISK_IMAGE_TYPE_D80;
     image->tracks = NUM_TRACKS_8050;
 
-    if (fseek(image->fd, 256 * blk, SEEK_SET) < 0)
-        return 0;
+    rewind(image->fd);
 
     while ((len = fread(block, 1, 256, image->fd)) == 256) {
         if (++blk > NUM_BLOCKS_8050 + 6) {
@@ -273,10 +324,8 @@ static int disk_image_check_for_d80(disk_image_t *image)
         }
     }
 
-    if (blk < NUM_BLOCKS_8050) {
-        log_error(disk_image_log, "Cannot read block %d.", blk);
+    if (disk_image_check_min_block(blk, NUM_BLOCKS_8050) < 0)
         return 0;
-    }
 
     switch (blk) {
       case NUM_BLOCKS_8050:
@@ -285,24 +334,23 @@ static int disk_image_check_for_d80(disk_image_t *image)
       default:
         return 0;
     }
-    log_message(disk_image_log, "D80 disk image recognised: %s%s.",
-                image->name, image->read_only ? " (read only)." : ".");
+    disk_image_check_log(image, "D80");
     return 1;
 }
 
 static int disk_image_check_for_d82(disk_image_t *image)
 {
-    int blk = 0, len;
+    unsigned int blk = 0;
+    size_t len;
     BYTE block[256];
 
-    if (!(IS_D82_LEN(file_length(image->fd))))
+    if (!(IS_D82_LEN(util_file_length(image->fd))))
         return 0;
 
     image->type = DISK_IMAGE_TYPE_D82;
     image->tracks = NUM_TRACKS_8250;
 
-    if (fseek(image->fd, 256 * blk, SEEK_SET) < 0)
-        return 0;
+    rewind(image->fd);
 
     while ((len = fread(block, 1, 256, image->fd)) == 256) {
         if (++blk > NUM_BLOCKS_8250 + 6) {
@@ -311,10 +359,8 @@ static int disk_image_check_for_d82(disk_image_t *image)
         }
     }
 
-    if (blk < NUM_BLOCKS_8250) {
-        log_error(disk_image_log, "Cannot read block %d.", blk);
+    if (disk_image_check_min_block(blk, NUM_BLOCKS_8250) < 0)
         return 0;
-    }
 
     switch (blk) {
       case NUM_BLOCKS_8250:
@@ -323,8 +369,7 @@ static int disk_image_check_for_d82(disk_image_t *image)
       default:
         return 0;
     }
-    log_message(disk_image_log, "D82 disk image recognised: %s%s.",
-                image->name, image->read_only ? " (read only)." : ".");
+    disk_image_check_log(image, "D82");
     return 1;
 }
 
@@ -349,8 +394,7 @@ static int disk_image_check_for_x64(disk_image_t *image)
     image->type = DISK_IMAGE_TYPE_X64;
     image->tracks = header[X64_HEADER_FLAGS_OFFSET + 1];
 
-    log_message(disk_image_log, "X64 disk image recognised: %s%s.",
-                image->name, image->read_only ? " (read only)." : ".");
+    disk_image_check_log(image, "X64");
     return 1;
 }
 
@@ -481,8 +525,7 @@ static int disk_image_check_for_gcr(disk_image_t *image)
 
     image->type = DISK_IMAGE_TYPE_G64;
     image->tracks = header[9] / 2;
-    log_message(disk_image_log, "GCR disk image recognised: %s%s.",
-                image->name, image->read_only ? " (read only)" : "");
+    disk_image_check_log(image, "GCR");
 
     if (image->gcr != NULL) {
         if (disk_image_read_gcr_image(image) < 0)
@@ -517,7 +560,9 @@ int disk_image_open(disk_image_t *image)
     }
 
     if (disk_image_check_for_d64(image))
-        return 0;        
+        return 0;
+    if (disk_image_check_for_d67(image))
+        return 0;
     if (disk_image_check_for_d71(image))
         return 0;
     if (disk_image_check_for_d81(image))
@@ -532,6 +577,7 @@ int disk_image_open(disk_image_t *image)
         return 0;
 
     zfclose(image->fd);
+    log_message(disk_image_log, "Unknown disk image `%s'.", image->name);
     return -1;
 }
 
@@ -564,7 +610,7 @@ static int disk_image_create_gcr(disk_image_t *image)
     BYTE gcr_header[12], gcr_track[7930], *gcrptr;
     DWORD gcr_track_p[MAX_TRACKS_1541 * 2];
     DWORD gcr_speed_p[MAX_TRACKS_1541 * 2];
-    int track, sector;
+    unsigned int track, sector;
 
     strcpy((char *) gcr_header, "GCR-1541");
 
@@ -634,15 +680,19 @@ static int disk_image_create_gcr(disk_image_t *image)
 int disk_image_create(const char *name, unsigned int type)
 {
     disk_image_t *image;
-    long size = 0;
-    char block[256];
-    int i;
+    unsigned int size, i;
+    BYTE block[256];
+
+    size = 0;
 
     switch(type) {
       case DISK_IMAGE_TYPE_D64:
       case DISK_IMAGE_TYPE_X64:
         size = D64_FILE_SIZE_35;
         break;
+      case DISK_IMAGE_TYPE_D67:
+        size = D67_FILE_SIZE;
+        break;
       case DISK_IMAGE_TYPE_D71:
         size = D71_FILE_SIZE;
         break;
@@ -704,6 +754,7 @@ int disk_image_create(const char *name, unsigned int type)
         }
         /* Fall through.  */
       case DISK_IMAGE_TYPE_D64:
+      case DISK_IMAGE_TYPE_D67:
       case DISK_IMAGE_TYPE_D71:
       case DISK_IMAGE_TYPE_D81:
       case DISK_IMAGE_TYPE_D80:
@@ -730,14 +781,14 @@ int disk_image_create(const char *name, unsigned int type)
         break;
       case DISK_IMAGE_TYPE_TAP:
         /* create an empty tap */
-        strcpy(&block[TAP_HDR_MAGIC_OFFSET],"C64-TAPE-RAW");
+        strcpy((char *)&block[TAP_HDR_MAGIC_OFFSET], "C64-TAPE-RAW");
         block[TAP_HDR_VERSION] = 1;
-        dword_to_le_buf(&block[TAP_HDR_LEN], 4);
+        util_dword_to_le_buf(&block[TAP_HDR_LEN], 4);
         if (fwrite(block, 24, 1, image->fd) <1) {
-                fclose(image->fd);
-                free(image->name);
-                free(image);
-                return -1;
+            fclose(image->fd);
+            free(image->name);
+            free(image);
+            return -1;
         }
 
     }
@@ -761,6 +812,15 @@ static char sector_map_d64[43] =
     17, 17, 17, 17, 17, 17, 17              /* 36 - 42 */
 };
 
+static char sector_map_d67[36] =
+{
+    0,
+    21, 21, 21, 21, 21, 21, 21, 21, 21, 21, /*  1 - 10 */
+    21, 21, 21, 21, 21, 21, 21, 20, 20, 20, /* 11 - 20 */
+    20, 20, 20, 20, 18, 18, 18, 18, 18, 18, /* 21 - 30 */
+    17, 17, 17, 17, 17                      /* 31 - 35 */
+};
+
 static char sector_map_d71[71] =
 {
     0,
@@ -787,21 +847,29 @@ static char sector_map_d80[78] =
     23, 23, 23, 23, 23, 23, 23          /* 71 - 77 */
 };
 
-int disk_image_sector_per_track(unsigned int format, unsigned int track)
+unsigned int disk_image_sector_per_track(unsigned int format,
+                                         unsigned int track)
 {
     switch (format) {
       case DISK_IMAGE_TYPE_D64:
       case DISK_IMAGE_TYPE_X64:
         if (track >= sizeof(sector_map_d64)) {
             log_message(disk_image_log, "Track %i exceeds sector map.", track);
-            return -1;
-        }        
+            return 0;
+        }
         return sector_map_d64[track];
         break;
+      case DISK_IMAGE_TYPE_D67:
+        if (track >= sizeof(sector_map_d67)) {
+            log_message(disk_image_log, "Track %i exceeds sector map.", track);
+            return 0;
+        }
+        return sector_map_d67[track];
+        break;
       case DISK_IMAGE_TYPE_D71:
         if (track >= sizeof(sector_map_d71)) {
             log_message(disk_image_log, "Track %i exceeds sector map.", track);
-            return -1;
+            return 0;
         }
         return sector_map_d71[track];
         break;
@@ -809,16 +877,15 @@ int disk_image_sector_per_track(unsigned int format, unsigned int track)
       case DISK_IMAGE_TYPE_D82:
         if (track >= sizeof(sector_map_d80)) {
             log_message(disk_image_log, "Track %i exceeds sector map.", track);
-            return -1;
+            return 0;
         }
         return sector_map_d80[track];
         break;
       default:
         log_message(disk_image_log,
-                    "Unknown disk type %i.  Cannot calculate sectors per track",
-                    format);
+                    "Unknown disk type %i.  Cannot calculate sectors per track",                    format);
     }
-    return -1;
+    return 0;
 }
 
 int disk_image_check_sector(unsigned int format, unsigned int track,
@@ -839,6 +906,14 @@ int disk_image_check_sector(unsigned int format, unsigned int track,
             sectors += disk_image_sector_per_track(DISK_IMAGE_TYPE_D64, i);
         sectors += sector;
         break;
+      case DISK_IMAGE_TYPE_D67:
+        if (track > MAX_TRACKS_2040 || sector
+            >= disk_image_sector_per_track(DISK_IMAGE_TYPE_D67, track))
+            return -1;
+        for (i = 1; i < track; i++)
+            sectors += disk_image_sector_per_track(DISK_IMAGE_TYPE_D67, i);
+        sectors += sector;
+        break;
       case DISK_IMAGE_TYPE_D71:
         if (track > MAX_TRACKS_1571)
             return -1;
@@ -858,7 +933,7 @@ int disk_image_check_sector(unsigned int format, unsigned int track,
         sectors = (track - 1) * NUM_SECTORS_1581 + sector;
         break;
       case DISK_IMAGE_TYPE_D80:
-        if (track > MAX_TRACKS_8050 || sector 
+        if (track > MAX_TRACKS_8050 || sector
             >= disk_image_sector_per_track(DISK_IMAGE_TYPE_D80, track))
             return -1;
         for (i = 1; i < track; i++)
@@ -957,6 +1032,7 @@ int disk_image_read_sector(disk_image_t *image, BYTE *buf, unsigned int track,
 
     switch (image->type) {
       case DISK_IMAGE_TYPE_D64:
+      case DISK_IMAGE_TYPE_D67:
       case DISK_IMAGE_TYPE_D71:
       case DISK_IMAGE_TYPE_D81:
       case DISK_IMAGE_TYPE_D80:
@@ -1206,6 +1282,7 @@ int disk_image_write_sector(disk_image_t *image, BYTE *buf, unsigned int track,
 
     switch (image->type) {
       case DISK_IMAGE_TYPE_D64:
+      case DISK_IMAGE_TYPE_D67:
       case DISK_IMAGE_TYPE_D71:
       case DISK_IMAGE_TYPE_D81:
       case DISK_IMAGE_TYPE_D80:
