@@ -56,13 +56,13 @@
 /* Logging.  */
 static log_t drive_snapshot_log = LOG_ERR;
 
-static int drive_write_image_snapshot_module(snapshot_t *s, unsigned int dnr);
-static int drive_write_gcrimage_snapshot_module(snapshot_t *s,
+static int drive_snapshot_write_image_module(snapshot_t *s, unsigned int dnr);
+static int drive_snapshot_write_gcrimage_module(snapshot_t *s,
                                                 unsigned int dnr);
-static int drive_read_image_snapshot_module(snapshot_t *s, unsigned int dnr);
-static int drive_read_gcrimage_snapshot_module(snapshot_t *s, unsigned int dnr);
-static int drive_write_rom_snapshot_module(snapshot_t *s, unsigned int dnr);
-static int drive_read_rom_snapshot_module(snapshot_t *s, unsigned int dnr);
+static int drive_snapshot_read_image_module(snapshot_t *s, unsigned int dnr);
+static int drive_snapshot_read_gcrimage_module(snapshot_t *s, unsigned int dnr);
+static int drive_snapshot_write_rom_module(snapshot_t *s, unsigned int dnr);
+static int drive_snapshot_read_rom_module(snapshot_t *s, unsigned int dnr);
 
 /*
 This is the format of the DRIVE snapshot module.
@@ -99,7 +99,7 @@ Type                 DWORD  2      drive type
 #define DRIVE_SNAP_MAJOR 1
 #define DRIVE_SNAP_MINOR 0
 
-int drive_write_snapshot_module(snapshot_t *s, int save_disks, int save_roms)
+int drive_snapshot_write_module(snapshot_t *s, int save_disks, int save_roms)
 {
     int i;
     char snap_module_name[] = "DRIVE";
@@ -144,27 +144,27 @@ int drive_write_snapshot_module(snapshot_t *s, int save_disks, int save_roms)
 
     for (i = 0; i < 2; i++) {
         if (0
-            || snapshot_module_write_dword(m, (DWORD) drive[i].accum) < 0
-            || snapshot_module_write_dword(m, (DWORD) drive[i].attach_clk) < 0
-            || snapshot_module_write_dword(m, (DWORD) drive[i].bits_moved) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].byte_ready) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].clock_frequency) < 0
-            || snapshot_module_write_word(m, (WORD) drive[i].current_half_track) < 0
-            || snapshot_module_write_dword(m, (DWORD) drive[i].detach_clk) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].diskID1) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].diskID2) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].extend_image_policy) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].finish_byte) < 0
-            || snapshot_module_write_dword(m, (DWORD) drive[i].GCR_head_offset) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].GCR_read) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].GCR_write_value) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].idling_method) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].last_mode) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].parallel_cable_enabled) < 0
-            || snapshot_module_write_byte(m, (BYTE) drive[i].read_only) < 0
-            || snapshot_module_write_dword(m, (DWORD) drive[i].rotation_last_clk) < 0
-            || snapshot_module_write_dword(m, (DWORD) (rotation_table_ptr[i])) < 0
-            || snapshot_module_write_dword(m, (DWORD) drive[i].type) < 0
+            || snapshot_module_write_dword(m, (DWORD)drive[i].accum) < 0
+            || snapshot_module_write_dword(m, (DWORD)drive[i].attach_clk) < 0
+            || snapshot_module_write_dword(m, (DWORD)drive[i].bits_moved) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].byte_ready) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].clock_frequency) < 0
+            || snapshot_module_write_word(m, (WORD)drive[i].current_half_track) < 0
+            || snapshot_module_write_dword(m, (DWORD)drive[i].detach_clk) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].diskID1) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].diskID2) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].extend_image_policy) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].finish_byte) < 0
+            || snapshot_module_write_dword(m, (DWORD)drive[i].GCR_head_offset) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].GCR_read) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].GCR_write_value) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].idling_method) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].last_mode) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].parallel_cable_enabled) < 0
+            || snapshot_module_write_byte(m, (BYTE)drive[i].read_only) < 0
+            || snapshot_module_write_dword(m, (DWORD)drive[i].rotation_last_clk) < 0
+            || snapshot_module_write_dword(m, (DWORD)(rotation_table_ptr[i])) < 0
+            || snapshot_module_write_dword(m, (DWORD)drive[i].type) < 0
         ) {
             if (m != NULL)
                 snapshot_module_close(m);
@@ -179,55 +179,55 @@ int drive_write_snapshot_module(snapshot_t *s, int save_disks, int save_roms)
         if (drive[i].enable) {
             struct drive_context_s *ctxptr =
                 (i == 0) ? &drive0_context : &drive1_context;
-            if (drive_cpu_write_snapshot_module(ctxptr, s) < 0)
+            if (drive_cpu_snapshot_write_module(ctxptr, s) < 0)
                 return -1;
             if (drive[i].type == DRIVE_TYPE_1541
                 || drive[i].type == DRIVE_TYPE_1541II
                 || drive[i].type == DRIVE_TYPE_2031) {
-                if (via1d_write_snapshot_module(ctxptr, s) < 0
-                    || via2d_write_snapshot_module(ctxptr, s) < 0)
+                if (via1d_snapshot_write_module(ctxptr, s) < 0
+                    || via2d_snapshot_write_module(ctxptr, s) < 0)
                     return -1;
             }
             if (drive[i].type == DRIVE_TYPE_1571) {
-                if (via1d_write_snapshot_module(ctxptr, s) < 0
-                    || via2d_write_snapshot_module(ctxptr, s) < 0
-                    || cia1571_write_snapshot_module(ctxptr, s) < 0)
+                if (via1d_snapshot_write_module(ctxptr, s) < 0
+                    || via2d_snapshot_write_module(ctxptr, s) < 0
+                    || cia1571_snapshot_write_module(ctxptr, s) < 0)
                     return -1;
             }
             if (drive[i].type == DRIVE_TYPE_1581) {
-                if (cia1581_write_snapshot_module(ctxptr, s) < 0)
+                if (cia1581_snapshot_write_module(ctxptr, s) < 0)
+                    return -1;
+            }
+            if (DRIVE_IS_OLDTYPE(drive[i].type)) {
+                if (riot1_snapshot_write_module(ctxptr, s) < 0
+                    || riot2_snapshot_write_module(ctxptr, s) < 0
+                    || fdc_snapshot_write_module(s, i) < 0)
                     return -1;
             }
-	    if (DRIVE_IS_OLDTYPE(drive[i].type)) {
-	        if (riot1_write_snapshot_module(ctxptr, s) < 0
-		    || riot2_write_snapshot_module(ctxptr, s) < 0
-		    || fdc_write_snapshot_module(s, i) < 0)
-		    return -1;
-	    }
         }
     }
 
     if (save_disks) {
-	if (GCR_image[0] > 0) {
-            if (drive_write_gcrimage_snapshot_module(s, 0) < 0)
+        if (GCR_image[0] > 0) {
+            if (drive_snapshot_write_gcrimage_module(s, 0) < 0)
                 return -1;
-	} else {
-            if (drive_write_image_snapshot_module(s, 0) < 0)
-		return -1;
-	}
+        } else {
+            if (drive_snapshot_write_image_module(s, 0) < 0)
+                return -1;
+        }
         if (GCR_image[1] > 0) {
-            if (drive_write_gcrimage_snapshot_module(s, 1) < 0)
+            if (drive_snapshot_write_gcrimage_module(s, 1) < 0)
                 return -1;
-	} else {
-            if (drive_write_image_snapshot_module(s, 1) < 0)
-		return -1;
-	}
+        } else {
+            if (drive_snapshot_write_image_module(s, 1) < 0)
+                return -1;
+        }
     }
     if (save_roms && drive[0].enable)
-        if (drive_write_rom_snapshot_module(s, 0) < 0)
+        if (drive_snapshot_write_rom_module(s, 0) < 0)
             return -1;
     if (save_roms && drive[1].enable)
-        if (drive_write_rom_snapshot_module(s, 1) < 0)
+        if (drive_snapshot_write_rom_module(s, 1) < 0)
             return -1;
     return 0;
 }
@@ -238,7 +238,7 @@ static int read_byte_into_int(snapshot_module_t *m, int *value_return)
 
     if (snapshot_module_read_byte(m, &b) < 0)
         return -1;
-    *value_return = (int) b;
+    *value_return = (int)b;
     return 0;
 }
 
@@ -248,7 +248,7 @@ static int read_word_into_int(snapshot_module_t *m, int *value_return)
 
     if (snapshot_module_read_word(m, &b) < 0)
         return -1;
-    *value_return = (int) b;
+    *value_return = (int)b;
     return 0;
 }
 
@@ -259,7 +259,7 @@ static int read_dword_into_unsigned_long(snapshot_module_t *m,
 
     if (snapshot_module_read_dword(m, &b) < 0)
         return -1;
-    *value_return = (unsigned long) b;
+    *value_return = (unsigned long)b;
     return 0;
 }
 
@@ -269,11 +269,11 @@ static int read_dword_into_int(snapshot_module_t *m, int *value_return)
 
     if (snapshot_module_read_dword(m, &b) < 0)
         return -1;
-    *value_return = (int) b;
+    *value_return = (int)b;
     return 0;
 }
 
-int drive_read_snapshot_module(snapshot_t *s)
+int drive_snapshot_read_module(snapshot_t *s)
 {
     BYTE major_version, minor_version;
     int i;
@@ -395,7 +395,7 @@ int drive_read_snapshot_module(snapshot_t *s)
       case DRIVE_TYPE_1581:
       case DRIVE_TYPE_2031:
       case DRIVE_TYPE_1001:
-	/* drive 1 does not allow dual disk drive */
+        /* drive 1 does not allow dual disk drive */
         drive[1].enable = 1;
         drive_setup_rom_image(1);
         drive_mem_init(&drive1_context, drive[1].type);
@@ -421,43 +421,43 @@ int drive_read_snapshot_module(snapshot_t *s)
         if (drive[i].enable) {
             struct drive_context_s *ctxptr =
                 (i == 0) ? &drive0_context : &drive1_context;
-            if (drive_cpu_read_snapshot_module(ctxptr, s) < 0)
+            if (drive_cpu_snapshot_read_module(ctxptr, s) < 0)
                 return -1;
             if (drive[i].type == DRIVE_TYPE_1541
                 || drive[i].type == DRIVE_TYPE_1541II
                 || drive[i].type == DRIVE_TYPE_2031) {
-                if (via1d_read_snapshot_module(ctxptr, s) < 0
-                    || via2d_read_snapshot_module(ctxptr, s) < 0)
+                if (via1d_snapshot_read_module(ctxptr, s) < 0
+                    || via2d_snapshot_read_module(ctxptr, s) < 0)
                     return -1;
             }
             if (drive[i].type == DRIVE_TYPE_1571) {
-                if (via1d_read_snapshot_module(ctxptr, s) < 0
-                    || via2d_read_snapshot_module(ctxptr, s) < 0
-                    || cia1571_read_snapshot_module(ctxptr, s) < 0)
+                if (via1d_snapshot_read_module(ctxptr, s) < 0
+                    || via2d_snapshot_read_module(ctxptr, s) < 0
+                    || cia1571_snapshot_read_module(ctxptr, s) < 0)
                     return -1;
             }
             if (drive[i].type == DRIVE_TYPE_1581) {
-                if (cia1581_read_snapshot_module(ctxptr, s) < 0)
+                if (cia1581_snapshot_read_module(ctxptr, s) < 0)
+                    return -1;
+            }
+            if (DRIVE_IS_OLDTYPE(drive[i].type)) {
+                if (riot1_snapshot_read_module(ctxptr, s) < 0
+                    || riot2_snapshot_read_module(ctxptr, s) < 0
+                    || fdc_snapshot_read_module(s, i) < 0)
                     return -1;
             }
-	    if (DRIVE_IS_OLDTYPE(drive[i].type)) {
-	        if (riot1_read_snapshot_module(ctxptr, s) < 0
-		    || riot2_read_snapshot_module(ctxptr, s) < 0
-		    || fdc_read_snapshot_module(s, i) < 0)
-		    return -1;
-	    }
         }
     }
 
-    if (drive_read_image_snapshot_module(s, 0) < 0
-	|| drive_read_gcrimage_snapshot_module(s, 0) < 0)
+    if (drive_snapshot_read_image_module(s, 0) < 0
+        || drive_snapshot_read_gcrimage_module(s, 0) < 0)
         return -1;
-    if (drive_read_image_snapshot_module(s, 1) < 0
-	|| drive_read_gcrimage_snapshot_module(s, 1) < 0)
+    if (drive_snapshot_read_image_module(s, 1) < 0
+        || drive_snapshot_read_gcrimage_module(s, 1) < 0)
         return -1;
-    if (drive_read_rom_snapshot_module(s, 0) < 0)
+    if (drive_snapshot_read_rom_module(s, 0) < 0)
         return -1;
-    if (drive_read_rom_snapshot_module(s, 1) < 0)
+    if (drive_snapshot_read_rom_module(s, 1) < 0)
         return -1;
 
     if (drive[0].type != DRIVE_TYPE_NONE)
@@ -487,13 +487,13 @@ int drive_read_snapshot_module(snapshot_t *s)
 /*
  * This image format is pretty simple:
  *
- * WORD Type		Disk image type (1581, 8050, 8250)
+ * WORD Type            Disk image type (1581, 8050, 8250)
  * 256 * blocks(disk image type) BYTE
- *			disk image
+ *                      disk image
  *
  */
 
-static int drive_write_image_snapshot_module(snapshot_t *s, unsigned int dnr)
+static int drive_snapshot_write_image_module(snapshot_t *s, unsigned int dnr)
 {
     char snap_module_name[10];
     snapshot_module_t *m;
@@ -538,7 +538,7 @@ static int drive_write_image_snapshot_module(snapshot_t *s, unsigned int dnr)
     return 0;
 }
 
-static int drive_read_image_snapshot_module(snapshot_t *s, unsigned int dnr)
+static int drive_snapshot_read_image_module(snapshot_t *s, unsigned int dnr)
 {
     BYTE major_version, minor_version;
     snapshot_module_t *m;
@@ -567,55 +567,55 @@ static int drive_read_image_snapshot_module(snapshot_t *s, unsigned int dnr)
     }
 
     if (snapshot_module_read_word(m, &word) < 0) {
-	snapshot_module_close(m);
-	return -1;
+        snapshot_module_close(m);
+        return -1;
     }
 
     switch(word) {
-    case 1581:
-	len = D81_FILE_SIZE;
-	break;
-    case 8050:
-	len = D80_FILE_SIZE;
-	break;
-    case 8250:
-	len = D82_FILE_SIZE;
-	break;
-    default:
-	log_error(drive_snapshot_log,
+      case 1581:
+        len = D81_FILE_SIZE;
+        break;
+      case 8050:
+        len = D80_FILE_SIZE;
+        break;
+      case 8250:
+        len = D82_FILE_SIZE;
+        break;
+      default:
+        log_error(drive_snapshot_log,
                   "Snapshot of disk image unknown (type %d)",
-		  (int)word);
+                  (int)word);
         snapshot_module_close(m);
-	return -1;
+        return -1;
     }
 
     /* create temporary file of the right size */
     p = tmpnam(filename);
     if (!p) {
-	log_error(drive_snapshot_log, "Could not create temporary filename");
+        log_error(drive_snapshot_log, "Could not create temporary filename");
         snapshot_module_close(m);
-	return -1;
+        return -1;
     }
     fp = fopen(filename, MODE_WRITE);
     if (!fp) {
-	log_error(drive_snapshot_log, "Could not create temporary file");
-	log_error(drive_snapshot_log, "filename=%s", filename);
+        log_error(drive_snapshot_log, "Could not create temporary file");
+        log_error(drive_snapshot_log, "filename=%s", filename);
         snapshot_module_close(m);
-	return -1;
+        return -1;
     }
     /* blow up the file to needed size */
     if (fseek(fp, len - 1, SEEK_SET) < 0
-	|| (fputc(0, fp) == EOF)) {
-	log_error(drive_snapshot_log, "Could not create large temporary file");
-	fclose(fp);
+        || (fputc(0, fp) == EOF)) {
+        log_error(drive_snapshot_log, "Could not create large temporary file");
+        fclose(fp);
         snapshot_module_close(m);
-	return -1;
+        return -1;
     }
     fclose(fp);
     if (file_system_attach_disk(dnr + 8, filename) < 0) {
         log_error(drive_snapshot_log, "Invalid Disk Image");
         snapshot_module_close(m);
-	return -1;
+        return -1;
     }
 
     sprintf(request_str, "Disk image unit #%d imported from snapshot", dnr + 8);
@@ -654,7 +654,7 @@ static int drive_read_image_snapshot_module(snapshot_t *s, unsigned int dnr)
 #define GCRIMAGE_SNAP_MAJOR 1
 #define GCRIMAGE_SNAP_MINOR 0
 
-static int drive_write_gcrimage_snapshot_module(snapshot_t *s, unsigned int dnr)
+static int drive_snapshot_write_gcrimage_module(snapshot_t *s, unsigned int dnr)
 {
     char snap_module_name[10];
     snapshot_module_t *m;
@@ -695,7 +695,7 @@ static int drive_write_gcrimage_snapshot_module(snapshot_t *s, unsigned int dnr)
     return 0;
 }
 
-static int drive_read_gcrimage_snapshot_module(snapshot_t *s, unsigned int dnr)
+static int drive_snapshot_read_gcrimage_module(snapshot_t *s, unsigned int dnr)
 {
     BYTE major_version, minor_version;
     snapshot_module_t *m;
@@ -711,7 +711,7 @@ static int drive_read_gcrimage_snapshot_module(snapshot_t *s, unsigned int dnr)
         return 0;
 
     if (major_version > GCRIMAGE_SNAP_MAJOR
-	|| minor_version > GCRIMAGE_SNAP_MINOR) {
+        || minor_version > GCRIMAGE_SNAP_MINOR) {
         log_error(drive_snapshot_log,
                   "Snapshot module version (%d.%d) newer than %d.%d.",
                   major_version, minor_version,
@@ -750,7 +750,7 @@ static int drive_read_gcrimage_snapshot_module(snapshot_t *s, unsigned int dnr)
 #define ROM_SNAP_MAJOR 1
 #define ROM_SNAP_MINOR 0
 
-static int drive_write_rom_snapshot_module(snapshot_t *s, unsigned int dnr)
+static int drive_snapshot_write_rom_module(snapshot_t *s, unsigned int dnr)
 {
     char snap_module_name[10];
     snapshot_module_t *m;
@@ -787,16 +787,16 @@ static int drive_write_rom_snapshot_module(snapshot_t *s, unsigned int dnr)
         break;
       case DRIVE_TYPE_2040:
         base = &(drive[dnr].rom[DRIVE_ROM_SIZE - DRIVE_ROM2040_SIZE]);
-	len = DRIVE_ROM2040_SIZE;
-	break;
+        len = DRIVE_ROM2040_SIZE;
+        break;
       case DRIVE_TYPE_3040:
         base = &(drive[dnr].rom[DRIVE_ROM_SIZE - DRIVE_ROM3040_SIZE]);
-	len = DRIVE_ROM3040_SIZE;
-	break;
+        len = DRIVE_ROM3040_SIZE;
+        break;
       case DRIVE_TYPE_4040:
         base = &(drive[dnr].rom[DRIVE_ROM_SIZE - DRIVE_ROM4040_SIZE]);
-	len = DRIVE_ROM4040_SIZE;
-	break;
+        len = DRIVE_ROM4040_SIZE;
+        break;
       case DRIVE_TYPE_1001:
       case DRIVE_TYPE_8050:
       case DRIVE_TYPE_8250:
@@ -817,7 +817,7 @@ static int drive_write_rom_snapshot_module(snapshot_t *s, unsigned int dnr)
     return 0;
 }
 
-static int drive_read_rom_snapshot_module(snapshot_t *s, unsigned int dnr)
+static int drive_snapshot_read_rom_module(snapshot_t *s, unsigned int dnr)
 {
     BYTE major_version, minor_version;
     snapshot_module_t *m;
@@ -862,16 +862,16 @@ static int drive_read_rom_snapshot_module(snapshot_t *s, unsigned int dnr)
         break;
       case DRIVE_TYPE_2040:
         base = &(drive[dnr].rom[DRIVE_ROM_SIZE - DRIVE_ROM2040_SIZE]);
-	len = DRIVE_ROM2040_SIZE;
-	break;
+        len = DRIVE_ROM2040_SIZE;
+        break;
       case DRIVE_TYPE_3040:
         base = &(drive[dnr].rom[DRIVE_ROM_SIZE - DRIVE_ROM3040_SIZE]);
-	len = DRIVE_ROM3040_SIZE;
-	break;
+        len = DRIVE_ROM3040_SIZE;
+        break;
       case DRIVE_TYPE_4040:
         base = &(drive[dnr].rom[DRIVE_ROM_SIZE - DRIVE_ROM4040_SIZE]);
-	len = DRIVE_ROM4040_SIZE;
-	break;
+        len = DRIVE_ROM4040_SIZE;
+        break;
       case DRIVE_TYPE_1001:
       case DRIVE_TYPE_8050:
       case DRIVE_TYPE_8250:
@@ -889,7 +889,7 @@ static int drive_read_rom_snapshot_module(snapshot_t *s, unsigned int dnr)
     }
 
     if (drive[dnr].type == DRIVE_TYPE_1541) {
-	drive_do_1541_checksum();
+        drive_do_1541_checksum();
     }
 
     snapshot_module_close(m);
