@@ -49,7 +49,6 @@
 #else
 #include <dirent.h>
 #endif
-#include <memory.h>
 #endif
 
 #ifdef HAVE_ERRNO_H
@@ -70,7 +69,7 @@
 
 #include "archdep.h"
 #include "attach.h"
-#include "charsets.h"
+#include "charset.h"
 #include "cmdline.h"
 #include "fsdevice.h"
 #include "log.h"
@@ -134,78 +133,79 @@ static char *fsdevice_dir[4];
 
 static int set_fsdevice_convert_p00(resource_value_t v, void *param)
 {
-    fsdevice_convert_p00_enabled[(int)param - 8] = (int) v;
+    fsdevice_convert_p00_enabled[(int)param - 8] = (int)v;
     return 0;
 }
 
 static int set_fsdevice_dir(resource_value_t v, void *param)
 {
-    const char *name = (const char *) v;
-    if (fsdevice_dir[(int)param - 8] != NULL && name != NULL
-        && strcmp(name, fsdevice_dir[(int)param - 8]) == 0)
-        return 0;
-    string_set(&fsdevice_dir[(int)param - 8], name ? name : "");
+    const char *name = (const char *)v;
+
+    util_string_set(&fsdevice_dir[(int)param - 8], name ? name : "");
     return 0;
 }
 
 static int set_fsdevice_save_p00(resource_value_t v, void *param)
 {
-    fsdevice_save_p00_enabled[(int)param - 8] = (int) v;
+    fsdevice_save_p00_enabled[(int)param - 8] = (int)v;
     return 0;
 }
 
 static int set_fsdevice_hide_cbm_files(resource_value_t v, void *param) 
 {
-    if (!fsdevice_convert_p00_enabled[(int)param - 8])
+    int val = (int)v;
+
+    if (val && !fsdevice_convert_p00_enabled[(int)param - 8])
         return -1;
-    fsdevice_hide_cbm_files_enabled[(int)param - 8] = (int)v;
+
+    fsdevice_hide_cbm_files_enabled[(int)param - 8] = val;
     return 0;
 }
 
 static resource_t resources[] = {
-    { "FSDevice8ConvertP00", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &fsdevice_convert_p00_enabled[0],
+    { "FSDevice8ConvertP00", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&fsdevice_convert_p00_enabled[0],
       set_fsdevice_convert_p00, (void *)8 },
-    { "FSDevice9ConvertP00", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &fsdevice_convert_p00_enabled[1],
+    { "FSDevice9ConvertP00", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&fsdevice_convert_p00_enabled[1],
       set_fsdevice_convert_p00, (void *)9 },
-    { "FSDevice10ConvertP00", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &fsdevice_convert_p00_enabled[2],
+    { "FSDevice10ConvertP00", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&fsdevice_convert_p00_enabled[2],
       set_fsdevice_convert_p00, (void *)10 },
-    { "FSDevice11ConvertP00", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &fsdevice_convert_p00_enabled[3],
+    { "FSDevice11ConvertP00", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&fsdevice_convert_p00_enabled[3],
       set_fsdevice_convert_p00, (void *)11 },
-    { "FSDevice8Dir", RES_STRING, (resource_value_t) FSDEVICE_DEFAULT_DIR,
-      (resource_value_t *) &fsdevice_dir[0], set_fsdevice_dir, (void *)8 },
-    { "FSDevice9Dir", RES_STRING, (resource_value_t) FSDEVICE_DEFAULT_DIR,
-      (resource_value_t *) &fsdevice_dir[1], set_fsdevice_dir, (void *)9 },
-    { "FSDevice10Dir", RES_STRING, (resource_value_t) FSDEVICE_DEFAULT_DIR,
-      (resource_value_t *) &fsdevice_dir[2], set_fsdevice_dir, (void *)10 },
-    { "FSDevice11Dir", RES_STRING, (resource_value_t) FSDEVICE_DEFAULT_DIR,
-      (resource_value_t *) &fsdevice_dir[3], set_fsdevice_dir, (void *)11 },
-    { "FSDevice8SaveP00", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &fsdevice_save_p00_enabled[0],
+    { "FSDevice8Dir", RES_STRING, (resource_value_t)FSDEVICE_DEFAULT_DIR,
+      (resource_value_t *)&fsdevice_dir[0], set_fsdevice_dir, (void *)8 },
+    { "FSDevice9Dir", RES_STRING, (resource_value_t)FSDEVICE_DEFAULT_DIR,
+      (resource_value_t *)&fsdevice_dir[1], set_fsdevice_dir, (void *)9 },
+    { "FSDevice10Dir", RES_STRING, (resource_value_t)FSDEVICE_DEFAULT_DIR,
+      (resource_value_t *)&fsdevice_dir[2], set_fsdevice_dir, (void *)10 },
+    { "FSDevice11Dir", RES_STRING, (resource_value_t)FSDEVICE_DEFAULT_DIR,
+      (resource_value_t *)&fsdevice_dir[3], set_fsdevice_dir, (void *)11 },
+    { "FSDevice8SaveP00", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&fsdevice_save_p00_enabled[0],
       set_fsdevice_save_p00, (void *)8 },
-    { "FSDevice9SaveP00", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &fsdevice_save_p00_enabled[1],
+    { "FSDevice9SaveP00", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&fsdevice_save_p00_enabled[1],
       set_fsdevice_save_p00, (void *)9 },
-    { "FSDevice10SaveP00", RES_INTEGER, (resource_value_t) 1,
-      (resource_value_t *) &fsdevice_save_p00_enabled[2],
+    { "FSDevice10SaveP00", RES_INTEGER, (resource_value_t)1,
+      (resource_value_t *)&fsdevice_save_p00_enabled[2],
       set_fsdevice_save_p00, (void *)10 },
-    { "FSDevice11SaveP00", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &fsdevice_save_p00_enabled[3],
+    { "FSDevice11SaveP00", RES_INTEGER, (resource_value_t)0,
+      (resource_value_t *)&fsdevice_save_p00_enabled[3],
       set_fsdevice_save_p00, (void *)11 },
-    { "FSDevice8HideCBMFiles", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &fsdevice_hide_cbm_files_enabled[0],
+    { "FSDevice8HideCBMFiles", RES_INTEGER, (resource_value_t)0,
+      (resource_value_t *)&fsdevice_hide_cbm_files_enabled[0],
       set_fsdevice_hide_cbm_files, (void *)8 },
-    { "FSDevice9HideCBMFiles", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &fsdevice_hide_cbm_files_enabled[1],
+    { "FSDevice9HideCBMFiles", RES_INTEGER, (resource_value_t)0,
+      (resource_value_t *)&fsdevice_hide_cbm_files_enabled[1],
       set_fsdevice_hide_cbm_files, (void *)9 },
-    { "FSDevice10HideCBMFiles", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &fsdevice_hide_cbm_files_enabled[2],
+    { "FSDevice10HideCBMFiles", RES_INTEGER, (resource_value_t)0,
+      (resource_value_t *)&fsdevice_hide_cbm_files_enabled[2],
       set_fsdevice_hide_cbm_files, (void *)10 },
-    { "FSDevice11HideCBMFiles", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &fsdevice_hide_cbm_files_enabled[3],
+    { "FSDevice11HideCBMFiles", RES_INTEGER, (resource_value_t)0,
+      (resource_value_t *)&fsdevice_hide_cbm_files_enabled[3],
       set_fsdevice_hide_cbm_files, (void *)11 },
     { NULL }
 };
@@ -232,13 +232,13 @@ static int cmdline_fsdirectory(const char *param, void *extra_param)
 }
 
 static cmdline_option_t cmdline_options[] = {
-    { "-fs8", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *) 8, NULL, NULL,
+    { "-fs8", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)8, NULL, NULL,
       "<name>", "Use <name> as directory for file system device #8" },
-    { "-fs9", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *) 9, NULL, NULL,
+    { "-fs9", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)9, NULL, NULL,
       "<name>", "Use <name> as directory for file system device #9" },
-    { "-fs10", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *) 10, NULL, NULL,
+    { "-fs10", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)10, NULL, NULL,
       "<name>", "Use <name> as directory for file system device #10" },
-    { "-fs11", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *) 11, NULL, NULL,
+    { "-fs11", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)11, NULL, NULL,
       "<name>", "Use <name> as directory for file system device #11" },
     { NULL }
 };
@@ -336,7 +336,7 @@ static void flush_fs(vdrive_t *vdrive, unsigned int secondary)
     fs_cmdbuf[fs_cptr] = 0;
 
     strcpy(cbmcmd, fs_cmdbuf);
-    petconvstring(cbmcmd, 1);   /* CBM name to FSname */
+    charset_petconvstring(cbmcmd, 1);   /* CBM name to FSname */
     cmd = cbmcmd;
     while (*cmd == ' ')
         cmd++;
@@ -394,7 +394,7 @@ static void flush_fs(vdrive_t *vdrive, unsigned int secondary)
                 strcat(name1, FSDEV_DIR_SEP_STR);
                 strcat(name1, arg);
             }
-        if (remove_file(name1)) {
+        if (util_file_remove(name1)) {
             er = IPE_NOT_FOUND;
             if (errno == EPERM)
                 er = IPE_PERMISSION;
@@ -451,7 +451,7 @@ static void flush_fs(vdrive_t *vdrive, unsigned int secondary)
                             continue;
                         }
 
-                        remove_file(name1p00);
+                        util_file_remove(name1p00);
                         if (rename(name2p00, name1p00) == 0)
                             break;
                     }
@@ -470,7 +470,7 @@ static void flush_fs(vdrive_t *vdrive, unsigned int secondary)
                 strcat(name2, FSDEV_DIR_SEP_STR);
                 strcat(name2, arg2);
 
-                remove_file(name1);
+                util_file_remove(name1);
                 if (rename(name2, name1)) {
                     er = IPE_NOT_FOUND;
                     if (errno == EPERM)
@@ -648,7 +648,7 @@ static int read_fs(vdrive_t *vdrive, BYTE * data, unsigned int secondary)
                         for (i = 0; rname[i] && (*p = rname[i]); ++i, ++p);
                     } else {
                         for (i = 0; tp[i] /*i < dirp->d_namlen */ &&
-                             (*p = p_topetcii(tp[i])); ++i, ++p);
+                             (*p = charset_p_topetcii(tp[i])); ++i, ++p);
                     }
 
                     *p++ = '"';
@@ -774,7 +774,7 @@ static int open_fs(vdrive_t *vdrive, const char *name, int length,
     fsname[reallength] = 0;
     strncpy(rname, fsname, reallength);
 
-    petconvstring(fsname, 1);   /* CBM name to FSname */
+    charset_petconvstring(fsname, 1);   /* CBM name to FSname */
 
     switch (readmode) {
       case FAM_WRITE:
@@ -840,7 +840,7 @@ static int open_fs(vdrive_t *vdrive, const char *name, int length,
 
         *p++ = '"';
         strcpy((char *) p, fs_info[secondary].dir);     /* Dir name */
-        petconvstring((char *) p, 0);   /* ASCII name to PETSCII */
+        charset_petconvstring((char *) p, 0);   /* ASCII name to PETSCII */
         i = 0;
         while (*p) {
             ++p;
