@@ -42,6 +42,7 @@
 
 extern void keyboard_init(void);
 extern void keyboard_set_keyarr(int row, int col, int value);
+extern void keyboard_set_keyarr_and_latch(int row, int col, int value);
 extern void keyboard_clear_keymatrix(void);
 
 enum joystick_bits_s {
@@ -67,16 +68,20 @@ extern int c64_kbd_init(void);
 extern int c128_kbd_init(void);
 extern int vic20_kbd_init(void);
 extern int pet_kbd_init(void);
+extern int plus4_kbd_init(void);
 extern int c610_kbd_init(void);
 
-extern int kbd_init_cmdline_options(void);
-extern int kbd_init_resources(void);
+extern int kbd_cmdline_options_init(void);
+extern int kbd_resources_init(void);
 
-extern int pet_kbd_init_cmdline_options(void);
-extern int pet_kbd_init_resources(void);
+extern int pet_kbd_cmdline_options_init(void);
+extern int pet_kbd_resources_init(void);
 
-typedef void (*key_ctrl_column4080_func_t) (void);
+typedef void (*key_ctrl_column4080_func_t)(void);
 extern void kbd_register_column4080_key(key_ctrl_column4080_func_t func);
 
+typedef void (*key_ctrl_caps_func_t)(void);
+extern void kbd_register_caps_key(key_ctrl_caps_func_t func);
+
 #endif
 
