@@ -40,8 +40,7 @@
 static FILE *log_file = NULL;
 
 static char **logs = NULL;
-static unsigned int num_logs = 0;
-static unsigned int num_allocated_logs = 0;
+static log_t num_logs = 0;
 
 /* ------------------------------------------------------------------------- */
 
@@ -49,15 +48,15 @@ static char *log_file_name;
 
 static int set_log_file_name(resource_value_t v, void *param)
 {
-    string_set(&log_file_name, (const char *) v);
+    util_string_set(&log_file_name, (const char *)v);
 
     return 0;
 }
 
-#ifndef __C1541__
+#ifndef __X1541__
 static resource_t resources[] = {
-    { "LogFileName", RES_STRING, (resource_value_t) NULL,
-      (resource_value_t *) &log_file_name, set_log_file_name, NULL },
+    { "LogFileName", RES_STRING, (resource_value_t)"",
+      (resource_value_t *)&log_file_name, set_log_file_name, NULL },
     { NULL }
 };
 
@@ -97,42 +96,38 @@ int log_init(void)
     if (log_file_name == NULL || *log_file_name == 0)
     {
         log_file = archdep_open_default_log_file();
+        return log_file<0 ? -1 : 0;
     }
     else
     {
+#ifndef __OS2__
         if (strcmp(log_file_name, "-") == 0)
             log_file = stdout;
         else
+#endif
             log_file = fopen(log_file_name, MODE_WRITE_TEXT);
     }
     /* flush all data direct to the output stream. */
-    if (log_file) setbuf(log_file, NULL);
+    if (log_file)
+        setbuf(log_file, NULL);
 
     return log_file == NULL ? -1 : 0;
 }
 
-int log_open(const char *id)
+log_t log_open(const char *id)
 {
     log_t new_log = 0;
-    int i;
+    log_t i;
 
-    for (i = 0; i < ((int)num_logs); i++) {
+    for (i = 0; i < num_logs; i++) {
         if (logs[i] == NULL) {
             new_log = i;
             break;
         }
     }
-    if (i == ((int)num_logs)) {
+    if (i == num_logs) {
         new_log = num_logs++;
-        if (num_logs > num_allocated_logs) {
-            if (num_allocated_logs == 0) {
-                num_allocated_logs = 128;
-                logs = (char**)xmalloc(sizeof(*logs) * num_allocated_logs);
-            } else {
-                num_allocated_logs *= 2;
-                logs = (char**)xrealloc(logs, sizeof(*logs) * num_allocated_logs);
-            }
-        }
+        logs = (char**)xrealloc(logs, sizeof(*logs) * num_logs);
     }
 
     logs[new_log] = stralloc(id);
@@ -148,35 +143,78 @@ int log_close(log_t log)
     return 0;
 }
 
+static int log_archdep(const char *logtxt, const char *fmt, va_list ap)
+{
+    /*
+     * ------ Split into single lines ------
+     */
+    int rc = 0;
+
+    char *txt = xmvsprintf(fmt, ap);
+
+    char *beg = txt;
+    char *end = txt + strlen(txt)+1;
+
+    while (beg < end)
+    {
+        char *eol = strchr(beg, '\n');
+
+        if (eol)
+            *eol='\0';
+
+        if (archdep_default_logger(*beg?logtxt:"", beg)<0)
+        {
+            rc = -1;
+            break;
+        }
+
+        if (!eol)
+            break;
+
+        beg = eol+1;
+    }
+
+    free(txt);
+
+    return rc;
+}
+
 static int log_helper(log_t log, unsigned int level,
                       const char *format, va_list ap)
 {
     static const char *level_strings[3] = {
         "",
-        "Warning: ",
-        "Error: "
+        "Warning - ",
+        "Error - "
     };
 
-    if (log_file == NULL) 
-	return archdep_default_logger(level_strings[level], format, ap);
+    const signed int logi = (signed int)log;
 
-    if (log == LOG_ERR
-        || (log != LOG_DEFAULT && logs[(unsigned int) log] == NULL)
-        || log_file == NULL) 
+    int rc=0;
+
+    char *logtxt = NULL;
+
+    if (logi==LOG_ERR || (logi != LOG_DEFAULT && logs[logi] == NULL))
         return -1;
 
-    if (log != LOG_DEFAULT && *logs[(unsigned int) log] != 0) {
-        if (fputs (logs[(unsigned int) log], log_file) == EOF
-            || fputs (": ", log_file) == EOF)
-            return -1;
+    if (logi!=LOG_DEFAULT && *logs[logi]!='\0')
+        logtxt = xmsprintf("%s: %s", logs[logi], level_strings[level]);
+    else
+        logtxt = stralloc("");
+
+    if (log_file == NULL) {
+        rc = log_archdep(logtxt, format, ap);
+    }
+    else {
+        if (fputs(logtxt, log_file) == EOF
+            || vfprintf(log_file, format, ap) < 0
+            || fputc ('\n', log_file) == EOF)
+            rc = -1;
     }
 
-    if (fputs(level_strings[level], log_file) == EOF
-        || vfprintf(log_file, format, ap) < 0
-        || fputc ('\n', log_file) == EOF)
-        return -1;
+    free(logtxt);
 
-    return 0;
+    return rc;
 }
 
 int log_message(log_t log, const char *format, ...)
@@ -210,3 +248,4 @@ int log_debug(const char *format, ...)
     va_start(ap, format);
     return log_helper(LOG_DEFAULT, 0, format, ap);
 }
+
