@@ -40,11 +40,12 @@ extern const char machine_name[];
 #define VICE_MACHINE_VIC20     3
 #define VICE_MACHINE_PET       4
 #define VICE_MACHINE_CBM2      5
+#define VICE_MACHINE_PLUS4     6
 
 extern int machine_class;
 extern int vsid_mode;
 extern
-#ifdef OS2
+#ifdef __OS2__
     const
 #endif
 int console_mode;
@@ -60,6 +61,7 @@ extern int machine_init(void);
 
 /* Reset the machine.  */
 extern void machine_reset(void);
+extern void machine_specific_reset(void);
 
 /* Power-up the machine.  */
 extern void machine_powerup(void);
@@ -91,14 +93,29 @@ extern void machine_handle_pending_alarms(int num_write_cycles);
 extern int machine_autodetect_psid(const char *name);
 extern void machine_play_psid(int tune);
 
+/* Check the base address for the second sid chip.  */
+extern int machine_sid2_check_range(unsigned int sid2_adr);
+
 /* Change the timing parameters of the maching (for example PAL/NTSC).  */
 extern void machine_change_timing(int timeval);
 
 /* Get screenshot data.  */
 struct screenshot_s;
-struct canvas_s;
+struct video_canvas_s;
 extern int machine_screenshot(struct screenshot_s *screenshot, unsigned int wn);
-extern int machine_canvas_screenshot(struct screenshot_s *screenshot, struct canvas_s *canvas);
+extern int machine_canvas_screenshot(struct screenshot_s *screenshot,
+                                     struct video_canvas_s *canvas);
+
+#define JAM_NONE       0
+#define JAM_RESET      1
+#define JAM_HARD_RESET 2
+#define JAM_MONITOR    3
+unsigned int machine_jam(const char *format, ...);
+
+extern void machine_video_refresh(void);
+
+/* Update memory pointers if memory mapping has changed. */
+extern void machine_update_memory_ptrs(void);
 
 #endif /* _MACHINE_H */
 
