@@ -44,7 +44,7 @@
 #include "attach.h"
 #include "autostart.h"
 #include "cartridge.h"
-#include "charsets.h"
+#include "charset.h"
 #include "cmdline.h"
 #include "console.h"
 #include "diskimage.h"
@@ -52,6 +52,7 @@
 #include "drivecpu.h"
 #include "fsdevice.h"
 #include "fullscreen.h"
+#include "gfxoutput.h"
 #include "interrupt.h"
 #include "joystick.h"
 #include "kbd.h"
@@ -61,6 +62,7 @@
 #include "machine.h"
 #include "maincpu.h"
 #include "main_exit.h"
+#include "palette.h"
 #include "resources.h"
 #include "sysfile.h"
 #include "screenshot.h"
@@ -72,14 +74,10 @@
 #include "version.h"
 #include "video.h"
 
-#ifdef HAVE_MOUSE
-#include "mouse.h"
-#endif
-
 /* ------------------------------------------------------------------------- */
 
 int vsid_mode = 0;
-#ifdef OS2
+#ifdef __OS2__
 const
 #endif
 int console_mode = 0;
@@ -95,10 +93,10 @@ static char *startup_tape_image;
 
 static int cmdline_help(const char *param, void *extra_param)
 {
-    cmdline_show_help();
+    cmdline_show_help(NULL);
     exit(0);
 
-    return 0;	/* OSF1 cc complains */
+    return 0;   /* OSF1 cc complains */
 }
 
 static int cmdline_default(const char *param, void *extra_param)
@@ -115,7 +113,7 @@ static int cmdline_autostart(const char *param, void *extra_param)
     return 0;
 }
 
-#ifndef OS2
+#ifndef __OS2__
 static int cmdline_console(const char *param, void *extra_param)
 {
     console_mode = 1;
@@ -154,17 +152,19 @@ static cmdline_option_t vsid_cmdline_options[] = {
       NULL, "Show a list of the available options and exit normally" },
     { "-?", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
       NULL, "Show a list of the available options and exit normally" },
-#ifndef OS2
+    { "-h", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
+      NULL, "Show a list of the available options and exit normally" },
+#if (!defined  __OS2__ && !defined __BEOS__)
     { "-console", CALL_FUNCTION, 0, cmdline_console, NULL, NULL, NULL,
-      NULL, "Console mode (for playing music)" },
-    { "-core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 1,
+      NULL, "Console mode (for music playback)" },
+    { "-core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
       NULL, "Allow production of core dumps" },
-    { "+core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 0,
+    { "+core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
       NULL, "Do not produce core dumps" },
 #else
-    { "-debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 1,
+    { "-debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
       NULL, "Don't call exception handler" },
-    { "+debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 0,
+    { "+debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
       NULL, "Call exception handler (default)" },
 #endif
     { NULL }
@@ -175,31 +175,33 @@ static cmdline_option_t cmdline_options[] = {
       NULL, "Show a list of the available options and exit normally" },
     { "-?", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
       NULL, "Show a list of the available options and exit normally" },
+    { "-h", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
+      NULL, "Show a list of the available options and exit normally" },
     { "-default", CALL_FUNCTION, 0, cmdline_default, NULL, NULL, NULL,
       NULL, "Restore default (factory) settings" },
     { "-autostart", CALL_FUNCTION, 1, cmdline_autostart, NULL, NULL, NULL,
       "<name>", "Attach and autostart tape/disk image <name>" },
-    { "-1", CALL_FUNCTION, 1, cmdline_attach, (void *) 1, NULL, NULL,
+    { "-1", CALL_FUNCTION, 1, cmdline_attach, (void *)1, NULL, NULL,
       "<name>", "Attach <name> as a tape image" },
-    { "-8", CALL_FUNCTION, 1, cmdline_attach, (void *) 8, NULL, NULL,
+    { "-8", CALL_FUNCTION, 1, cmdline_attach, (void *)8, NULL, NULL,
       "<name>", "Attach <name> as a disk image in drive #8" },
-    { "-9", CALL_FUNCTION, 1, cmdline_attach, (void *) 9, NULL, NULL,
+    { "-9", CALL_FUNCTION, 1, cmdline_attach, (void *)9, NULL, NULL,
       "<name>", "Attach <name> as a disk image in drive #9" },
-    { "-10", CALL_FUNCTION, 1, cmdline_attach, (void *) 10, NULL, NULL,
+    { "-10", CALL_FUNCTION, 1, cmdline_attach, (void *)10, NULL, NULL,
       "<name>", "Attach <name> as a disk image in drive #10" },
-    { "-11", CALL_FUNCTION, 1, cmdline_attach, (void *) 11, NULL, NULL,
+    { "-11", CALL_FUNCTION, 1, cmdline_attach, (void *)11, NULL, NULL,
       "<name>", "Attach <name> as a disk image in drive #11" },
-#ifdef OS2
-    { "-debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 1,
+#if defined  __OS2__ || defined __BEOS__
+    { "-debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
       NULL, "Don't call exception handler" },
-    { "+debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 0,
+    { "+debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
       NULL, "Call exception handler (default)" },
 #else
     { "-console", CALL_FUNCTION, 0, cmdline_console, NULL, NULL, NULL,
       NULL, "Console mode (for playing music)" },
-    { "-core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 1,
+    { "-core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
       NULL, "Allow production of core dumps" },
-    { "+core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t) 0,
+    { "+core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
       NULL, "Do not produce core dumps" },
 #endif
     { NULL }
@@ -263,12 +265,6 @@ static int init_resources(void)
         archdep_startup_log_error("Cannot initialize joystick-specific resources.\n");
         return -1;
     }
-#ifdef HAVE_MOUSE
-    if (mouse_init_resources() < 0) {
-        archdep_startup_log_error("Cannot initialize mouse-specific resources.\n");
-        return -1;
-    }
-#endif
     return 0;
 }
 
@@ -293,11 +289,11 @@ static int init_cmdline_options(void)
         archdep_startup_log_error("Cannot initialize command-line options for system file locator.\n");
         return -1;
     }
-    if (ui_init_cmdline_options() < 0) {
+    if (!vsid_mode && ui_init_cmdline_options() < 0) {
         archdep_startup_log_error("Cannot initialize UI-specific command-line options.\n");
         return -1;
     }
-    if (file_system_init_cmdline_options() < 0) {
+    if (!vsid_mode && file_system_init_cmdline_options() < 0) {
         archdep_startup_log_error("Cannot initialize Attach-specific command-line options.\n");
         return -1;
     }
@@ -318,12 +314,6 @@ static int init_cmdline_options(void)
         archdep_startup_log_error("Cannot initialize joystick-specific command-line options.\n");
         return -1;
     }
-#ifdef HAVE_MOUSE
-    if (mouse_init_cmdline_options() < 0) {
-        archdep_startup_log_error("Cannot initialize mouse-specific command-line options.\n");
-        return -1;
-    }
-#endif
     if (kbd_buf_init_cmdline_options() < 0) {
         archdep_startup_log_error("Cannot initialize keyboard buffer-specific command-line options.\n");
         return -1;
@@ -398,6 +388,7 @@ static char *replace_hexcodes(char *s)
 /* This is the main program entry point.  When not compiling for Windows,
    this is `main()'; on Windows we have to #define the name to something
    different because the standard entry point is `WinMain()' there.  */
+
 int MAIN_PROGRAM(int argc, char **argv)
 {
     int i;
@@ -406,30 +397,30 @@ int MAIN_PROGRAM(int argc, char **argv)
        -console => no user interface
        -vsid    => user interface in separate process */
     for (i = 0; i < argc; i++) {
-#ifndef OS2
+#ifndef __OS2__
         if (strcmp(argv[i], "-console") == 0) {
-	    console_mode = 1;
-	} else
+            console_mode = 1;
+        } else
 #endif
-	if (strcmp(argv[i], "-vsid") == 0) {
-	    vsid_mode = 1;
-	}
+        if (strcmp(argv[i], "-vsid") == 0) {
+            vsid_mode = 1;
+        }
     }
 
 #ifdef ENABLE_NLS
     /* gettext stuff, not needed in Gnome, but here I can
        overrule the default locale path */
-    setlocale (LC_ALL, "");
+    setlocale(LC_ALL, "");
     bindtextdomain (PACKAGE, NLS_LOCALEDIR);
-    textdomain (PACKAGE);
+    textdomain(PACKAGE);
 #endif
 
     archdep_startup(&argc, argv);
 
 #ifndef __riscos
     if (atexit (main_exit) < 0) {
-	perror ("atexit");
-	return -1;
+        perror ("atexit");
+        return -1;
     }
 #endif
 
@@ -454,16 +445,16 @@ int MAIN_PROGRAM(int argc, char **argv)
 
     /* Load the user's default configuration file.  */
     if (vsid_mode) {
-	resources_set_value("Drive8Type", (resource_value_t)0);
-	resources_set_value("Sound", (resource_value_t)1);
+        resources_set_value("Drive8Type", (resource_value_t)0);
+        resources_set_value("Sound", (resource_value_t)1);
 #ifdef HAVE_RESID
-	resources_set_value("SidUseResid", (resource_value_t)1);
+        resources_set_value("SidUseResid", (resource_value_t)1);
 #endif
-	resources_set_value("SidModel", (resource_value_t)0);
-	resources_set_value("SidFilters", (resource_value_t)1);
-	resources_set_value("SoundSampleRate", (resource_value_t)44100);
-	resources_set_value("SoundSpeedAdjustment", (resource_value_t)2);
-	resources_set_value("SoundBufferSize", (resource_value_t)1000);
+        resources_set_value("SidModel", (resource_value_t)0);
+        resources_set_value("SidFilters", (resource_value_t)1);
+        resources_set_value("SoundSampleRate", (resource_value_t)44100);
+        resources_set_value("SoundSpeedAdjustment", (resource_value_t)2);
+        resources_set_value("SoundBufferSize", (resource_value_t)1000);
         resources_set_value("SoundSuspendTime", (resource_value_t)0);
     } else {
         int retval = resources_load(NULL);
@@ -515,8 +506,8 @@ int MAIN_PROGRAM(int argc, char **argv)
                 archdep_program_name(), machine_name);
     log_message(LOG_DEFAULT, " ");
     log_message(LOG_DEFAULT, "Written by");
-    log_message(LOG_DEFAULT, "E. Perazzoli, T. Rantanen, A. Fachat, D. Sladic, A. Boose,");
-    log_message(LOG_DEFAULT, "T. Biczo, J. Valta, J. Sonninen and T. Bretz.");
+    log_message(LOG_DEFAULT, "D. Sladic, A. Boose, D. Lem, T. Biczo, A. Dehmel, T. Bretz,");
+    log_message(LOG_DEFAULT, "A. Matthies, M. Pottendorfer, M. Brenner, S. Trikaliotis.");
     log_message(LOG_DEFAULT, " ");
     log_message(LOG_DEFAULT, "This is free software with ABSOLUTELY NO WARRANTY.");
     log_message(LOG_DEFAULT, "See the \"About VICE\" command for more info.");
@@ -533,16 +524,16 @@ int MAIN_PROGRAM(int argc, char **argv)
     archdep_setup_signals(do_core_dumps);
 
     /* Check for PSID here since we don't want to allow autodetection
-       in autostart.c. ROM image loading should also be skipped. */
+       in autostart.c. */
     if (vsid_mode)
     {
         if (autostart_string
-	    && machine_autodetect_psid(autostart_string) == -1)
-	{
-	    log_error(LOG_DEFAULT, "`%s' is not a valid PSID file.",
-		      autostart_string);
-	    return -1;
-	}
+            && machine_autodetect_psid(autostart_string) == -1)
+        {
+            log_error(LOG_DEFAULT, "`%s' is not a valid PSID file.",
+                      autostart_string);
+            return -1;
+        }
     }
 
     if (!vsid_mode)
@@ -552,6 +543,8 @@ int MAIN_PROGRAM(int argc, char **argv)
         joystick_init();
 #endif
 
+        palette_init();
+        gfxoutput_init();
         screenshot_init();
 
         drive0_cpu_early_init();
@@ -564,6 +557,7 @@ int MAIN_PROGRAM(int argc, char **argv)
         return -1;
     }
 
+    /* FIXME: what's about uimon_init??? */
     if (!vsid_mode && console_init() < 0) {
         log_error(LOG_DEFAULT, "Console initialization failed.");
         return -1;
@@ -597,15 +591,18 @@ int MAIN_PROGRAM(int argc, char **argv)
                     char *name;
 
                     fclose(autostart_fd);
-                    petconvstring(autostart_prg_name, 0);
+                    charset_petconvstring(autostart_prg_name, 0);
                     name = replace_hexcodes(autostart_prg_name);
-                    autostart_autodetect(autostart_file, name, 0);
+                    autostart_autodetect(autostart_file, name, 0,
+                                         AUTOSTART_MODE_RUN);
                     free(name);
                 } else
-                    autostart_autodetect(autostart_string, NULL, 0);
+                    autostart_autodetect(autostart_string, NULL, 0,
+                                         AUTOSTART_MODE_RUN);
                 free(autostart_file);
             } else {
-                autostart_autodetect(autostart_string, NULL, 0);
+                autostart_autodetect(autostart_string, NULL, 0,
+                                     AUTOSTART_MODE_RUN);
             }
         }
 
@@ -627,6 +624,7 @@ int MAIN_PROGRAM(int argc, char **argv)
                       startup_tape_image);
 
     }
+
     ui_init_finalize();
 
     init_done = 1;
@@ -634,12 +632,12 @@ int MAIN_PROGRAM(int argc, char **argv)
     /* Let's go...  */
     maincpu_trigger_reset();
 
-#ifdef USE_VIDMODE_EXTENSION
+#ifdef USE_XF86_EXTENSIONS
     if (!(console_mode || vsid_mode))
         fullscreen_mode_init();
 #endif
 
-    mainloop(((ADDRESS)0));
+    maincpu_mainloop();
 
     log_error(LOG_DEFAULT, "perkele!");
 
