@@ -46,8 +46,8 @@
 #define mypia_store pia2_store
 #define mypia_read pia2_read
 #define mypia_peek pia2_peek
-#define mypia_write_snapshot_module pia2_write_snapshot_module
-#define mypia_read_snapshot_module pia2_read_snapshot_module
+#define mypia_snapshot_write_module pia2_snapshot_write_module
+#define mypia_snapshot_read_module pia2_snapshot_read_module
 #define mypia_signal pia2_signal
 
 static piareg mypia;
@@ -55,11 +55,11 @@ static piareg mypia;
 /* ------------------------------------------------------------------------- */
 /* CPU binding */
 
-#define my_set_int(a)                                                   \
+#define my_set_int(a) \
         maincpu_set_irq(I_PIA1, (a)? IK_IRQ : IK_NONE)
 
 #define my_restore_int(a)                                     \
-        interrupt_set_int_noclk(&maincpu_int_status, I_PIA1,  \
+        interrupt_set_irq_noclk(&maincpu_int_status, I_PIA1,  \
         (a) ? IK_IRQ : IK_NONE)
 
 #define mycpu_rmw_flag  rmw_flag
@@ -70,27 +70,26 @@ static piareg mypia;
 
 _PIA_FUNC void pia_set_ca2(int a)
 {
-    parallel_cpu_set_ndac((a)?0:1);
+    parallel_cpu_set_ndac((BYTE)((a) ? 0 : 1));
 }
 
 _PIA_FUNC void pia_set_cb2(int a)
 {
-    parallel_cpu_set_dav((a)?0:1);
+    parallel_cpu_set_dav((BYTE)((a) ? 0 : 1));
 }
 
 _PIA_FUNC void pia_reset(void)
 {
-    parallel_cpu_set_bus(0xff);	/* all data lines high, because of input mode */
-}
+    parallel_cpu_set_bus(0xff); /* all data lines high, because of input mode */}
 
 
 /*
-E820	PORT A	    Input buffer for IEEE data lines
-E821	CA2	    IEEE NDAC out
-	CA1	    IEEE ATN in
-E822	PORT B	    Output buffer for IEEE data lines
-E823	CB2	    IEEE DAV out
-	CB1	    IEEE SRQ in
+E820    PORT A      Input buffer for IEEE data lines
+E821    CA2         IEEE NDAC out
+        CA1         IEEE ATN in
+E822    PORT B      Output buffer for IEEE data lines
+E823    CB2         IEEE DAV out
+        CB1         IEEE SRQ in
 */
 
 _PIA_FUNC void store_pa(BYTE byte)
@@ -122,7 +121,7 @@ _PIA_FUNC BYTE read_pa(void)
         drive1_cpu_execute(clk);
 
     if (parallel_debug)
-	log_message(mypia_log,
+        log_message(mypia_log,
                 "read pia2 port A %x, parallel_bus=%x, gives %x.",
                 mypia.port_a, parallel_bus,
                 ((parallel_bus & ~mypia.ddr_a)
