@@ -1,6 +1,6 @@
 //  ---------------------------------------------------------------------------
 //  This file is part of reSID, a MOS6581 SID emulator engine.
-//  Copyright (C) 2000  Dag Lem <resid@nimrod.no>
+//  Copyright (C) 2002  Dag Lem <resid@nimrod.no>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -41,18 +41,22 @@ public:
   ExternalFilter();
 
   void enable_filter(bool enable);
+  void set_chip_model(chip_model model);
 
-  void clock(sound_sample Vi);
-  void clock(cycle_count delta_t, sound_sample Vi);
+  RESID_INLINE void clock(sound_sample Vi);
+  RESID_INLINE void clock(cycle_count delta_t, sound_sample Vi);
   void reset();
 
   // Audio output (20 bits).
-  sound_sample output();
+  RESID_INLINE sound_sample output();
 
 protected:
   // Filter enabled.
   bool enabled;
 
+  // Maximum mixer DC offset.
+  sound_sample mixer_DC;
+
   // State of filters.
   sound_sample Vlp; // lowpass
   sound_sample Vhp; // highpass
@@ -72,22 +76,19 @@ friend class SID;
 // time a sample is calculated.
 // ----------------------------------------------------------------------------
 
-#if RESID_INLINE || defined(__EXTFILT_CC__)
+#if RESID_INLINING || defined(__EXTFILT_CC__)
 
 // ----------------------------------------------------------------------------
 // SID clocking - 1 cycle.
 // ----------------------------------------------------------------------------
-#if RESID_INLINE
-inline
-#endif
+RESID_INLINE
 void ExternalFilter::clock(sound_sample Vi)
 {
   // This is handy for testing.
   if (!enabled) {
-    // Normalize output since there is no filter to do it.
-    const sound_sample Vmax = 4096*3*0x0f;
+    // Remove maximum DC level since there is no filter to do it.
     Vlp = Vhp = 0;
-    Vo = Vi + Vmax;
+    Vo = Vi - mixer_DC;
     return;
   }
 
@@ -109,18 +110,15 @@ void ExternalFilter::clock(sound_sample Vi)
 // ----------------------------------------------------------------------------
 // SID clocking - delta_t cycles.
 // ----------------------------------------------------------------------------
-#if RESID_INLINE
-inline
-#endif
+RESID_INLINE
 void ExternalFilter::clock(cycle_count delta_t,
 			   sound_sample Vi)
 {
   // This is handy for testing.
   if (!enabled) {
-    // Normalize output since there is no filter to do it.
-    const sound_sample Vmax = 4096*3*0x0f;
+    // Remove maximum DC level since there is no filter to do it.
     Vlp = Vhp = 0;
-    Vo = Vi + Vmax;
+    Vo = Vi - mixer_DC;
     return;
   }
 
@@ -155,14 +153,12 @@ void ExternalFilter::clock(cycle_count delta_t,
 // ----------------------------------------------------------------------------
 // Audio output (19.5 bits).
 // ----------------------------------------------------------------------------
-#if RESID_INLINE
-inline
-#endif
+RESID_INLINE
 sound_sample ExternalFilter::output()
 {
   return Vo;
 }
 
-#endif // RESID_INLINE || defined(__EXTFILT_CC__)
+#endif // RESID_INLINING || defined(__EXTFILT_CC__)
 
 #endif // not __EXTFILT_H__
