@@ -1,7 +1,7 @@
 #! /usr/bin/perl -w
 #   ---------------------------------------------------------------------------
 #   This file is part of reSID, a MOS6581 SID emulator engine.
-#   Copyright (C) 1999  Dag Lem <resid@nimrod.no>
+#   Copyright (C) 2002  Dag Lem <resid@nimrod.no>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -20,27 +20,20 @@
 
 use strict;
 
-die("Usage: samp2src name data-in src-out\n") unless $#ARGV == 2;
-my ($name, $in, $out) = @ARGV[0..2];
+die("Usage: samp2src name data-in src-out\n") unless @ARGV == 3;
+my ($name, $in, $out) = @ARGV;
 
 open(F, "<$in") or die($!);
 local $/ = undef;
 my $data = <F>;
 close(F) or die($!);
 
-my @sample = map(sprintf("0x%02x", ord($_)), split(//, $data));
-
-$data = '';
-my $i;
-for ($i = 0; $i <= $#sample; $i += 8) {
-  $data .= sprintf("/* 0x%03x: */  ", $i) . join(', ', @sample[$i..$i+7]) . ",\n";
-}
-
 open(F, ">$out") or die($!);
+
 print F <<\EOF;
 //  ---------------------------------------------------------------------------
 //  This file is part of reSID, a MOS6581 SID emulator engine.
-//  Copyright (C) 1999  Dag Lem <resid@nimrod.no>
+//  Copyright (C) 2002  Dag Lem <resid@nimrod.no>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -58,9 +51,15 @@ print F <<\EOF;
 //  ---------------------------------------------------------------------------
 
 EOF
+
 print F "#include \"wave.h\"\n\nreg8 WaveformGenerator::$name\[\] =\n{\n";
-print F $data;
+
+for (my $i = 0; $i < length($data); $i += 8) {
+  print F sprintf("/* 0x%03x: */ ", $i), map(sprintf(" 0x%02x,", $_), unpack("C*", substr($data, $i, 8))), "\n";
+}
+
 print F "};\n";
+
 close(F) or die($!);
 
 exit(0);
