@@ -27,21 +27,29 @@
 #ifndef _SOUND_H
 #define _SOUND_H
 
+#include "vice.h"
+
 #include <stdlib.h>
 #include "types.h"
 
 /* Sound defaults.  */
 #define SOUND_SAMPLE_RATE 22050
+#define SOUND_CHANNELS_MAX 2
 
-#ifndef __MSDOS__
-# define SOUND_SAMPLE_BUFFER_SIZE       350     /* ms */
-#else
-# define SOUND_SAMPLE_BUFFER_SIZE       100
+#ifdef __MSDOS__
+# define SOUND_SAMPLE_BUFFER_SIZE       100     /* ms */
+#endif
+#ifdef __OS2__
+# define SOUND_SAMPLE_BUFFER_SIZE       400
+#endif
+#ifndef SOUND_SAMPLE_BUFFER_SIZE
+# define SOUND_SAMPLE_BUFFER_SIZE       350
 #endif
 
-/* I need this to serialize close_sound and enablesound/initsid in
+/* I need this to serialize close_sound and enablesound/sound_open in
    the OS/2 Multithreaded environment                              */
 extern int sound_state_changed;
+extern int sid_state_changed;
 
 /* device structure */
 typedef struct sound_device_s
@@ -51,26 +59,28 @@ typedef struct sound_device_s
     /* init -routine to be called at device initialization. Should use
        suggested values if possible or return new values if they cannot be
        used */
-    int	(*init)(const char *param,
+    int (*init)(const char *param,
         int *speed,
         int *fragsize, int *fragnr,
-        double bufsize);
+        int *channels);
     /* send number of bytes to the soundcard. it is assumed to block if kernel
        buffer is full */
-    int	(*write)(SWORD *pbuf, size_t nr);
+    int (*write)(SWORD *pbuf, size_t nr);
     /* dump-routine to be called for every write to SID */
     int (*dump)(ADDRESS addr, BYTE byte,
-					CLOCK clks);
+                                        CLOCK clks);
     /* flush-routine to be called every frame */
     int (*flush)(char *state);
     /* return number of samples unplayed in the kernel buffer at the moment */
-    int (*bufferstatus)(int first);
+    int (*bufferspace)(void);
     /* close and cleanup device */
     void (*close)(void);
     /* suspend device */
     int (*suspend)(void);
     /* resume device */
     int (*resume)(void);
+    /* is attenuation needed on suspend or not */
+    int need_attenuation;
 } sound_device_t;
 
 /* Sound adjustment types.  */
@@ -81,15 +91,20 @@ typedef struct sound_device_s
 /* external functions for vice */
 extern void sound_init(unsigned int clock_rate, unsigned int ticks_per_frame);
 extern void sound_reset(void);
-extern int  sound_flush(int relative_speed);
+#if __MSDOS__ || __riscos
+extern int sound_flush(int relative_speed);
+#else
+extern double sound_flush(int relative_speed);
+#endif
 extern void sound_suspend(void);
 extern void sound_resume(void);
 extern void sound_close(void);
+extern void sound_set_relative_speed(int value);
 extern void sound_set_warp_mode(int value);
 extern void sound_set_machine_parameter(long clock_rate, long ticks_per_frame);
 
-extern int  sound_init_resources(void);
-extern int  sound_init_cmdline_options(void);
+extern int  sound_resources_init(void);
+extern int  sound_cmdline_options_init(void);
 
 
 /* device initialization prototypes */
@@ -117,26 +132,30 @@ extern int sound_init_dart2_device(void);
 extern int sound_init_beos_device(void);
 extern int sound_init_arts_device(void);
 extern int sound_init_esd_device(void);
+extern int sound_init_wmm_device(void);
 
 /* internal function for sound device registration */
 extern int sound_register_device(sound_device_t *pdevice);
 
 /* other internal functions used around sound -code */
-extern int sound_read(ADDRESS addr);
-extern void sound_store(ADDRESS addr, BYTE val);
+extern int sound_read(ADDRESS addr, int chipno);
+extern void sound_store(ADDRESS addr, BYTE val, int chipno);
 extern long sound_sample_position(void);
 
 /* functions and structs implemented by each machine */
-extern void sound_machine_init(void);
 typedef struct sound_s sound_t;
-extern sound_t *sound_machine_open(int speed, int cycles_per_sec);
+extern sound_t *sound_machine_open(int chipno);
+extern int sound_machine_init(sound_t *psid, int speed, int cycles_per_sec);
 extern void sound_machine_close(sound_t *psid);
-extern int sound_machine_calculate_samples(sound_t *psid, SWORD *pbuf, int nr);
+extern int sound_machine_calculate_samples(sound_t *psid, SWORD *pbuf, int nr,
+					   int interleave, int *delta_t);
 extern void sound_machine_store(sound_t *psid, ADDRESS addr, BYTE val);
 extern BYTE sound_machine_read(sound_t *psid, ADDRESS addr);
 extern char *sound_machine_dump_state(sound_t *psid);
 extern void sound_machine_prevent_clk_overflow(sound_t *psid, CLOCK sub);
 extern void sound_machine_reset(sound_t *psid, CLOCK cpu_clk);
+extern int sound_machine_cycle_based(void);
+extern int sound_machine_channels(void);
 
 #ifdef __riscos
 extern int SoundPollEvery;
