@@ -30,27 +30,23 @@
 
 #include "sound.h"
 #include "utils.h"
+#include "archdep.h"
 
 static FILE *fs_fd = NULL;
 
 static int fs_init(const char *param, int *speed,
-		   int *fragsize, int *fragnr, double bufsize)
+		   int *fragsize, int *fragnr, int *channels)
 {
-    if (!param)
-	param = "vicesnd.raw";
-    fs_fd = fopen(param, "w");
-    if (!fs_fd)
-	return 1;
-    return 0;
+    /* No stereo capability. */
+    *channels = 1;
+
+    fs_fd = fopen(param?param:"vicesnd.raw", MODE_WRITE);
+    return !fs_fd;
 }
 
 static int fs_write(SWORD *pbuf, size_t nr)
 {
-    int i;
-    i = fwrite(pbuf, sizeof(SWORD), nr, fs_fd);
-    if (i != nr)
-	return 1;
-    return 0;
+    return fwrite(pbuf, sizeof(SWORD), nr, fs_fd) != nr;
 }
 
 static void fs_close(void)
@@ -69,7 +65,8 @@ static sound_device_t fs_device =
     NULL,
     fs_close,
     NULL,
-    NULL
+    NULL,
+    0
 };
 
 int sound_init_fs_device(void)
