@@ -28,6 +28,7 @@
 #ifndef _TRAPS_H
 #define _TRAPS_H
 
+#include "mem.h"
 #include "types.h"
 
 typedef struct trap_s
@@ -41,11 +42,13 @@ typedef struct trap_s
 #else
     void (*func)();
 #endif
+    read_func_t *readfunc;
+    store_func_t *storefunc;
 } trap_t;
 
 extern void traps_init(void);
-extern int traps_init_resources(void);
-extern int traps_init_cmdline_options(void);
+extern int traps_resources_init(void);
+extern int traps_cmdline_options_init(void);
 extern int traps_add(const trap_t *t);
 extern int traps_remove(const trap_t *t);
 extern int traps_handler(void);
