@@ -35,6 +35,10 @@
 
 #include "types.h"
 
+#define UTIL_FILE_LOAD_RAW          0
+#define UTIL_FILE_LOAD_SKIP_ADDRESS 1
+#define UTIL_FILE_LOAD_FILL         2
+
 extern char *stralloc(const char *str);
 extern void *xmalloc(size_t s);
 extern void *xcalloc(size_t nmemb, size_t size);
@@ -42,36 +46,40 @@ extern void *xrealloc(void *p, size_t s);
 extern char *xmsprintf(const char *fmt, ...);
 extern char *xmvsprintf(const char *fmt, va_list args);
 extern char *concat(const char *s1, ...);
-extern char *bufcat(char *buf, int *buf_size, size_t *max_buf_size,
-                    const char *src, int src_size);
-extern void remove_spaces(char *s);
-extern void xadd_extension(char **name, const char *extension);
-extern int make_backup_file(const char *fname);
-extern char *get_current_dir(void);
+extern char *util_bufcat(char *buf, int *buf_size, size_t *max_buf_size,
+                         const char *src, int src_size);
+extern void util_remove_spaces(char *s);
+extern void util_add_extension(char **name, const char *extension);
+extern char *util_add_extension_const(const char *filename,
+                                      const char *extension);
+extern char *util_get_current_dir(void);
 
-extern size_t file_length(FILE *fd);
-extern int load_file(const char *name, void *dest, size_t size);
-extern int save_file(const char *name, const void *src, int size);
-extern int remove_file(const char *name);
+extern size_t util_file_length(FILE *fd);
+extern int util_file_load(const char *name, BYTE *dest, size_t size,
+                          unsigned int load_flag);
+extern int util_file_save(const char *name, BYTE *src, int size);
+extern int util_file_remove(const char *name);
 
-extern int get_line(char *buf, int bufsize, FILE *f);
-extern void fname_split(const char *path, char **directory_return,
-                        char **name_return);
+extern int util_get_line(char *buf, int bufsize, FILE *f);
+extern void util_fname_split(const char *path, char **directory_return,
+                             char **name_return);
 
-extern int string_to_long(const char *str, const char **endptr, int base,
-                          long *result);
-extern char *subst(const char *s, const char *string, const char *replacement);
-extern void string_set(char **str, const char *new_value);
+extern int util_string_to_long(const char *str, const char **endptr, int base,
+                               long *result);
+extern char *util_subst(const char *s, const char *string,
+                        const char *replacement);
+extern int util_string_set(char **str, const char *new_value);
+extern int util_check_null_string(const char *string);
 
 extern int read_dword(FILE *fd, DWORD *buf, size_t num);
 extern int write_dword(FILE *fd, DWORD *buf, size_t num);
 
-extern void dword_to_le_buf(BYTE *buf, DWORD data);
+extern void util_dword_to_le_buf(BYTE *buf, DWORD data);
 
-extern int file_exists_p(const char *name);
+extern int util_file_exists_p(const char *name);
 
-extern char *find_prev_line(const char *text, const char *pos);
-extern char *find_next_line(const char *text, const char *pos);
+extern char *util_find_prev_line(const char *text, const char *pos);
+extern char *util_find_next_line(const char *pos);
 
 #if !defined HAVE_MEMMOVE
 void *memmove(void *target, const void *source, unsigned int length);
