@@ -27,7 +27,6 @@
  *
  */
 
-#include "alarm.h"
 #include "log.h"
 #include "types.h"
 #include "via.h"
@@ -40,34 +39,31 @@ BYTE myvia[16];
  * Local variables
  */
 
-static int myviaifr;		/* Interrupt Flag register for myvia */
-static int myviaier;		/* Interrupt Enable register for myvia */
+static int myviaifr;            /* Interrupt Flag register for myvia */
+static int myviaier;            /* Interrupt Enable register for myvia */
 
-static unsigned int myviatal;	/* current timer A latch value */
-static unsigned int myviatbl;	/* current timer B latch value */
+static unsigned int myviatal;   /* current timer A latch value */
+static unsigned int myviatbl;   /* current timer B latch value */
 
-static CLOCK myviatau;		/* time when myvia timer A is updated */
-static CLOCK myviatbu;		/* time when myvia timer B is updated */
-static CLOCK myviatai;		/* time when next timer A alarm is */
-static CLOCK myviatbi;		/* time when next timer A alarm is */
+static CLOCK myviatau;          /* time when myvia timer A is updated */
+static CLOCK myviatbu;          /* time when myvia timer B is updated */
+static CLOCK myviatai;          /* time when next timer A alarm is */
+static CLOCK myviatbi;          /* time when next timer A alarm is */
 
-static int myviapb7;		/* state of PB7 for pulse output... */
-static int myviapb7x;		/* to be xored herewith  */
-static int myviapb7o;		/* to be ored herewith  */
+static int myviapb7;            /* state of PB7 for pulse output... */
+static int myviapb7x;           /* to be xored herewith  */
+static int myviapb7o;           /* to be ored herewith  */
 static int myviapb7xx;
 static int myviapb7sx;
 
-static BYTE oldpa;		/* the actual output on PA (input = high) */
-static BYTE oldpb;		/* the actual output on PB (input = high) */
+static BYTE oldpa;              /* the actual output on PA (input = high) */
+static BYTE oldpb;              /* the actual output on PB (input = high) */
 
-static BYTE myvia_ila;		/* input latch A */
-static BYTE myvia_ilb;		/* input latch B */
+static BYTE myvia_ila;          /* input latch A */
+static BYTE myvia_ilb;          /* input latch B */
 
 static int ca2_state;
 static int cb2_state;
 
 static log_t myvia_log = LOG_ERR;
 
-/* VIA alarms.  */
-static alarm_t myvia_t1_alarm;
-static alarm_t myvia_t2_alarm;
