@@ -27,17 +27,25 @@
 #ifndef _VIC20_H
 #define _VIC20_H
 
-#define VIC20_PAL_CYCLES_PER_SEC  1108405
-#define VIC20_PAL_CYCLES_PER_LINE 71
-#define VIC20_PAL_SCREEN_LINES    312
+#define VIC20_PAL_CYCLES_PER_SEC        1108405
+#define VIC20_PAL_CYCLES_PER_LINE       71
+#define VIC20_PAL_SCREEN_LINES          312
+#define VIC20_PAL_FIRST_DISPLAYED_LINE  28
+#define VIC20_PAL_LAST_DISPLAYED_LINE   311
+#define VIC20_PAL_CYCLE_OFFSET          0
+ 
 #define VIC20_PAL_CYCLES_PER_RFSH (VIC20_PAL_SCREEN_LINES \
                                  * VIC20_PAL_CYCLES_PER_LINE)
 #define VIC20_PAL_RFSH_PER_SEC    (1.0 / ((double)VIC20_PAL_CYCLES_PER_RFSH  \
                                         / (double)VIC20_PAL_CYCLES_PER_SEC))
 
-#define VIC20_NTSC_CYCLES_PER_SEC  1022727
-#define VIC20_NTSC_CYCLES_PER_LINE 65
-#define VIC20_NTSC_SCREEN_LINES	 261
+#define VIC20_NTSC_CYCLES_PER_SEC       1022727
+#define VIC20_NTSC_CYCLES_PER_LINE      65
+#define VIC20_NTSC_SCREEN_LINES         261
+#define VIC20_NTSC_FIRST_DISPLAYED_LINE 8
+#define VIC20_NTSC_LAST_DISPLAYED_LINE  260
+#define VIC20_NTSC_CYCLE_OFFSET         37
+
 #define VIC20_NTSC_CYCLES_PER_RFSH (VIC20_NTSC_SCREEN_LINES \
                                   * VIC20_NTSC_CYCLES_PER_LINE)
 #define VIC20_NTSC_RFSH_PER_SEC    (1.0 / ((double)VIC20_NTSC_CYCLES_PER_RFSH \
