@@ -2,8 +2,9 @@
  * vic20.c - IEC bus handling for the VIC20.
  *
  * Written by
- *  Daniel Sladic (sladic@eecg.toronto.edu)
- *  Andr Fachat (fachat@physik.tu-chemnitz.de)
+ *  Daniel Sladic <sladic@eecg.toronto.edu>
+ *  Andr Fachat <fachat@physik.tu-chemnitz.de>
+ *  Andreas Boose <boose@linux.rz.fh-hannover.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -29,16 +30,18 @@
 #define _VIC20IEC_H
 
 #include "types.h"
-#include "iecdrive.h"
+
+struct iec_info_s;
 
 extern BYTE iec_pa_read(void);
 extern void iec_pa_write(BYTE data);
-void iec_pcr_write(BYTE data);
+extern void iec_pcr_write(BYTE data);
 
 /* These are dummies.  */
 extern void parallel_cable_cpu_write(BYTE data, int handshake);
 extern BYTE parallel_cable_cpu_read(void);
 
-extern iec_info_t *iec_get_drive_port(void);
+extern struct iec_info_s *iec_get_drive_port(void);
 
 #endif
+
