@@ -81,6 +81,15 @@
 
 /* ------------------------------------------------------------------------- */
 
+/* Do we need 2x video support?  */
+#if defined(__riscos) || (VIDEO_DISPLAY_DEPTH != 0)
+/* Use chip specific 2x code.  */
+#else
+#define VIDEO_REMOVE_2X 1
+#endif
+
+/* ------------------------------------------------------------------------- */
+
 /* This code comes from GNU make:
    Copyright (C) 1988, 89, 90, 91, 92, 93, 94, 95
      Free Software Foundation, Inc.
@@ -93,28 +102,28 @@
 
 /* For some reason, our DJGPP setup does not like to have both `limits.h' and
    `sys/param.h' #included.  */
-#if !defined(OS2) && !defined(DJGPP) && defined(HAVE_SYS_PARAM_H)
+#if !defined(__OS2__) && !defined(DJGPP) && defined(HAVE_SYS_PARAM_H)
 #include <sys/param.h>
 #endif
 
-#ifndef	PATH_MAX
-#ifndef	POSIX
-#define	PATH_MAX	MAXPATHLEN
-#endif	/* Not POSIX.  */
-#endif	/* No PATH_MAX.  */
+#ifndef PATH_MAX
+#ifndef POSIX
+#define PATH_MAX        MAXPATHLEN
+#endif  /* Not POSIX.  */
+#endif  /* No PATH_MAX.  */
 #ifndef MAXPATHLEN
 #define MAXPATHLEN 1024
-#endif	/* No MAXPATHLEN.  */
+#endif  /* No MAXPATHLEN.  */
 
 /* As `GET_PATH_MAX' might call a function, a `PATH_VAR' macro is provided to
    declare local strings for storing paths.  WARNING: This needs `alloca()'
    to be available!  */
-#ifdef	PATH_MAX
-#define	GET_PATH_MAX	PATH_MAX
+#ifdef  PATH_MAX
+#define GET_PATH_MAX    PATH_MAX
 #else
-#define	NEED_GET_PATH_MAX
+#define NEED_GET_PATH_MAX
 extern unsigned int get_path_max();
-#define	GET_PATH_MAX	(get_path_max())
+#define GET_PATH_MAX    (get_path_max())
 #endif
 
 /* ------------------------------------------------------------------------- */
