@@ -32,80 +32,73 @@
 
 #include "alarm.h"
 #include "log.h"
-#include "maincpu.h"
 #include "raster.h"
 #include "types.h"
 #include "vicii-mem.h"
 
 /* Screen constants.  */
 #define VIC_II_PAL_SCREEN_HEIGHT        312
-#define VIC_II_NTSC_SCREEN_HEIGHT	263
-#define VIC_II_NTSCOLD_SCREEN_HEIGHT	262
+#define VIC_II_NTSC_SCREEN_HEIGHT       263
+#define VIC_II_NTSCOLD_SCREEN_HEIGHT    262
 
-#if 0
-#define VIC_II_SCREEN_WIDTH		411
-#else
-/* Not the real size, but more than enough for everything.  Emulating a
-   smaller screen makes it faster.  */
-#define VIC_II_SCREEN_WIDTH		384
-#endif
+/* We need the full width for correct
+   sprite-sprite-collision in unvisible area */
+#define VIC_II_SCREEN_WIDTH             512
 
 #define VIC_II_PAL_OFFSET                       0
 #define VIC_II_NTSC_OFFSET                      0
 #define VIC_II_NTSCOLD_OFFSET                   0
 
-#define VIC_II_SCREEN_XPIX			320
-#define VIC_II_SCREEN_YPIX			200
-#define VIC_II_SCREEN_TEXTCOLS			40
-#define VIC_II_SCREEN_TEXTLINES 	       	25
-#define VIC_II_SCREEN_PAL_BORDERWIDTH		32
-#define VIC_II_SCREEN_PAL_BORDERHEIGHT     	51
-#define VIC_II_SCREEN_NTSC_BORDERWIDTH		32
-#define VIC_II_SCREEN_NTSC_BORDERHEIGHT		27
-#define VIC_II_SCREEN_NTSCOLD_BORDERWIDTH	32
-#define VIC_II_SCREEN_NTSCOLD_BORDERHEIGHT	27
-#define VIC_II_SCREEN_CHARHEIGHT		8
+#define VIC_II_SCREEN_XPIX                      320
+#define VIC_II_SCREEN_YPIX                      200
+#define VIC_II_SCREEN_TEXTCOLS                  40
+#define VIC_II_SCREEN_TEXTLINES                 25
+#define VIC_II_SCREEN_PAL_BORDERWIDTH           32
+#define VIC_II_SCREEN_PAL_BORDERHEIGHT          51
+#define VIC_II_SCREEN_NTSC_BORDERWIDTH          32
+#define VIC_II_SCREEN_NTSC_BORDERHEIGHT         27
+#define VIC_II_SCREEN_NTSCOLD_BORDERWIDTH       32
+#define VIC_II_SCREEN_NTSCOLD_BORDERHEIGHT      27
+#define VIC_II_SCREEN_CHARHEIGHT                8
 
-#define VIC_II_PAL_FIRST_DISPLAYED_LINE		0x10
-#define VIC_II_PAL_LAST_DISPLAYED_LINE		0x11f
-#define VIC_II_PAL_25ROW_START_LINE		0x33
-#define VIC_II_PAL_25ROW_STOP_LINE		0xfb
-#define VIC_II_PAL_24ROW_START_LINE		0x37
-#define VIC_II_PAL_24ROW_STOP_LINE		0xf7
+#define VIC_II_PAL_FIRST_DISPLAYED_LINE         0x10
+#define VIC_II_PAL_LAST_DISPLAYED_LINE          0x11f
+#define VIC_II_PAL_25ROW_START_LINE             0x33
+#define VIC_II_PAL_25ROW_STOP_LINE              0xfb
+#define VIC_II_PAL_24ROW_START_LINE             0x37
+#define VIC_II_PAL_24ROW_STOP_LINE              0xf7
 
-#define VIC_II_NTSC_FIRST_DISPLAYED_LINE	(0x20 - VIC_II_NTSC_OFFSET)
-#define VIC_II_NTSC_LAST_DISPLAYED_LINE		0x102
-#define VIC_II_NTSC_25ROW_START_LINE		(0x33 - VIC_II_NTSC_OFFSET)
-#define VIC_II_NTSC_25ROW_STOP_LINE		(0xfb - VIC_II_NTSC_OFFSET)
-#define VIC_II_NTSC_24ROW_START_LINE		(0x37 - VIC_II_NTSC_OFFSET)
-#define VIC_II_NTSC_24ROW_STOP_LINE		(0xf7 - VIC_II_NTSC_OFFSET)
+#define VIC_II_NTSC_FIRST_DISPLAYED_LINE        (0x20 - VIC_II_NTSC_OFFSET)
+#define VIC_II_NTSC_LAST_DISPLAYED_LINE         0x102
+#define VIC_II_NTSC_25ROW_START_LINE            (0x33 - VIC_II_NTSC_OFFSET)
+#define VIC_II_NTSC_25ROW_STOP_LINE             (0xfb - VIC_II_NTSC_OFFSET)
+#define VIC_II_NTSC_24ROW_START_LINE            (0x37 - VIC_II_NTSC_OFFSET)
+#define VIC_II_NTSC_24ROW_STOP_LINE             (0xf7 - VIC_II_NTSC_OFFSET)
 
-#define VIC_II_NTSCOLD_FIRST_DISPLAYED_LINE	(0x20 - VIC_II_NTSCOLD_OFFSET)
-#define VIC_II_NTSCOLD_LAST_DISPLAYED_LINE	0x102
-#define VIC_II_NTSCOLD_25ROW_START_LINE		(0x33 - VIC_II_NTSCOLD_OFFSET)
-#define VIC_II_NTSCOLD_25ROW_STOP_LINE		(0xfb - VIC_II_NTSCOLD_OFFSET)
-#define VIC_II_NTSCOLD_24ROW_START_LINE		(0x37 - VIC_II_NTSCOLD_OFFSET)
-#define VIC_II_NTSCOLD_24ROW_STOP_LINE		(0xf7 - VIC_II_NTSCOLD_OFFSET)
+#define VIC_II_NTSCOLD_FIRST_DISPLAYED_LINE     (0x20 - VIC_II_NTSCOLD_OFFSET)
+#define VIC_II_NTSCOLD_LAST_DISPLAYED_LINE      0x102
+#define VIC_II_NTSCOLD_25ROW_START_LINE         (0x33 - VIC_II_NTSCOLD_OFFSET)
+#define VIC_II_NTSCOLD_25ROW_STOP_LINE          (0xfb - VIC_II_NTSCOLD_OFFSET)
+#define VIC_II_NTSCOLD_24ROW_START_LINE         (0x37 - VIC_II_NTSCOLD_OFFSET)
+#define VIC_II_NTSCOLD_24ROW_STOP_LINE          (0xf7 - VIC_II_NTSCOLD_OFFSET)
 
-#define VIC_II_40COL_START_PIXEL		0x20
-#define VIC_II_40COL_STOP_PIXEL			0x160
-#define VIC_II_38COL_START_PIXEL		0x27
-#define VIC_II_38COL_STOP_PIXEL			0x157
+#define VIC_II_40COL_START_PIXEL                0x20
+#define VIC_II_40COL_STOP_PIXEL                 0x160
+#define VIC_II_38COL_START_PIXEL                0x27
+#define VIC_II_38COL_STOP_PIXEL                 0x157
 
-#define VIC_II_NUM_SPRITES		8
-#define VIC_II_MAX_SPRITE_WIDTH		48
-#define VIC_II_NUM_COLORS	        16
+#define VIC_II_NUM_SPRITES              8
+#define VIC_II_MAX_SPRITE_WIDTH         48
+#define VIC_II_NUM_COLORS               16
 
-#define VIC_II_PAL_SPRITE_WRAP_X	504
-#define VIC_II_NTSC_SPRITE_WRAP_X	520
-#define VIC_II_NTSCOLD_SPRITE_WRAP_X	512
+#define VIC_II_PAL_SPRITE_WRAP_X        504
+#define VIC_II_NTSC_SPRITE_WRAP_X       520
+#define VIC_II_NTSCOLD_SPRITE_WRAP_X    512
 
-
 
 /* Available video modes.  The number is given by
    ((vic_ii.regs[0x11] & 0x60) | (vic_ii.regs[0x16] & 0x10)) >> 4.  */
-enum _vic_ii_video_mode
-  {
+enum vic_ii_video_mode_s {
     VIC_II_NORMAL_TEXT_MODE,
     VIC_II_MULTICOLOR_TEXT_MODE,
     VIC_II_HIRES_BITMAP_MODE,
@@ -114,18 +107,18 @@ enum _vic_ii_video_mode
     VIC_II_ILLEGAL_TEXT_MODE,
     VIC_II_ILLEGAL_BITMAP_MODE_1,
     VIC_II_ILLEGAL_BITMAP_MODE_2,
-    VIC_II_IDLE_MODE,		/* Special mode for idle state.  */
+    VIC_II_IDLE_MODE,           /* Special mode for idle state.  */
     VIC_II_NUM_VMODES
-  };
-typedef enum _vic_ii_video_mode vic_ii_video_mode_t;
+};
+typedef enum vic_ii_video_mode_s vic_ii_video_mode_t;
 
-#define VIC_II_IS_ILLEGAL_MODE(x)	((x) >= VIC_II_ILLEGAL_TEXT_MODE \
-					 && (x) != VIC_II_IDLE_MODE)
-#define VIC_II_IS_BITMAP_MODE(x)	((x) & 0x02)
+#define VIC_II_IS_ILLEGAL_MODE(x)       ((x) >= VIC_II_ILLEGAL_TEXT_MODE \
+                                         && (x) != VIC_II_IDLE_MODE)
+#define VIC_II_IS_BITMAP_MODE(x)        ((x) & 0x02)
 
 /* On MS-DOS, we do not need 2x drawing functions.  This is mainly to save
    memory and (little) speed.  */
-#if(!defined(__MSDOS__) && !defined(__riscos) && !defined(OS2))
+#if !defined(__MSDOS__) && !defined(__riscos) && !defined(__OS2__)
 #define VIC_II_NEED_2X 1
 #endif
 
@@ -139,7 +132,7 @@ typedef enum _vic_ii_video_mode vic_ii_video_mode_t;
 #define VIC_II_NTSCOLD_CYCLES_PER_LINE  C64_NTSCOLD_CYCLES_PER_LINE
 
 /* Cycle # at which the VIC takes the bus in a bad line (BA goes low).  */
-#define	VIC_II_FETCH_CYCLE          11
+#define VIC_II_FETCH_CYCLE          11
 
 /* Cycle # at which sprite DMA is set.  */
 #define VIC_II_PAL_SPRITE_FETCH_CYCLE       54
@@ -175,7 +168,7 @@ typedef enum _vic_ii_video_mode vic_ii_video_mode_t;
 
 /* Cycle # within the current line.  */
 #define VIC_II_RASTER_CYCLE(clk)    ((unsigned int)((clk) \
-                                                    % vic_ii.cycles_per_line))
+                                    % vic_ii.cycles_per_line))
 
 /* `clk' value for the beginning of the current line.  */
 #define VIC_II_LINE_START_CLK(clk)  (((clk) / vic_ii.cycles_per_line) \
@@ -197,33 +190,29 @@ typedef enum _vic_ii_video_mode vic_ii_video_mode_t;
 /* VIC-II structures.  This is meant to be used by VIC-II modules
    *exclusively*!  */
 
-struct vic_ii_light_pen_s
-  {
+struct vic_ii_light_pen_s {
     int triggered;
     int x, y;
-  };
+};
 typedef struct vic_ii_light_pen_s vic_ii_light_pen_t;
 
-enum _vic_ii_fetch_idx
-  {
+enum vic_ii_fetch_idx_s {
     VIC_II_FETCH_MATRIX,
     VIC_II_CHECK_SPRITE_DMA,
     VIC_II_FETCH_SPRITE
-  };
-typedef enum _vic_ii_fetch_idx vic_ii_fetch_idx_t;
+};
+typedef enum vic_ii_fetch_idx_s vic_ii_fetch_idx_t;
 
-enum _vic_ii_idle_data_location
-  {
+enum vic_ii_idle_data_location_s {
     IDLE_NONE,
     IDLE_3FFF,
     IDLE_39FF
-  };
-typedef enum _vic_ii_idle_data_location vic_ii_idle_data_location_t;
+};
+typedef enum vic_ii_idle_data_location_s vic_ii_idle_data_location_t;
 
-struct vic_ii_s
-  {
+struct vic_ii_s {
     /* Flag: Are we initialized?  */
-    int initialized;		/* = 0; */
+    int initialized;            /* = 0; */
 
     /* VIC-II raster.  */
     raster_t raster;
@@ -232,7 +221,7 @@ struct vic_ii_s
     int regs[64];
 
     /* Interrupt register.  */
-    int irq_status;		/* = 0; */
+    int irq_status;             /* = 0; */
 
     /* Line for raster compare IRQ.  */
     unsigned int raster_irq_line;
@@ -241,7 +230,24 @@ struct vic_ii_s
     BYTE color_ram[0x400];
 
     /* Pointer to the base of RAM seen by the VIC-II.  */
-    BYTE *ram_base;		/* = ram; */
+    /* address is base of 64k bank. vbank adds 0/16k/32k/48k to get actual
+       video address */
+    BYTE *ram_base_phi1;                /* = VIC-II address during Phi1; */
+    BYTE *ram_base_phi2;                /* = VIC-II address during Phi2; */
+
+    /* valid VIC-II address bits for Phi1 and Phi2. After masking
+       the address, it is or'd with the offset value to set always-1 bits */
+    ADDRESS vaddr_mask_phi1;            /* mask of valid address bits */
+    ADDRESS vaddr_mask_phi2;            /* mask of valid address bits */
+    ADDRESS vaddr_offset_phi1;          /* mask of address bits always set */
+    ADDRESS vaddr_offset_phi2;          /* mask of address bits always set */
+
+    /* Those two values determine where in the address space the chargen
+       ROM is mapped. Use mask=0x7000, value=0x1000 for the C64. */
+    ADDRESS vaddr_chargen_mask_phi1;    /* address bits to comp. for chargen */
+    ADDRESS vaddr_chargen_mask_phi2;    /* address bits to comp. for chargen */
+    ADDRESS vaddr_chargen_value_phi1;   /* compare value for chargen */
+    ADDRESS vaddr_chargen_value_phi2;   /* compare value for chargen */
 
     /* Video memory pointers.  */
     BYTE *screen_ptr;
@@ -298,10 +304,11 @@ struct vic_ii_s
     vic_ii_light_pen_t light_pen;
 
     /* Start of the memory bank seen by the VIC-II.  */
-    int vbank;			/* = 0; */
+    int vbank_phi1;                     /* = 0; */
+    int vbank_phi2;                     /* = 0; */
 
     /* Pointer to the start of the video bank.  */
-    BYTE *vbank_ptr;
+    /* BYTE *vbank_ptr; - never used, only set */
 
     /* Data to display in idle state.  */
     int idle_data;
@@ -314,7 +321,7 @@ struct vic_ii_s
     int extended_keyboard_rows_enabled;
 
     /* All the VIC-II logging goes here.  */
-    log_t log;			/* = LOG_ERR; */
+    log_t log;                  /* = LOG_ERR; */
 
     /* VIC-II alarms.  */
     alarm_t raster_fetch_alarm;
@@ -364,21 +371,22 @@ struct vic_ii_s
 
     /* Number of lines the whole screen is shifted up.  */
     int offset;
-  };
+    
+    /* flag backgroundcolor in HIRES mode */
+    int get_background_from_vbuf;
+};
 typedef struct vic_ii_s vic_ii_t;
 
 extern vic_ii_t vic_ii;
 
-/* Private function calls, used by the other VIC-II modules.  FIXME:
-   Prepend names with `_'?  */
-extern int vic_ii_load_palette (const char *name);
-extern void vic_ii_fetch_matrix (int offs, int num);
-extern void vic_ii_set_raster_irq (unsigned int line);
-extern void vic_ii_update_memory_ptrs (unsigned int cycle);
-extern void vic_ii_update_video_mode (unsigned int cycle);
-extern int vic_ii_raster_draw_alarm_handler (CLOCK offset);
-extern int vic_ii_raster_fetch_alarm_handler (CLOCK offset);
-extern int vic_ii_raster_irq_alarm_handler (CLOCK offset);
+/* Private function calls, used by the other VIC-II modules.  */
+extern void vic_ii_fetch_matrix(int offs, int num);
+extern void vic_ii_set_raster_irq(unsigned int line);
+extern void vic_ii_update_memory_ptrs(unsigned int cycle);
+extern void vic_ii_update_video_mode(unsigned int cycle);
+extern void vic_ii_raster_draw_alarm_handler(CLOCK offset);
+extern void vic_ii_raster_fetch_alarm_handler(CLOCK offset);
+extern void vic_ii_resize(void);
 
 /* Debugging options.  */
 
@@ -404,67 +412,5 @@ extern int vic_ii_raster_irq_alarm_handler (CLOCK offset);
 #define VIC_II_DEBUG_REGISTER(x)
 #endif
 
-inline static void vic_ii_handle_pending_alarms (int num_write_cycles)
-{
-  if (num_write_cycles != 0)
-    {
-      int f;
+#endif /* _VICIITYPES_H */
 
-      /* Cycles can be stolen only during the read accesses, so we serve
-         only the events that happened during them.  The last read access
-         happened at `clk - maincpu_write_cycles()' as all the opcodes
-         except BRK and JSR do all the write accesses at the very end.  BRK
-         cannot take us here and we would not be able to handle JSR
-         correctly anyway, so we don't care about them...  */
-
-      /* Go back to the time when the read accesses happened and serve VIC
-         events.  */
-      clk -= num_write_cycles;
-
-      do
-	{
-	  f = 0;
-	  if (clk > vic_ii.fetch_clk)
-	    {
-	      vic_ii_raster_fetch_alarm_handler (0);
-	      f = 1;
-	    }
-	  if (clk >= vic_ii.draw_clk)
-	    {
-	      vic_ii_raster_draw_alarm_handler((long)(clk - vic_ii.draw_clk));
-	      f = 1;
-	    }
-	}
-      while (f);
-
-      /* Go forward to the time when the last write access happens (that's
-         the one we care about, as the only instructions that do two write
-         accesses - except BRK and JSR - are the RMW ones, which store the
-         old value in the first write access, and then store the new one in
-         the second write access).  */
-      clk += num_write_cycles;
-
-    }
-  else
-    {
-      int f;
-
-      do
-	{
-	  f = 0;
-	  if (clk >= vic_ii.fetch_clk)
-	    {
-	      vic_ii_raster_fetch_alarm_handler (0);
-	      f = 1;
-	    }
-	  if (clk >= vic_ii.draw_clk)
-	    {
-	      vic_ii_raster_draw_alarm_handler (0);
-	      f = 1;
-	    }
-	}
-      while (f);
-    }
-}
-
-#endif /* _VICII_H */
